@@ -43,13 +43,17 @@ void HighlightedOperationSkroogoid::init()
         setLayout(widgetLayout);
 
         Plasma::DataEngine* engine = dataEngine("skgdataengine");
-        if (engine->isValid())  engine->connectSource("Highlighted Operations", this);
+        if (engine->isValid()) {
+            engine->connectSource("Highlighted Operations", this);
+        }
     }
 }
 
 void HighlightedOperationSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& engineData)
 {
-    if (sourceName != "Highlighted Operations") return;
+    if (sourceName != "Highlighted Operations") {
+        return;
+    }
 
     QHash<QString, QStringList> listData;
     for (int i = 0 ; i < engineData.keys().count() ; ++i) {
