@@ -46,7 +46,9 @@ void UnitSkroogoid::init()
 
         // Load the dataengine that contains data we need
         Plasma::DataEngine* engine = dataEngine("skgdataengine");
-        if (engine->isValid())  engine->connectSource("Units", this);
+        if (engine->isValid()) {
+            engine->connectSource("Units", this);
+        }
     }
 }
 
@@ -55,8 +57,10 @@ UnitSkroogoid::~UnitSkroogoid()
 
 void UnitSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& engineData)
 {
-    if (sourceName != "Units") return;
-    SKGTRACEIN(1, "UnitSkroogoid::dataUpdated");
+    if (sourceName != "Units") {
+        return;
+    }
+    SKGTRACEINFUNC(1);
     // Get the current document
     SKGMainPanel* panel = SKGMainPanel::getMainPanel();
     doc = qobject_cast<SKGDocumentBank*> (panel->getDocument());
