@@ -30,7 +30,7 @@
 SKGTipOfDayBoardWidget::SKGTipOfDayBoardWidget(SKGDocument* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Tip of the day"))
 {
-    SKGTRACEIN(10, "SKGTipOfDayBoardWidget::SKGTipOfDayBoardWidget");
+    SKGTRACEINFUNC(10);
 
     QFrame* f = new QFrame();
     ui.setupUi(f);
@@ -47,7 +47,7 @@ SKGTipOfDayBoardWidget::SKGTipOfDayBoardWidget(SKGDocument* iDocument)
 
 SKGTipOfDayBoardWidget::~SKGTipOfDayBoardWidget()
 {
-    SKGTRACEIN(10, "SKGTipOfDayBoardWidget::~SKGTipOfDayBoardWidget");
+    SKGTRACEINFUNC(10);
 }
 
 void SKGTipOfDayBoardWidget::onModified()
