@@ -52,12 +52,12 @@ SKGBookmarkPlugin::SKGBookmarkPlugin(QWidget* iWidget, QObject* iParent, const Q
 {
     Q_UNUSED(iArg);
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGBookmarkPlugin::SKGBookmarkPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGBookmarkPlugin::~SKGBookmarkPlugin()
 {
-    SKGTRACEIN(10, "SKGBookmarkPlugin::~SKGBookmarkPlugin");
+    SKGTRACEINFUNC(10);
     m_currentDocument = NULL;
     m_dockWidget = NULL;
     m_importStdBookmarkAction = NULL;
@@ -67,7 +67,7 @@ SKGBookmarkPlugin::~SKGBookmarkPlugin()
 
 bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGBookmarkPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
 
     m_currentDocument = iDocument;
@@ -127,7 +127,7 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
 QWidget* SKGBookmarkPlugin::getPreferenceWidget()
 {
-    SKGTRACEIN(10, "SKGFilePlugin::getPreferenceWidget");
+    SKGTRACEINFUNC(10);
     QWidget* w = new QWidget();
     ui.setupUi(w);
     return w;
@@ -140,15 +140,19 @@ KConfigSkeleton* SKGBookmarkPlugin::getPreferenceSkeleton()
 
 void SKGBookmarkPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGBookmarkPlugin::refresh");
+    SKGTRACEINFUNC(10);
     if (m_dockWidget) {
         SKGBookmarkPluginDockWidget* p = static_cast<SKGBookmarkPluginDockWidget*>(m_dockWidget->widget());
-        if (p) p->refresh();
+        if (p) {
+            p->refresh();
+        }
     }
 
     if (m_currentDocument) {
         bool test = (m_currentDocument->getDatabase() != NULL);
-        if (m_importStdBookmarkAction) m_importStdBookmarkAction->setEnabled(test);
+        if (m_importStdBookmarkAction) {
+            m_importStdBookmarkAction->setEnabled(test);
+        }
 
         // Automatic bookmarks creation
         if (m_currentDocument->getDatabase() != NULL) {
@@ -166,7 +170,9 @@ void SKGBookmarkPlugin::refresh()
                 }
 
                 // Automatic open of autostart bookmark
-                if (!err && !(QApplication::keyboardModifiers() &Qt::ShiftModifier)) goHome();
+                if (!err && !(QApplication::keyboardModifiers() &Qt::ShiftModifier)) {
+                    goHome();
+                }
             }
         }
     }
@@ -204,7 +210,7 @@ QDockWidget* SKGBookmarkPlugin::getDockWidget()
 
 void SKGBookmarkPlugin::importStandardBookmarks()
 {
-    SKGTRACEIN(10, "SKGBookmarkPlugin::importStandardBookmarks");
+    SKGTRACEINFUNC(10);
     SKGError err;
     SKGBEGINTRANSACTION(*m_currentDocument, i18nc("Noun, name of the user action", "Import standard bookmarks"), err);
 
@@ -248,10 +254,14 @@ void SKGBookmarkPlugin::importStandardBookmarks()
 
 void SKGBookmarkPlugin::goHome()
 {
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->closeAllPages(false);  // Home do not close pinned pages
+    if (SKGMainPanel::getMainPanel()) {
+        SKGMainPanel::getMainPanel()->closeAllPages(false);    // Home do not close pinned pages
+    }
 
     SKGObjectBase::SKGListSKGObjectBase oNodeList;
-    if (m_currentDocument) m_currentDocument->getObjects("v_node", "t_autostart='Y' ORDER BY f_sortorder, t_name", oNodeList);
+    if (m_currentDocument) {
+        m_currentDocument->getObjects("v_node", "t_autostart='Y' ORDER BY f_sortorder, t_name", oNodeList);
+    }
     int nbAutoStartedBookmarks = oNodeList.count();
     for (int i = 0; i < nbAutoStartedBookmarks; ++i) {
         SKGNodeObject autostarted_bookmark(oNodeList.at(i));
@@ -272,7 +282,7 @@ void SKGBookmarkPlugin::onOpenBookmark(Qt::MouseButtons iMouse, Qt::KeyboardModi
 
 void SKGBookmarkPlugin::onAddBookmark()
 {
-    SKGTRACEIN(1, "SKGBookmarkPlugin::onAddBookmark");
+    SKGTRACEINFUNC(1);
     SKGError err;
 
     // Get current page
@@ -305,7 +315,9 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
         // Build query
         QString wc = "rd_node_id=0 OR rd_node_id IS NULL OR rd_node_id=''";
         int idParent = callerMenu->property("id").toInt();
-        if (idParent != 0) wc = "rd_node_id=" % SKGServices::intToString(idParent);
+        if (idParent != 0) {
+            wc = "rd_node_id=" % SKGServices::intToString(idParent);
+        }
 
         // Build new menu
         SKGObjectBase::SKGListSKGObjectBase listNode;
