@@ -43,8 +43,10 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
     : SKGWidget(iDocument), m_mainMenu(NULL), m_actDelete(NULL), m_actRename(NULL), m_actChangeIcon(NULL), m_actAddBookmark(NULL), m_actAddBookmarks(NULL),
       m_actAddBookmarkGroup(NULL), m_actSetAutostart(NULL), m_actUnsetAutostart(NULL)
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -86,7 +88,7 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
 
 SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget");
+    SKGTRACEINFUNC(1);
     m_mainMenu = NULL;
     m_actDelete = NULL;
     m_actRename = NULL;
@@ -161,19 +163,19 @@ void SKGBookmarkPluginDockWidget::showMenu(const QPoint& iPos)
 
 void SKGBookmarkPluginDockWidget::onSetAutostart()
 {
-    SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::onSetAutoStart");
+    SKGTRACEINFUNC(10);
     setAutostart("Y");
 }
 
 void SKGBookmarkPluginDockWidget::onUnsetAutostart()
 {
-    SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::onSetAutoStart");
+    SKGTRACEINFUNC(10);
     setAutostart("N");
 }
 
 void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
 {
-    SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::setAutostart");
+    SKGTRACEINFUNC(10);
     SKGObjectBase::SKGListSKGObjectBase selectedBookmarks = getSelectedObjects();
 
     SKGError err;
@@ -198,7 +200,7 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
 
 void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool iFirstInNewPage, bool iPin)
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::openBookmark");
+    SKGTRACEINFUNC(1);
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     QList<SKGNodeObject> nodes;
@@ -225,9 +227,13 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
             // This bookmark has information ==> we open it
             SKGTabPage* page = SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(data[0]), tabNumberForNextOpen, data[2], selectedNode.getName(), SKGServices::intToString(selectedNode.getID()), i == nodes.count() - 1);
             if (page) {
-                if (skgbookmark_settings::pinhomebookmarks()) page->setPin(iPin);
+                if (skgbookmark_settings::pinhomebookmarks()) {
+                    page->setPin(iPin);
+                }
                 SKGTabWidget* tab = SKGMainPanel::getMainPanel()->getTabWidget();
-                if (tab) tab->setTabIcon(SKGMainPanel::getMainPanel()->currentPageIndex(), selectedNode.getIcon());
+                if (tab) {
+                    tab->setTabIcon(SKGMainPanel::getMainPanel()->currentPageIndex(), selectedNode.getIcon());
+                }
                 selectedNode.opened = true;
                 tabNumberForNextOpen = -1;
             }
@@ -253,29 +259,33 @@ void SKGBookmarkPluginDockWidget::onBeforeOpenBookmark()
 
 void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex& index)
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onOpenBookmark");
+    SKGTRACEINFUNC(1);
     QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
     SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
     if (model) {
         SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
-        if (!node.isFolder()) openBookmark(node);
+        if (!node.isFolder()) {
+            openBookmark(node);
+        }
     }
 }
 
 void SKGBookmarkPluginDockWidget::onOpenBookmarkFolder(const QModelIndex& index)
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onOpenBookmarkFolder");
+    SKGTRACEINFUNC(1);
     QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
     SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
     if (model) {
         SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
-        if (node.isFolder()) openBookmark(node);
+        if (node.isFolder()) {
+            openBookmark(node);
+        }
     }
 }
 
 void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onAddBookmarkGroup");
+    SKGTRACEINFUNC(1);
     SKGError err;
     SKGNodeObject node;
     {
@@ -294,7 +304,9 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
         }
 
         // Add current name
-        if (!name.isEmpty()) name += OBJECTSEPARATOR;
+        if (!name.isEmpty()) {
+            name += OBJECTSEPARATOR;
+        }
         name += i18nc("Default name for bookmark", "New bookmark");
 
         // Create bookmark folder
@@ -312,7 +324,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
 
 void SKGBookmarkPluginDockWidget::onAddBookmarks()
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onAddBookmark");
+    SKGTRACEINFUNC(1);
     SKGError err;
     SKGNodeObject rootNode;
     {
@@ -331,7 +343,9 @@ void SKGBookmarkPluginDockWidget::onAddBookmarks()
         }
 
         // Add current name
-        if (!name.isEmpty()) name += OBJECTSEPARATOR;
+        if (!name.isEmpty()) {
+            name += OBJECTSEPARATOR;
+        }
         name += i18nc("Default name for bookmark", "New bookmark");
 
         // Create bookmark folder
@@ -354,7 +368,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmarks()
 
 void SKGBookmarkPluginDockWidget::onAddBookmark()
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onAddBookmark");
+    SKGTRACEINFUNC(1);
     SKGError err;
 
     // Get current page
@@ -363,7 +377,9 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
         // Get current selection
         SKGNodeObject parentNode(getDocument(), 0);
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
-        if (bookmarks.count()) parentNode = bookmarks.at(0);
+        if (bookmarks.count()) {
+            parentNode = bookmarks.at(0);
+        }
 
         // Create bookmark
         err = createNodeFromPage(SKGMainPanel::getMainPanel()->currentPage(), parentNode, node);
@@ -378,7 +394,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
 
 SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, const SKGNodeObject& iParentNode, SKGNodeObject& oCreatedNode)
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::createNodeFromPage");
+    SKGTRACEINFUNC(1);
     SKGError err;
 
     // Get current page
@@ -396,7 +412,9 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
         name = parentNode.getFullName();
 
         // Add current name
-        if (!name.isEmpty()) name += OBJECTSEPARATOR;
+        if (!name.isEmpty()) {
+            name += OBJECTSEPARATOR;
+        }
 
         QString defaultName = iPage->objectName();
         QString defaultIcon;
@@ -425,7 +443,7 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
 
 void SKGBookmarkPluginDockWidget::onRenameBookmark()
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onRenameBookmark");
+    SKGTRACEINFUNC(1);
 
     SKGObjectBase::SKGListSKGObjectBase selection;
     QItemSelectionModel* selModel = ui.kBookmarksList->selectionModel();
@@ -443,7 +461,7 @@ void SKGBookmarkPluginDockWidget::onRenameBookmark()
 
 void SKGBookmarkPluginDockWidget::onChangeIconBookmark()
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onChangeIconBookmark");
+    SKGTRACEINFUNC(1);
 
     SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
     if (bookmarks.count() == 1) {
@@ -467,7 +485,7 @@ void SKGBookmarkPluginDockWidget::onChangeIconBookmark()
 
 void SKGBookmarkPluginDockWidget::onRemoveBookmark()
 {
-    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onRemoveBookmark");
+    SKGTRACEINFUNC(1);
     SKGError err;
     {
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark delete"), err);
@@ -487,32 +505,52 @@ void SKGBookmarkPluginDockWidget::onRemoveBookmark()
 
 void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
 {
-    SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::onBookmarkEditorChanged");
+    SKGTRACEINFUNC(10);
 
     // Enable bookmark buttons
     int nbSelectedObjects = getNbSelectedObjects();
     bool testAdd = getDocument()->getDatabase() != NULL && nbSelectedObjects <= 1;
-    if (m_actAddBookmarkGroup) m_actAddBookmarkGroup->setEnabled(testAdd);
-    if (m_actAddBookmark) m_actAddBookmark->setEnabled(testAdd && SKGMainPanel::getMainPanel()->currentPageIndex() >= 0);
-    if (m_actAddBookmarks) m_actAddBookmarks->setEnabled(testAdd && SKGMainPanel::getMainPanel()->currentPageIndex() >= 0);
-    if (m_actDelete) m_actDelete->setEnabled(nbSelectedObjects > 0);
-    if (m_actRename) m_actRename->setEnabled(nbSelectedObjects == 1);
-    if (m_actChangeIcon) m_actChangeIcon->setEnabled(nbSelectedObjects == 1);
+    if (m_actAddBookmarkGroup) {
+        m_actAddBookmarkGroup->setEnabled(testAdd);
+    }
+    if (m_actAddBookmark) {
+        m_actAddBookmark->setEnabled(testAdd && SKGMainPanel::getMainPanel()->currentPageIndex() >= 0);
+    }
+    if (m_actAddBookmarks) {
+        m_actAddBookmarks->setEnabled(testAdd && SKGMainPanel::getMainPanel()->currentPageIndex() >= 0);
+    }
+    if (m_actDelete) {
+        m_actDelete->setEnabled(nbSelectedObjects > 0);
+    }
+    if (m_actRename) {
+        m_actRename->setEnabled(nbSelectedObjects == 1);
+    }
+    if (m_actChangeIcon) {
+        m_actChangeIcon->setEnabled(nbSelectedObjects == 1);
+    }
 }
 
 void SKGBookmarkPluginDockWidget::refresh()
 {
-    SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::refresh");
+    SKGTRACEINFUNC(10);
     // Bookmarks
     SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
     int nbSelectedObjects = bookmarks.count();
     if (nbSelectedObjects == 1) {
         SKGNodeObject node(bookmarks.at(0));
-        if (m_actSetAutostart) m_actSetAutostart->setEnabled(node.getAttribute("t_autostart") != "Y");
-        if (m_actUnsetAutostart) m_actUnsetAutostart->setEnabled(node.getAttribute("t_autostart") == "Y");
+        if (m_actSetAutostart) {
+            m_actSetAutostart->setEnabled(node.getAttribute("t_autostart") != "Y");
+        }
+        if (m_actUnsetAutostart) {
+            m_actUnsetAutostart->setEnabled(node.getAttribute("t_autostart") == "Y");
+        }
     } else {
-        if (m_actSetAutostart) m_actSetAutostart->setEnabled(nbSelectedObjects > 1);
-        if (m_actUnsetAutostart) m_actUnsetAutostart->setEnabled(nbSelectedObjects > 1);
+        if (m_actSetAutostart) {
+            m_actSetAutostart->setEnabled(nbSelectedObjects > 1);
+        }
+        if (m_actUnsetAutostart) {
+            m_actUnsetAutostart->setEnabled(nbSelectedObjects > 1);
+        }
     }
 
     onBookmarkEditorChanged();
@@ -523,7 +561,9 @@ void SKGBookmarkPluginDockWidget::onPageChanged()
     // Set current selection of dock
     QString id;
     SKGTabPage* cPage = SKGMainPanel::getMainPanel()->currentPage();
-    if (cPage) id = cPage->getBookmarkID();
+    if (cPage) {
+        id = cPage->getBookmarkID();
+    }
     ui.kBookmarksList->selectObject(id % "-node");
 }
 
