@@ -44,19 +44,19 @@ SKGHighlightPlugin::SKGHighlightPlugin(QWidget* iWidget, QObject* iParent, const
     m_currentDocument(NULL), m_switchHighLight(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGHighlightPlugin::SKGHighlightPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGHighlightPlugin::~SKGHighlightPlugin()
 {
-    SKGTRACEIN(10, "SKGHighlightPlugin::~SKGHighlightPlugin");
+    SKGTRACEINFUNC(10);
     m_currentDocument = NULL;
     m_switchHighLight = NULL;
 }
 
 bool SKGHighlightPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGHighlightPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
 
     m_currentDocument = iDocument;
@@ -77,13 +77,17 @@ bool SKGHighlightPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
 void SKGHighlightPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::refresh");
+    SKGTRACEINFUNC(10);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         if (selection.count() > 0) {
-            if (m_switchHighLight) m_switchHighLight->setEnabled(selection.at(0).getAttributes().contains("t_bookmarked"));
+            if (m_switchHighLight) {
+                m_switchHighLight->setEnabled(selection.at(0).getAttributes().contains("t_bookmarked"));
+            }
         } else {
-            if (m_switchHighLight) m_switchHighLight->setEnabled(false);
+            if (m_switchHighLight) {
+                m_switchHighLight->setEnabled(false);
+            }
         }
     }
 }
@@ -111,7 +115,7 @@ int SKGHighlightPlugin::getOrder() const
 void SKGHighlightPlugin::onSwitchHighLight()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGHighlightPlugin::onSwitchHighLight", err);
+    SKGTRACEINFUNCRC(10, err);
     // Get Selection
     if (SKGMainPanel::getMainPanel() && m_currentDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
