@@ -75,11 +75,11 @@ public:
      * Get the current month
      * @return the current month
      */
-    virtual QString getMonth();
+    virtual QString getPeriod();
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
-    void onMonthChanged();
+    void onPeriodChanged();
     void onGetNewHotStuff();
     void onPutNewHotStuff();
     void onTemplateChanged();
