@@ -49,7 +49,7 @@ SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget* iWidget, QObject* iParent, con
     m_currentDocument(NULL), m_dockWidget(NULL), m_dockContent(NULL), m_addPropertyAction(NULL), m_addPropertyMenu(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGPropertiesPlugin::SKGPropertiesPlugin");
+    SKGTRACEINFUNC(10);
 
     // Get list of bills
     m_billsProcess.setStandardOutputFile(QDir::tempPath() % "/skg_bills.csv");
@@ -60,14 +60,16 @@ SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget* iWidget, QObject* iParent, con
 
 SKGPropertiesPlugin::~SKGPropertiesPlugin()
 {
-    SKGTRACEIN(10, "SKGPropertiesPlugin::~SKGPropertiesPlugin");
+    SKGTRACEINFUNC(10);
     m_currentDocument = NULL;
     m_dockWidget = NULL;
     m_dockContent = NULL;
     m_addPropertyMenu = NULL;
     m_addPropertyAction = NULL;
 
-    if (m_billsProcess.state() == QProcess::Running) m_billsProcess.kill();
+    if (m_billsProcess.state() == QProcess::Running) {
+        m_billsProcess.kill();
+    }
 }
 
 void SKGPropertiesPlugin::onBillsRetreived()
@@ -91,7 +93,7 @@ void SKGPropertiesPlugin::onBillsRetreived()
 
 bool SKGPropertiesPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGPropertiesPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
 
     m_currentDocument = iDocument;
@@ -133,7 +135,7 @@ bool SKGPropertiesPlugin::setupActions(SKGDocument* iDocument, const QStringList
 
 void SKGPropertiesPlugin::onAddProperty()
 {
-    SKGTRACEIN(10, "SKGPropertiesPluginDockWidget::onAddProperty");
+    SKGTRACEINFUNC(10);
     SKGError err;
     // Scope for the transaction
     QAction* act = qobject_cast<QAction*>(sender());
@@ -164,7 +166,7 @@ void SKGPropertiesPlugin::onAddProperty()
 
 void SKGPropertiesPlugin::onDownloadAndAddBills()
 {
-    SKGTRACEIN(10, "SKGPropertiesPluginDockWidget::onDownloadAndAddBills");
+    SKGTRACEINFUNC(10);
     SKGError err;
     // Scope for the transaction
     QAction* act = qobject_cast<QAction*>(sender());
@@ -182,11 +184,12 @@ void SKGPropertiesPlugin::onDownloadAndAddBills()
             for (int i = 0; !err && i < nb; ++i) {
                 // Download the files
                 QFile::remove(fileName);
-                QString cmd = "boobill download " % id % " " % fileName;
+                QString cmd = "boobill download " % id % " \"" % fileName % '"';
                 QProcess p;
                 p.start(cmd);
-                if (!p.waitForFinished(60000) || p.exitCode() != 0) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
-                else {
+                if (!p.waitForFinished(60000) || p.exitCode() != 0) {
+                    err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
+                } else {
                     IFOKDO(err, m_currentDocument->stepForward(2 * i))
 
                     IFOKDO(err, selection[i].setProperty(i18nc("Noun", "Bill"), id, fileName))
@@ -246,7 +249,7 @@ void SKGPropertiesPlugin::onShowAddPropertyMenu()
                     act->setSeparator(true);
                 }
 
-                //Add download on going
+                // Add download on going
                 QAction* act = m_addPropertyMenu->addAction(i18nc("Message", "Download list of available bills on going..."));
                 if (act) {
                     act->setEnabled(false);
@@ -313,9 +316,13 @@ void SKGPropertiesPlugin::onShowAddPropertyMenu()
 
 void SKGPropertiesPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGPropertiesPlugin::refresh");
-    if (m_dockContent) m_dockContent->refresh();
-    if (m_addPropertyAction && SKGMainPanel::getMainPanel()) m_addPropertyAction->setEnabled(SKGMainPanel::getMainPanel()->getSelectedObjects().count() > 0);
+    SKGTRACEINFUNC(10);
+    if (m_dockContent) {
+        m_dockContent->refresh();
+    }
+    if (m_addPropertyAction && SKGMainPanel::getMainPanel()) {
+        m_addPropertyAction->setEnabled(SKGMainPanel::getMainPanel()->getSelectedObjects().count() > 0);
+    }
 }
 
 QDockWidget* SKGPropertiesPlugin::getDockWidget()
