@@ -41,8 +41,10 @@
 SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget(SKGDocument* iDocument)
     : SKGWidget(iDocument)
 {
-    SKGTRACEIN(1, "SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -80,17 +82,19 @@ SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget(SKGDocument* iDocum
 
 SKGPropertiesPluginDockWidget::~SKGPropertiesPluginDockWidget()
 {
-    SKGTRACEIN(1, "SKGPropertiesPluginDockWidget::~SKGPropertiesPluginDockWidget");
+    SKGTRACEINFUNC(1);
 }
 
 void SKGPropertiesPluginDockWidget::refresh()
 {
-    SKGTRACEIN(1, "SKGPropertiesPluginDockWidget::refresh");
+    SKGTRACEINFUNC(1);
 
     // Change filter
     SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(ui.kView->model());
     QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(model);
-    if (proxyModel) model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+    if (proxyModel) {
+        model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+    }
 
     if (model) {
         QString filter;
@@ -114,8 +118,9 @@ void SKGPropertiesPluginDockWidget::refresh()
 
                 QString tableName;
                 for (int i = 0; i < nb; ++i) {
-                    if (i > 0) filter += ',';
-                    else {
+                    if (i > 0) {
+                        filter += ',';
+                    } else {
                         tableName = selection.at(i).getRealTable();
                     }
                     filter += '\'' % selection.at(i).getUniqueID() % '\'';
@@ -144,14 +149,16 @@ void SKGPropertiesPluginDockWidget::refresh()
     }
 
     ui.kView->setState("");
-    if (ui.kView->isAutoResized()) ui.kView->resizeColumnsToContentsDelayed();
+    if (ui.kView->isAutoResized()) {
+        ui.kView->resizeColumnsToContentsDelayed();
+    }
 
     onSelectionChanged();
 }
 
 void SKGPropertiesPluginDockWidget::onSelectionChanged()
 {
-    SKGTRACEIN(10, "SKGPropertiesPluginDockWidget::onSelectionChanged");
+    SKGTRACEINFUNC(10);
     int nbSelected = getNbSelectedObjects();
     ui.kPicture->hide();
     ui.kOpenBtn->hide();
@@ -204,12 +211,14 @@ void SKGPropertiesPluginDockWidget::onSelectionChanged()
         }
     }
 
-    if (ui.kView->isAutoResized()) ui.kView->resizeColumnsToContentsDelayed();
+    if (ui.kView->isAutoResized()) {
+        ui.kView->resizeColumnsToContentsDelayed();
+    }
 }
 
 void SKGPropertiesPluginDockWidget::onOpenFile()
 {
-    SKGTRACEIN(10, "SKGPropertiesPluginDockWidget::onOpenFile");
+    SKGTRACEINFUNC(10);
     int nbSelected = getNbSelectedObjects();
     if (nbSelected > 0) {
         SKGObjectBase::SKGListSKGObjectBase objs = getSelectedObjects();
@@ -247,12 +256,14 @@ void SKGPropertiesPluginDockWidget::onOpenFile()
         }
     }
 
-    if (ui.kView->isAutoResized()) ui.kView->resizeColumnsToContentsDelayed();
+    if (ui.kView->isAutoResized()) {
+        ui.kView->resizeColumnsToContentsDelayed();
+    }
 }
 
 void SKGPropertiesPluginDockWidget::onAddProperty()
 {
-    SKGTRACEIN(10, "SKGPropertiesPluginDockWidget::onAddProperty");
+    SKGTRACEINFUNC(10);
     SKGError err;
     QStringList listUUID;
     // Scope for the transaction
@@ -268,7 +279,9 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
                        KGuiItem(i18nc("Question", "Copy") , "edit-copy"),
                        KGuiItem(i18nc("Question", "Link") , "edit-link"));
 
-            if (mode == KMessageBox::Cancel) return;
+            if (mode == KMessageBox::Cancel) {
+                return;
+            }
             if (mode == KMessageBox::Yes) {
                 // Value is a file name ==> blob
                 if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) {
@@ -315,7 +328,7 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
 
 void SKGPropertiesPluginDockWidget::onRenameProperty()
 {
-    SKGTRACEIN(10, "SKGPropertiesPluginDockWidget::onRenameProperty");
+    SKGTRACEINFUNC(10);
     SKGError err;
     QStringList listUUID;
     // Scope for the transaction
@@ -353,7 +366,7 @@ void SKGPropertiesPluginDockWidget::onSelectFile()
 void SKGPropertiesPluginDockWidget::onRemoveProperty()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGPropertiesPluginDockWidget::onRemoveProperty", err);
+    SKGTRACEINFUNCRC(10, err);
     {
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
         int nb = selection.count();
