@@ -50,7 +50,7 @@ K_EXPORT_PLUGIN(SKGImportPluginBackendFactory("skrooge_import_backend", "skrooge
 SKGImportPluginBackend::SKGImportPluginBackend(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginBackend::SKGImportPluginBackend");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 
     foreach(const QString & file, KStandardDirs().findAllResources("data", "skrooge/backends/*.backend")) {
@@ -63,14 +63,14 @@ SKGImportPluginBackend::~SKGImportPluginBackend()
 
 bool SKGImportPluginBackend::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginBackend::isImportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_listBackends.contains(m_importer->getFileNameExtension()));
 }
 
 struct download {
     download(int iNbToDownload, const QString& iCmd, const QString& iPwd)
-        : m_nbToDownload(iNbToDownload), m_cmd(iCmd), m_pwd(iPwd)
-    {}
+        : m_nbToDownload(iNbToDownload), m_cmd(iCmd), m_pwd(iPwd) {
+    }
 
     typedef QString result_type;
 
@@ -86,7 +86,9 @@ struct download {
             QProcess p;
             p.setStandardOutputFile(file);
             p.start(cmd);
-            if (p.waitForFinished(1000 * 60 * 2) && p.exitCode() == 0) return iAccountId;
+            if (p.waitForFinished(1000 * 60 * 2) && p.exitCode() == 0) {
+                return iAccountId;
+            }
             ++retry;
         } while (retry < 6);
         return "";
@@ -99,9 +101,11 @@ struct download {
 
 SKGError SKGImportPluginBackend::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginBackend::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
     SKGBEGINPROGRESSTRANSACTION(*m_importer->getDocument(), i18nc("Noun, name of the user action", "Import with %1", "Backend"), err, 3);
     QHash< QString, QString > properties;
@@ -120,11 +124,13 @@ SKGError SKGImportPluginBackend::importFile()
         QProcess p;
         p.setStandardOutputFile(csvfile);
         p.start(cmd);
-        if (!p.waitForFinished(1000 * 60 * 2) || p.exitCode() != 0) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
-        else {
+        if (!p.waitForFinished(1000 * 60 * 2) || p.exitCode() != 0) {
+            err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
+        } else {
             QFile file(csvfile);
-            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", csvfile));
-            else {
+            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", csvfile));
+            } else {
                 QRegExp reggetaccounts(properties["getaccountid"]);
                 QRegExp reggetaccountbalance(properties["getaccountbalance"]);
 
@@ -143,8 +149,9 @@ SKGError SKGImportPluginBackend::importFile()
 
                             // Get account balance
                             pos = reggetaccountbalance.indexIn(line);
-                            if (pos > -1) backendAccountsBalance[accountid] = reggetaccountbalance.cap(1);
-                            else {
+                            if (pos > -1) {
+                                backendAccountsBalance[accountid] = reggetaccountbalance.cap(1);
+                            } else {
                                 backendAccountsBalance[accountid] = '0';
                             }
                         }
@@ -164,21 +171,22 @@ SKGError SKGImportPluginBackend::importFile()
         // Download operations
         IFOKDO(err, m_importer->getDocument()->stepForward(1, i18nc("Progress message", "Download operations")))
         IFOK(err) {
-            if (backendAccounts.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Your backend '%1' seems to be not well configure because no account has been found.", bankendName));
-            else {
+            if (backendAccounts.isEmpty()) {
+                err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Your backend '%1' seems to be not well configure because no account has been found.", bankendName));
+            } else {
                 // Download qif file
                 QDate lastDownload = SKGServices::stringToTime(m_importer->getDocument()->getParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_DATE")).date();
                 QString lastList = m_importer->getDocument()->getParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_LIST");
                 QString currentList = backendAccounts.join(";");
 
                 int nbToDownload = 0;
-                if (currentList != lastList) nbToDownload = 99999;
-                else {
+                if (currentList != lastList) {
+                    nbToDownload = 99999;
+                } else {
                     nbToDownload = qMax(lastDownload.daysTo(QDate::currentDate()) * 10, 20);
                 }
                 QStringList listDownloadedId;
                 {
-                    SKGTRACEINRC(10, "SKGImportExportPlugin::importbackend-download", err);
                     QFuture<QString> f = QtConcurrent::mapped(backendAccounts, download(nbToDownload, properties["getoperations"], pwd));
                     f.waitForFinished();
                     listDownloadedId = f.results();
@@ -225,7 +233,9 @@ SKGError SKGImportPluginBackend::importFile()
                         newParameters["columns_positions"] = properties["csvcolumns"];
                         newParameters["mode_csv_unit"] = 'N';
                         newParameters["balance"] = backendAccountsBalance[listDownloadedId.at(i)];
-                        if (i != nb - 1) newParameters["donotfinalize"] = 'Y';
+                        if (i != nb - 1) {
+                            newParameters["donotfinalize"] = 'Y';
+                        }
                         imp1.setImportParameters(newParameters);
                         IFOKDO(err, imp1.importFile())
 
@@ -236,8 +246,9 @@ SKGError SKGImportPluginBackend::importFile()
                     // Reset message
                     IFOKDO(err, m_importer->getDocument()->removeMessages(m_importer->getDocument()->getCurrentTransaction()))
                     int nbm = messages.count();
-                    for (int j = 0; j < nbm; ++j)
+                    for (int j = 0; j < nbm; ++j) {
                         m_importer->getDocument()->sendMessage(messages.at(j), types.at(j));
+                    }
 
                     IFOKDO(err, m_importer->getDocument()->setParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_DATE", SKGServices::dateToSqlString(QDateTime::currentDateTime())))
                     IFOKDO(err, m_importer->getDocument()->setParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_LIST", currentList))
