@@ -42,7 +42,7 @@ K_EXPORT_PLUGIN(SKGImportPluginJsonFactory("skrooge_import_json", "skrooge_impor
 SKGImportPluginJson::SKGImportPluginJson(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginJson::SKGImportPluginJson");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 }
 
@@ -52,7 +52,7 @@ SKGImportPluginJson::~SKGImportPluginJson()
 
 bool SKGImportPluginJson::isExportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::isExportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_importer->getFileNameExtension() == "JSON");
 }
 
@@ -63,10 +63,13 @@ SKGError SKGImportPluginJson::exportFile()
     err = m_importer->getDocument()->copyToJson(doc);
     IFOK(err) {
         KSaveFile file(m_importer->getLocalFileName(false));
-        if (!file.open())err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
-        else {
+        if (!file.open()) {
+            err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
+        } else {
             QTextStream stream(&file);
-            if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
+            if (!m_importer->getCodec().isEmpty()) {
+                stream.setCodec(m_importer->getCodec().toAscii().constData());
+            }
             stream << doc << endl;
         }
 
