@@ -564,9 +564,9 @@ SKGError SKGImportPluginKmy::importAccounts(SKGBankObject& bank, SKGAccountObjec
                     }
                 }
                 IFOKDO(err, accountObj.save())
-                
+
                 // Change parent bank in case of ASSETS
-                if(accountObj.getType() == SKGAccountObject::WALLET) {
+                if (accountObj.getType() == SKGAccountObject::WALLET) {
                     // Get blank bank
                     SKGBankObject blankBank(m_importer->getDocument());
                     IFOKDO(err, blankBank.setName(""))
@@ -574,10 +574,10 @@ SKGError SKGImportPluginKmy::importAccounts(SKGBankObject& bank, SKGAccountObjec
                         err = blankBank.load();
                     } else {
                         err = blankBank.save();
-                    }                                            
+                    }
                     IFOKDO(err, accountObj.setBank(blankBank))
-                    IFOKDO(err, accountObj.save())                                      
-                }                
+                    IFOKDO(err, accountObj.save())
+                }
 
                 m_mapIdAccount[account.attribute("id")] = accountObj;
             } else if (type != "16") {
@@ -618,13 +618,15 @@ SKGError SKGImportPluginKmy::importAccounts(SKGBankObject& bank, SKGAccountObjec
                 }
             }
 
-            foreach(const QString & i, type15Account.keys()) {
-                m_mapIdAccount[i] = m_mapIdAccount[type15Account[i]];
+            QStringList list = type15Account.keys();
+            foreach(const QString & k, list) {
+                m_mapIdAccount[k] = m_mapIdAccount[type15Account[k]];
                 m_mapIdUnit[account.attribute("id")] = m_mapIdUnit[account.attribute("currency")];
             }
 
-            foreach(const QString & i, type15Unit.keys()) {
-                m_mapIdUnit[i] = m_mapIdUnit[type15Unit[i]];
+            list = type15Unit.keys();
+            foreach(const QString & k, list) {
+                m_mapIdUnit[k] = m_mapIdUnit[type15Unit[k]];
             }
 
             IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
