@@ -134,8 +134,7 @@ SKGError SKGImportPluginMny::importFile()
 
     // Check install
     if (KStandardDirs::findExe("java").isEmpty()) {
-        err.setReturnCode(ERR_INSTALL).setMessage(i18nc("Error message",  "The java application is not installed"));
-        err.setProperty("application", "java");
+        err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "The java application is not installed. You must manually install it."));
         return err;
     }
 
