@@ -45,7 +45,7 @@ K_EXPORT_PLUGIN(SKGImportPluginMT940Factory("skrooge_import_mt940", "skrooge_imp
 SKGImportPluginMT940::SKGImportPluginMT940(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginMT940::SKGImportPluginMT940");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 }
 
@@ -55,15 +55,17 @@ SKGImportPluginMT940::~SKGImportPluginMT940()
 
 bool SKGImportPluginMT940::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginMT940::isImportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_importer->getFileNameExtension() == "MT940");
 }
 
 SKGError SKGImportPluginMT940::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportMt940::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
     // Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MT940"), 2);
@@ -71,17 +73,22 @@ SKGError SKGImportPluginMT940::importFile()
         // Open file
         IFOK(err) {
             QFile file(m_importer->getLocalFileName());
-            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-            else {
+            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+            } else {
                 // Read lines
                 QStringList lines;
                 {
                     QTextStream stream(&file);
-                    if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
+                    if (!m_importer->getCodec().isEmpty()) {
+                        stream.setCodec(m_importer->getCodec().toAscii().constData());
+                    }
                     while (!stream.atEnd()) {
                         // Read line
                         QString line = stream.readLine().trimmed();
-                        if (!line.isEmpty())  lines.push_back(line);
+                        if (!line.isEmpty()) {
+                            lines.push_back(line);
+                        }
                     }
                 }
                 // close file
@@ -132,17 +139,23 @@ SKGError SKGImportPluginMT940::importFile()
                                         account = listAccount.at(0);
                                         err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Using account '%1' for import", account.getName()));
                                     } else {
-                                        if (listAccount.count() > 1) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "More than one possible account found."));
+                                        if (listAccount.count() > 1) {
+                                            err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "More than one possible account found."));
+                                        }
 
                                         SKGBankObject bank(m_importer->getDocument());
                                         IFOKDO(err, bank.setName(bankName))
                                         IFOKDO(err, bank.setNumber(bankName))
-                                        if (!err && bank.load().isFailed()) err = bank.save();
+                                        if (!err && bank.load().isFailed()) {
+                                            err = bank.save();
+                                        }
                                         IFOKDO(err, bank.addAccount(account))
                                         IFOKDO(err, account.setName(name))
                                         IFOKDO(err, account.setNumber(number))
                                         IFOKDO(err, account.setType(SKGAccountObject::CURRENT))
-                                        if (!err && account.load().isFailed()) err = account.save();
+                                        if (!err && account.load().isFailed()) {
+                                            err = account.save();
+                                        }
                                         IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Default account '%1' created for import", name)))
                                     }
                                 }
@@ -170,13 +183,17 @@ SKGError SKGImportPluginMT940::importFile()
                                 // Example :61:0712280103D000000000200,00FMSCNONREF
                                 QString val = line.right(line.count() - 4);
                                 QDate date = QDate::fromString(val.left(6), "yyMMdd");
-                                if (date.year() < 1970) date = date.addYears(100);
+                                if (date.year() < 1970) {
+                                    date = date.addYears(100);
+                                }
 
                                 int index = (val[10] == 'R' ? 11 : 10);
                                 double sign = (val[index] == 'C' ? 1.0 : -1.0);
                                 ++index;
 
-                                if (val[index] == 'R')  ++index;
+                                if (val[index] == 'R') {
+                                    ++index;
+                                }
 
                                 QString amountString;
                                 while (true) {
