@@ -47,7 +47,7 @@ K_EXPORT_PLUGIN(SKGImportPluginOfxFactory("skrooge_import_ofx", "skrooge_import_
 SKGImportPluginOfx::SKGImportPluginOfx(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginOfx::SKGImportPluginOfx");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 }
 
@@ -57,18 +57,22 @@ SKGImportPluginOfx::~SKGImportPluginOfx()
 
 bool SKGImportPluginOfx::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginOfx::isImportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_importer->getFileNameExtension() == "OFX" || m_importer->getFileNameExtension() == "QFX");
 }
 
 SKGError SKGImportPluginOfx::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
 
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginOfx::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
-    if (!QFile(m_importer->getLocalFileName()).exists()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    if (!QFile(m_importer->getLocalFileName()).exists()) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    }
     IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX")))
     IFOK(err) {
         SKGImportPluginOfx::m_ofxError = SKGError();
@@ -82,7 +86,9 @@ SKGError SKGImportPluginOfx::importFile()
             ofx_set_transaction_cb(ctx, SKGImportPluginOfx::ofxTransactionCallback, m_importer);
             // ofx_set_security_cb(ctx, ofxSecurityCallback, this);
             int rc = libofx_proc_file(ctx, m_importer->getLocalFileName().toUtf8(), AUTODETECT);
-            if (rc)  err = SKGError(ERR_FAIL, i18nc("Error message",  "Import OFX file '%1' failed", m_importer->getFileName().prettyUrl()));
+            if (rc) {
+                err = SKGError(ERR_FAIL, i18nc("Error message",  "Import OFX file '%1' failed", m_importer->getFileName().prettyUrl()));
+            }
             IFOKDO(err, SKGImportPluginOfx::m_ofxError) {
                 // This is an option ==> no error management
                 SKGError err2;
@@ -92,22 +98,32 @@ SKGError SKGImportPluginOfx::importFile()
 
                     // Get account
                     SKGAccountObject act;
-                    if (!err2) err2 = getAccount(data.account_ptr, m_importer->getDocument(), act);
+                    if (!err2) {
+                        err2 = getAccount(data.account_ptr, m_importer->getDocument(), act);
+                    }
 
                     // Date of balance
                     QDate date = (data.ledger_balance_date_valid == true ? QDateTime::fromTime_t(data.ledger_balance_date).date() : QDate::currentDate());
 
                     // Get unit
                     SKGUnitObject unit;
-                    if (!err2) err2 = m_importer->getDefaultUnit(unit);
+                    if (!err2) {
+                        err2 = m_importer->getDefaultUnit(unit);
+                    }
 
                     // Current amount
                     double currentAmount = act.getAmount(date);
 
                     // Update account
-                    if (!err2) err2 = act.setInitialBalance(data.ledger_balance - currentAmount, unit);
-                    if (!err2) err2 = act.save();
-                    if (!err2) err2 = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", act.getName()));
+                    if (!err2) {
+                        err2 = act.setInitialBalance(data.ledger_balance - currentAmount, unit);
+                    }
+                    if (!err2) {
+                        err2 = act.save();
+                    }
+                    if (!err2) {
+                        err2 = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", act.getName()));
+                    }
                 }
             }
         } catch (...) {  // NOLINT(whitespace/parens)
@@ -133,7 +149,9 @@ SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumen
     if (accountNumber.startsWith(bankNumber % ' ')) {
         accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
         QStringList splitNumbers = accountNumber.split(' ');
-        if (splitNumbers.count() == 2) accountNumber = splitNumbers.at(1);
+        if (splitNumbers.count() == 2) {
+            accountNumber = splitNumbers.at(1);
+        }
     }
 
     // Check if account is already existing
@@ -144,13 +162,19 @@ SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumen
 
 int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void* pv)
 {
-    if (SKGImportPluginOfx::m_ofxError) return 0;
-    SKGTRACEINRC(5, "SKGImportPluginOfx::ofxStatementCallback", SKGImportPluginOfx::m_ofxError);
+    if (SKGImportPluginOfx::m_ofxError) {
+        return 0;
+    }
+    SKGTRACEINFUNCRC(5, SKGImportPluginOfx::m_ofxError);
 
     SKGImportExportManager* impotExporter = static_cast<SKGImportExportManager*>(pv);
-    if (!impotExporter) return 0;
+    if (!impotExporter) {
+        return 0;
+    }
     SKGDocumentBank* doc = impotExporter->getDocument();
-    if (!doc) return 0;
+    if (!doc) {
+        return 0;
+    }
 
     // // Get data
     OfxAccountData* accountData = data.account_ptr;
@@ -172,13 +196,19 @@ int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void*
 
 int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
 {
-    if (SKGImportPluginOfx::m_ofxError) return 0;
-    SKGTRACEINRC(5, "SKGImportPluginOfx::ofxAccountCallback", SKGImportPluginOfx::m_ofxError);
+    if (SKGImportPluginOfx::m_ofxError) {
+        return 0;
+    }
+    SKGTRACEINFUNCRC(5, SKGImportPluginOfx::m_ofxError);
 
     SKGImportExportManager* impotExporter = static_cast<SKGImportExportManager*>(pv);
-    if (!impotExporter) return 0;
+    if (!impotExporter) {
+        return 0;
+    }
     SKGDocumentBank* doc = impotExporter->getDocument();
-    if (!doc) return 0;
+    if (!doc) {
+        return 0;
+    }
 
     SKGObjectBase tmp;
     if (data.account_id_valid == true) {
@@ -219,22 +249,37 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
                     // Create new bank
                     bank = SKGBankObject(doc);
                     SKGImportPluginOfx::m_ofxError = bank.setName(bankId);
-                    if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = bank.setNumber(QString::fromUtf8(data.bank_id));
-                    if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = bank.save();
+                    if (!SKGImportPluginOfx::m_ofxError) {
+                        SKGImportPluginOfx::m_ofxError = bank.setNumber(QString::fromUtf8(data.bank_id));
+                    }
+                    if (!SKGImportPluginOfx::m_ofxError) {
+                        SKGImportPluginOfx::m_ofxError = bank.save();
+                    }
                 }
 
                 // Create new account
                 QString name = QString::fromUtf8(data.account_name);
-                if (name.isEmpty()) name = QString::fromUtf8(data.account_id);
-                else {
+                if (name.isEmpty()) {
+                    name = QString::fromUtf8(data.account_id);
+                } else {
                     name = name.remove("Bank account ");
                 }
 
-                if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = bank.addAccount(account);
-                if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.setName(name);
-                if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.setNumber(accountNumber);
-                if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.setAgencyNumber(agencyNumber);
-                if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.setComment(QString::fromUtf8(data.account_name));
+                if (!SKGImportPluginOfx::m_ofxError) {
+                    SKGImportPluginOfx::m_ofxError = bank.addAccount(account);
+                }
+                if (!SKGImportPluginOfx::m_ofxError) {
+                    SKGImportPluginOfx::m_ofxError = account.setName(name);
+                }
+                if (!SKGImportPluginOfx::m_ofxError) {
+                    SKGImportPluginOfx::m_ofxError = account.setNumber(accountNumber);
+                }
+                if (!SKGImportPluginOfx::m_ofxError) {
+                    SKGImportPluginOfx::m_ofxError = account.setAgencyNumber(agencyNumber);
+                }
+                if (!SKGImportPluginOfx::m_ofxError) {
+                    SKGImportPluginOfx::m_ofxError = account.setComment(QString::fromUtf8(data.account_name));
+                }
                 SKGAccountObject::AccountType type = SKGAccountObject::CURRENT;
                 if (data.account_type_valid == true) {
                     switch (data.account_type) {
@@ -256,10 +301,16 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
                     }
                 }
 
-                if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.setType(type);
-                if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.save();
+                if (!SKGImportPluginOfx::m_ofxError) {
+                    SKGImportPluginOfx::m_ofxError = account.setType(type);
+                }
+                if (!SKGImportPluginOfx::m_ofxError) {
+                    SKGImportPluginOfx::m_ofxError = account.save();
+                }
 
-                if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultAccount(&account);
+                if (!SKGImportPluginOfx::m_ofxError) {
+                    SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultAccount(&account);
+                }
 
                 SKGTRACEL(10) << "Account [" << name << "] created" << endl;
             }
@@ -276,10 +327,16 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
         } else {
             // Create new account
             SKGImportPluginOfx::m_ofxError = unit.setName(QString::fromUtf8(data.currency));
-            if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = unit.setSymbol(QString::fromUtf8(data.currency));
-            if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = unit.save();
+            if (!SKGImportPluginOfx::m_ofxError) {
+                SKGImportPluginOfx::m_ofxError = unit.setSymbol(QString::fromUtf8(data.currency));
+            }
+            if (!SKGImportPluginOfx::m_ofxError) {
+                SKGImportPluginOfx::m_ofxError = unit.save();
+            }
 
-            if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultUnit(&unit);
+            if (!SKGImportPluginOfx::m_ofxError) {
+                SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultUnit(&unit);
+            }
         }
     }
     return SKGImportPluginOfx::m_ofxError.getReturnCode();
@@ -287,13 +344,19 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
 
 int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, void* pv)
 {
-    if (SKGImportPluginOfx::m_ofxError) return 0;
-    SKGTRACEINRC(5, "SKGImportPluginOfx::ofxTransactionCallback", SKGImportPluginOfx::m_ofxError);
+    if (SKGImportPluginOfx::m_ofxError) {
+        return 0;
+    }
+    SKGTRACEINFUNCRC(5, SKGImportPluginOfx::m_ofxError);
 
     SKGImportExportManager* impotExporter = static_cast<SKGImportExportManager*>(pv);
-    if (!impotExporter) return 0;
+    if (!impotExporter) {
+        return 0;
+    }
     SKGDocumentBank* doc = impotExporter->getDocument();
-    if (!doc) return 0;
+    if (!doc) {
+        return 0;
+    }
 
     // Get account
     SKGAccountObject account;
@@ -309,37 +372,61 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
         // Create id
         QString ID;
         if (data.fi_id_valid == true) {
-            if (QString::fromUtf8(data.fi_id).count('0') != QString::fromUtf8(data.fi_id).count()) ID = QString("ID-") % QString::fromUtf8(data.fi_id);
+            if (QString::fromUtf8(data.fi_id).count('0') != QString::fromUtf8(data.fi_id).count()) {
+                ID = QString("ID-") % QString::fromUtf8(data.fi_id);
+            }
         } else if (data.reference_number_valid == true) {
-            if (QString::fromUtf8(data.reference_number).count('0') != QString::fromUtf8(data.reference_number).count()) ID = QString("REF-") % data.reference_number;
+            if (QString::fromUtf8(data.reference_number).count('0') != QString::fromUtf8(data.reference_number).count()) {
+                ID = QString("REF-") % data.reference_number;
+            }
         }
 
         // Create operation
         SKGOperationObject ope;
-        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.addOperation(ope, true);
-        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.setDate(date);
-        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.setUnit(unit);
-        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.setAttribute("t_imported", "T");
-        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.setImportID(ID);
+        if (!SKGImportPluginOfx::m_ofxError) {
+            SKGImportPluginOfx::m_ofxError = account.addOperation(ope, true);
+        }
+        if (!SKGImportPluginOfx::m_ofxError) {
+            SKGImportPluginOfx::m_ofxError = ope.setDate(date);
+        }
+        if (!SKGImportPluginOfx::m_ofxError) {
+            SKGImportPluginOfx::m_ofxError = ope.setUnit(unit);
+        }
+        if (!SKGImportPluginOfx::m_ofxError) {
+            SKGImportPluginOfx::m_ofxError = ope.setAttribute("t_imported", "T");
+        }
+        if (!SKGImportPluginOfx::m_ofxError) {
+            SKGImportPluginOfx::m_ofxError = ope.setImportID(ID);
+        }
         if (!SKGImportPluginOfx::m_ofxError) {
             QString payeeName;
-            if (data.payee_id_valid == true) payeeName = QString::fromUtf8(data.payee_id);
-            else if (data.name_valid == true) {
+            if (data.payee_id_valid == true) {
+                payeeName = QString::fromUtf8(data.payee_id);
+            } else if (data.name_valid == true) {
                 payeeName = QString::fromUtf8(data.name);
             }
             if (!payeeName.isEmpty()) {
                 SKGPayeeObject payeeObj;
                 SKGImportPluginOfx::m_ofxError = SKGPayeeObject::createPayee(doc, payeeName, payeeObj);
-                if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.setPayee(payeeObj);
+                if (!SKGImportPluginOfx::m_ofxError) {
+                    SKGImportPluginOfx::m_ofxError = ope.setPayee(payeeObj);
+                }
             }
         }
-        if (!SKGImportPluginOfx::m_ofxError && data.memo_valid == true) SKGImportPluginOfx::m_ofxError = ope.setComment(QString::fromUtf8(data.memo));
-        if (!SKGImportPluginOfx::m_ofxError && data.check_number_valid == true) SKGImportPluginOfx::m_ofxError = ope.setNumber(SKGServices::stringToInt(data.check_number));
-        if (!SKGImportPluginOfx::m_ofxError && data.invtransactiontype_valid == true) SKGImportPluginOfx::m_ofxError = ope.setMode(i18nc("Noun, the title of an item", "Title"));
+        if (!SKGImportPluginOfx::m_ofxError && data.memo_valid == true) {
+            SKGImportPluginOfx::m_ofxError = ope.setComment(QString::fromUtf8(data.memo));
+        }
+        if (!SKGImportPluginOfx::m_ofxError && data.check_number_valid == true) {
+            SKGImportPluginOfx::m_ofxError = ope.setNumber(SKGServices::stringToInt(data.check_number));
+        }
+        if (!SKGImportPluginOfx::m_ofxError && data.invtransactiontype_valid == true) {
+            SKGImportPluginOfx::m_ofxError = ope.setMode(i18nc("Noun, the title of an item", "Title"));
+        }
         if (!SKGImportPluginOfx::m_ofxError && data.transactiontype_valid == true) {
             QString mode;
-            if (data.transactiontype == OFX_CREDIT) mode = i18nc("Noun, type of OFX transaction", "Credit");
-            else if (data.transactiontype == OFX_DEBIT) {
+            if (data.transactiontype == OFX_CREDIT) {
+                mode = i18nc("Noun, type of OFX transaction", "Credit");
+            } else if (data.transactiontype == OFX_DEBIT) {
                 mode = i18nc("Noun, type of OFX transaction", "Debit");
             } else if (data.transactiontype == OFX_INT) {
                 mode = i18nc("Noun, type of OFX transaction", "Interest");
@@ -373,23 +460,41 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
 
             SKGImportPluginOfx::m_ofxError = ope.setMode(mode);
         }
-        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.save();
+        if (!SKGImportPluginOfx::m_ofxError) {
+            SKGImportPluginOfx::m_ofxError = ope.save();
+        }
 
         // Create sub operation
         SKGSubOperationObject subop;
-        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.addSubOperation(subop);
-        if (!SKGImportPluginOfx::m_ofxError && data.amount_valid == true) SKGImportPluginOfx::m_ofxError = subop.setQuantity(data.amount + (data.commission_valid == true ? data.commission : 0));
-        if (!SKGImportPluginOfx::m_ofxError && data.memo_valid == true) SKGImportPluginOfx::m_ofxError = subop.setComment(QString::fromUtf8(data.memo));
-        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = subop.save();
+        if (!SKGImportPluginOfx::m_ofxError) {
+            SKGImportPluginOfx::m_ofxError = ope.addSubOperation(subop);
+        }
+        if (!SKGImportPluginOfx::m_ofxError && data.amount_valid == true) {
+            SKGImportPluginOfx::m_ofxError = subop.setQuantity(data.amount + (data.commission_valid == true ? data.commission : 0));
+        }
+        if (!SKGImportPluginOfx::m_ofxError && data.memo_valid == true) {
+            SKGImportPluginOfx::m_ofxError = subop.setComment(QString::fromUtf8(data.memo));
+        }
+        if (!SKGImportPluginOfx::m_ofxError) {
+            SKGImportPluginOfx::m_ofxError = subop.save();
+        }
 
         // Commission
         if (!SKGImportPluginOfx::m_ofxError && data.commission_valid == true && data.amount_valid == true && data.commission > 0) {
             // Create splitter operation
             SKGSubOperationObject subop2;
-            if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.addSubOperation(subop2);
-            if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = subop2.setComment(i18nc("Noun, a quantity of money taken by a financial institution to perform an operation", "Commission"));
-            if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = subop2.setQuantity(-data.commission);
-            if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = subop2.save();
+            if (!SKGImportPluginOfx::m_ofxError) {
+                SKGImportPluginOfx::m_ofxError = ope.addSubOperation(subop2);
+            }
+            if (!SKGImportPluginOfx::m_ofxError) {
+                SKGImportPluginOfx::m_ofxError = subop2.setComment(i18nc("Noun, a quantity of money taken by a financial institution to perform an operation", "Commission"));
+            }
+            if (!SKGImportPluginOfx::m_ofxError) {
+                SKGImportPluginOfx::m_ofxError = subop2.setQuantity(-data.commission);
+            }
+            if (!SKGImportPluginOfx::m_ofxError) {
+                SKGImportPluginOfx::m_ofxError = subop2.save();
+            }
         }
     }
     return SKGImportPluginOfx::m_ofxError.getReturnCode();
