@@ -668,7 +668,7 @@ SKGError SKGImportPluginQif::importFile()
 //                                            if ( op=='L' && currentOperation.getPayee().compare ( "Opening Balance", Qt::CaseInsensitive ) !=0 && !investmentAccount)
                                         if (op == 'L' && !opening) {
                                             transferAccount = val.mid(1, pos - 1);
-                                            if (transferAccount == account->getName()) {
+                                            if (account && transferAccount == account->getName()) {
                                                 transferAccount = "";
                                             }
                                         }
@@ -791,7 +791,13 @@ SKGError SKGImportPluginQif::importFile()
                             QString checkOperationAmountString = SKGServices::doubleToString(checkOperationAmount);
                             QString checkSuboperationsAmountString = SKGServices::doubleToString(checkSuboperationsAmount);
                             if (!err && checkOperationAmount != 0 && checkSuboperationsAmount != 0 && checkOperationAmountString != checkSuboperationsAmountString) {
-                                err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "The total amount of the operation (%1) is different to the sum of the sub-operations (%2).", checkOperationAmountString, checkSuboperationsAmountString), SKGDocument::Warning);
+                                SKGSubOperationObject suboprepair;
+                                IFOKDO(err, currentOperation.addSubOperation(suboprepair))
+                                IFOKDO(err, suboprepair.setQuantity(checkOperationAmount - checkSuboperationsAmount))
+                                IFOKDO(err, suboprepair.setComment(i18nc("An information message",  "Auto repaired operation")))
+                                IFOKDO(err, suboprepair.save())
+
+                                IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "The total amount of the operation (%1) was different to the sum of the sub-operations (%2). The operation has been repaired.", checkOperationAmountString, checkSuboperationsAmountString), SKGDocument::Warning));
                             }
 
                             // Initialize variables
