@@ -47,7 +47,7 @@ K_EXPORT_PLUGIN(SKGImportPluginSkgFactory("skrooge_import_skg", "skrooge_import_
 SKGImportPluginSkg::SKGImportPluginSkg(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginSkg::SKGImportPluginSkg");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 
     m_parameters["password"] = "";
@@ -59,18 +59,21 @@ SKGImportPluginSkg::~SKGImportPluginSkg()
 
 bool SKGImportPluginSkg::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginSkg::isImportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_importer->getFileNameExtension() == "SKG" || m_importer->getFileNameExtension() == "SQLITE");
 }
 
 SKGError SKGImportPluginSkg::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginSkg::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
     QString lfile = m_importer->getLocalFileName();
-    if (lfile.isEmpty()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    else {
+    if (lfile.isEmpty()) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    } else {
         SKGDocumentBank docOrigin;
         err = docOrigin.load(lfile, m_parameters["password"]);
         IFOK(err) {
@@ -91,7 +94,9 @@ SKGError SKGImportPluginSkg::importFile()
                             // This unit does not exist yet
                             IFOK(err) {
                                 SKGUnitObject::UnitType unitType = unitOrigin.getType();
-                                if (unitType == SKGUnitObject::PRIMARY || unitType == SKGUnitObject::SECONDARY) unitType = SKGUnitObject::CURRENCY;
+                                if (unitType == SKGUnitObject::PRIMARY || unitType == SKGUnitObject::SECONDARY) {
+                                    unitType = SKGUnitObject::CURRENCY;
+                                }
                                 err = unit.setType(unitType);
                             }
                             IFOK(err) {
@@ -99,7 +104,9 @@ SKGError SKGImportPluginSkg::importFile()
                                 unitOrigin.getUnit(parentUnitOrigin);
 
                                 SKGUnitObject parentUnit(mapOriginNew[parentUnitOrigin.getUniqueID()]);
-                                if (parentUnit != unit) err = unit.setUnit(parentUnit);
+                                if (parentUnit != unit) {
+                                    err = unit.setUnit(parentUnit);
+                                }
                             }
                             IFOKDO(err, unit.save(false))
                         }
@@ -282,7 +289,9 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, operation.setImported(true))
                         IFOK(err) {
                             QString importID = operationOrigin.getImportID();
-                            if (importID.isEmpty()) importID = "SKG-" % SKGServices::intToString(operationOrigin.getID());
+                            if (importID.isEmpty()) {
+                                importID = "SKG-" % SKGServices::intToString(operationOrigin.getID());
+                            }
                             err = operation.setImportID(importID);
                         }
                         IFOK(err) {
@@ -342,7 +351,9 @@ SKGError SKGImportPluginSkg::importFile()
                         }
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
 
-                        if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        if (!err && i % 500 == 0) {
+                            err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        }
                     }
 
                     SKGENDTRANSACTION(m_importer->getDocument(),  err);
@@ -443,15 +454,17 @@ SKGError SKGImportPluginSkg::importFile()
 
 bool SKGImportPluginSkg::isExportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::isExportPossible");
+    SKGTRACEINFUNC(10);
     return isImportPossible();
 }
 
 SKGError SKGImportPluginSkg::exportFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginSkg::exportFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
     QString tempFile = m_importer->getDocument()->getCurrentTemporaryFile();
     if (m_importer->getDocument()->getCurrentFileName().isEmpty()) {
@@ -478,7 +491,9 @@ SKGError SKGImportPluginSkg::exportFile()
     QString file = m_importer->getLocalFileName(false);
     QFile::remove(file);
     if (QFileInfo(file).suffix().toUpper() == "SQLITE") {
-        if (SKGServices::upload(tempFile, file)) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Creation file '%1' failed", file));
+        if (SKGServices::upload(tempFile, file)) {
+            err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Creation file '%1' failed", file));
+        }
     } else {
         err = SKGServices::cryptFile(tempFile, file, "", true, m_importer->getDocument()->getDocumentHeader());
         IFOK(err) {
@@ -489,7 +504,9 @@ SKGError SKGImportPluginSkg::exportFile()
         }
     }
 
-    if (m_importer->getDocument()->getCurrentFileName().isEmpty())  QFile(tempFile).remove();
+    if (m_importer->getDocument()->getCurrentFileName().isEmpty()) {
+        QFile(tempFile).remove();
+    }
 
     return err;
 }
