@@ -51,22 +51,24 @@ SKGBankPlugin::SKGBankPlugin(QWidget* iWidget, QObject* iParent, const QVariantL
     : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_reconciliateAction(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGBankPlugin::SKGBankPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGBankPlugin::~SKGBankPlugin()
 {
-    SKGTRACEIN(10, "SKGBankPlugin::~SKGBankPlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
     m_reconciliateAction = NULL;
 }
 
 bool SKGBankPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGBankPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) return false;
+    if (m_currentBankDocument == NULL) {
+        return false;
+    }
 
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_bank/skrooge_bank.rc");
@@ -86,8 +88,9 @@ int SKGBankPlugin::getNbDashboardWidgets()
 
 QString SKGBankPlugin::getDashboardWidgetTitle(int iIndex)
 {
-    if (iIndex == 0) return i18nc("Noun, a list of bank accounts", "Accounts (Light)");
-    else if (iIndex == 1) {
+    if (iIndex == 0) {
+        return i18nc("Noun, a list of bank accounts", "Accounts (Light)");
+    } else if (iIndex == 1) {
         return i18nc("Noun, a list of bank accounts", "Accounts (Full)");
     } else if (iIndex == 2) {
         return i18nc("Noun, a list of banks", "Banks (Light)");
@@ -97,11 +100,12 @@ QString SKGBankPlugin::getDashboardWidgetTitle(int iIndex)
 
 SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
 {
-    if (iIndex == 0) return new SKGAccountBoardWidget(m_currentBankDocument);
-    else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                     getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", "skrooge/html/default/account_table.html"),
-                                     QStringList() << "v_account_display", true);
+    if (iIndex == 0) {
+        return new SKGAccountBoardWidget(m_currentBankDocument);
+    } else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                       getDashboardWidgetTitle(iIndex),
+                                       KStandardDirs().findResource("data", "skrooge/html/default/account_table.html"),
+                                       QStringList() << "v_account_display", true);
     else if (iIndex == 2) {
         SKGHtmlBoardWidget* w = new SKGHtmlBoardWidget(m_currentBankDocument,
                 getDashboardWidgetTitle(iIndex),
@@ -127,7 +131,7 @@ SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
 
 SKGTabPage* SKGBankPlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGBankPlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGBankPluginWidget(m_currentBankDocument);
 }
 
@@ -167,14 +171,18 @@ bool SKGBankPlugin::isInPagesChooser() const
 
 void SKGBankPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGBankPlugin::refresh");
+    SKGTRACEINFUNC(10);
     if (m_currentBankDocument && SKGMainPanel::getMainPanel()) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         if (selection.count() > 0) {
             bool onAccount = (selection.at(0).getRealTable() == "account");
-            if (m_reconciliateAction) m_reconciliateAction->setEnabled(onAccount);
+            if (m_reconciliateAction) {
+                m_reconciliateAction->setEnabled(onAccount);
+            }
         } else {
-            if (m_reconciliateAction) m_reconciliateAction->setEnabled(false);
+            if (m_reconciliateAction) {
+                m_reconciliateAction->setEnabled(false);
+            }
         }
     }
 }
@@ -194,7 +202,7 @@ void SKGBankPlugin::onReconciliate()
 
 SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGBankPlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
 
     // Get bank without accounts
