@@ -46,21 +46,23 @@ K_EXPORT_PLUGIN(SKGBudgetPluginFactory("skrooge_budget", "skrooge_budget"))
 SKGBudgetPlugin::SKGBudgetPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGBudgetPlugin::SKGBudgetPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGBudgetPlugin::~SKGBudgetPlugin()
 {
-    SKGTRACEIN(10, "SKGBudgetPlugin::~SKGBudgetPlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
 }
 
 bool SKGBudgetPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGBudgetPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) return false;
+    if (m_currentBankDocument == NULL) {
+        return false;
+    }
 
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_budget/skrooge_budget.rc");
@@ -77,7 +79,7 @@ bool SKGBudgetPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
 
 SKGTabPage* SKGBudgetPlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGBudgetPlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGBudgetPluginWidget(m_currentBankDocument);
 }
 
@@ -114,7 +116,7 @@ bool SKGBudgetPlugin::isInPagesChooser() const
 
 SKGAdviceList SKGBudgetPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGBudgetPlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
     QString month = QDate::currentDate().toString("yyyy-MM");
     QString year = QDate::currentDate().toString("yyyy");
@@ -192,7 +194,7 @@ SKGError SKGBudgetPlugin::executeAdviceCorrection(const QString& iAdviceIdentifi
 void SKGBudgetPlugin::onProcessRules()
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGBudgetPlugin::onProcessRules", err);
+    _SKGTRACEINFUNCRC(10, err);
 
     {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Process budget rules")  , err);
