@@ -41,8 +41,10 @@
 SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(1, "SKGCalculatorPluginWidget::SKGCalculatorPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     m_timer.setSingleShot(true);
     connect(&m_timer, SIGNAL(timeout()), this, SLOT(onAmortizationComputation()), Qt::QueuedConnection);
@@ -112,7 +114,7 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
 
 SKGCalculatorPluginWidget::~SKGCalculatorPluginWidget()
 {
-    SKGTRACEIN(1, "SKGCalculatorPluginWidget::~SKGCalculatorPluginWidget");
+    SKGTRACEINFUNC(1);
     m_objectModel = NULL;
 }
 
@@ -134,7 +136,7 @@ bool SKGCalculatorPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 QString SKGCalculatorPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGCalculatorPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -159,7 +161,7 @@ QString SKGCalculatorPluginWidget::getState()
 
 void SKGCalculatorPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGCalculatorPluginWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -173,19 +175,33 @@ void SKGCalculatorPluginWidget::setState(const QString& iState)
     QString amortizationInsuranceRate = root.attribute("amortizationInsuranceRate");
     QString amortizationLenght = root.attribute("amortizationLenght");
 
-    if (!currentPage.isEmpty()) ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
+    if (!currentPage.isEmpty()) {
+        ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
+    }
     if (!account.isEmpty()) {
         bool previous = ui.kDisplayAccountCombo->blockSignals(true);
         ui.kDisplayAccountCombo->setText(account);
         ui.kDisplayAccountCombo->blockSignals(previous);
     }
-    if (!amortizationLoan.isEmpty()) ui.kLoanEdit->setText(amortizationLoan);
-    if (!amortizationUnit.isEmpty()) ui.kUnitEdit->setText(amortizationUnit);
-    if (!amortizationRate.isEmpty()) ui.kAnnualRateEdit->setValue(SKGServices::stringToDouble(amortizationRate));
-    if (!amortizationInsuranceRate.isEmpty()) ui.kInsuranceRateEdit->setValue(SKGServices::stringToDouble(amortizationInsuranceRate));
-    if (!amortizationLenght.isEmpty()) ui.kLenghtEdit->setValue(SKGServices::stringToInt(amortizationLenght));
+    if (!amortizationLoan.isEmpty()) {
+        ui.kLoanEdit->setText(amortizationLoan);
+    }
+    if (!amortizationUnit.isEmpty()) {
+        ui.kUnitEdit->setText(amortizationUnit);
+    }
+    if (!amortizationRate.isEmpty()) {
+        ui.kAnnualRateEdit->setValue(SKGServices::stringToDouble(amortizationRate));
+    }
+    if (!amortizationInsuranceRate.isEmpty()) {
+        ui.kInsuranceRateEdit->setValue(SKGServices::stringToDouble(amortizationInsuranceRate));
+    }
+    if (!amortizationLenght.isEmpty()) {
+        ui.kLenghtEdit->setValue(SKGServices::stringToInt(amortizationLenght));
+    }
 
-    if (!year.isEmpty()) ui.KYearEdit->setText(year);
+    if (!year.isEmpty()) {
+        ui.KYearEdit->setText(year);
+    }
 
     // Update model
     if (m_objectModel) {
@@ -219,7 +235,7 @@ void SKGCalculatorPluginWidget::onBtnModeClicked(int mode)
 
 void SKGCalculatorPluginWidget::onSelectionChanged()
 {
-    SKGTRACEIN(10, "SKGCalculatorPluginWidget::onSelectionChanged");
+    SKGTRACEINFUNC(10);
     // Mapping
     QItemSelectionModel* selModel = ui.kInterestView->selectionModel();
     if (selModel) {
@@ -243,7 +259,7 @@ void SKGCalculatorPluginWidget::onSelectionChanged()
 void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 
 {
-    SKGTRACEIN(10, "SKGCalculatorPluginWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
@@ -252,7 +268,9 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
     setEnabled(db != NULL);
     if (db != NULL && (iTableName == "interest" || iTableName.isEmpty())) {
         // Correction bug 2299394 vvv
-        if (ui.kInterestView->isAutoResized()) ui.kInterestView->resizeColumnsToContentsDelayed();
+        if (ui.kInterestView->isAutoResized()) {
+            ui.kInterestView->resizeColumnsToContentsDelayed();
+        }
         // Correction bug 2299394 ^^^
 
         // Correction 215658: vvv because the table is modified, the selection is modified
@@ -280,7 +298,9 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
         }
 
         int posText = ui.kDisplayAccountCombo->findText(current);
-        if (posText == -1) posText = 0;
+        if (posText == -1) {
+            posText = 0;
+        }
         ui.kDisplayAccountCombo->setCurrentIndex(posText);
 
         ui.kAdd->setEnabled(ui.kDisplayAccountCombo->count() > 0);
@@ -295,13 +315,17 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
 
         QStringList list;
         getDocument()->getDistinctValues("v_operation_display", "d_DATEYEAR", "", list);
-        if (list.count()) firstYear = SKGServices::stringToInt(list.at(0));
+        if (list.count()) {
+            firstYear = SKGServices::stringToInt(list.at(0));
+        }
 
         QString year = ui.KYearEdit->text();
         ui.KYearEdit->clear();
         for (int i = lastYear; i >= firstYear; --i) {
             QString v = SKGServices::intToString(i);
-            if (year.isEmpty()) year = v;
+            if (year.isEmpty()) {
+                year = v;
+            }
             ui.KYearEdit->addItem(v);
         }
 
@@ -346,8 +370,10 @@ void SKGCalculatorPluginWidget::computeInterest()
 
 void SKGCalculatorPluginWidget::onFilterChanged()
 {
-    SKGTRACEIN(1, "SKGCalculatorPluginWidget::onFilterChanged");
-    if (!isEnabled()) return;
+    SKGTRACEINFUNC(1);
+    if (!isEnabled()) {
+        return;
+    }
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     // Compute where clause
@@ -356,7 +382,9 @@ void SKGCalculatorPluginWidget::onFilterChanged()
 
     // Update model
     if (m_objectModel) {
-        if (m_objectModel->setFilter(filter2)) ui.kInterestView->setState(ui.kInterestView->getState());
+        if (m_objectModel->setFilter(filter2)) {
+            ui.kInterestView->setState(ui.kInterestView->getState());
+        }
 
         // Compute result
         computeInterest();
@@ -367,14 +395,18 @@ void SKGCalculatorPluginWidget::onFilterChanged()
 SKGObjectBase::SKGListSKGObjectBase SKGCalculatorPluginWidget::getSelectedObjects()
 {
     SKGObjectBase::SKGListSKGObjectBase output;
-    if (ui.kWidgetSelector->getSelectedMode() == 0) output = ui.kInterestView->getSelectedObjects();
+    if (ui.kWidgetSelector->getSelectedMode() == 0) {
+        output = ui.kInterestView->getSelectedObjects();
+    }
     return output;
 }
 
 int SKGCalculatorPluginWidget::getNbSelectedObjects()
 {
     int output = 0;
-    if (ui.kWidgetSelector->getSelectedMode() == 0) output = ui.kInterestView->getNbSelectedObjects();
+    if (ui.kWidgetSelector->getSelectedMode() == 0) {
+        output = ui.kInterestView->getNbSelectedObjects();
+    }
     return output;
 }
 
@@ -400,7 +432,7 @@ void SKGCalculatorPluginWidget::onSelectedInterestChanged()
 void SKGCalculatorPluginWidget::onAdd()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGCalculatorPluginWidget::onAdd", err);
+    SKGTRACEINFUNCRC(10, err);
     {
         SKGInterestObject interestObj;
         {
@@ -438,7 +470,7 @@ void SKGCalculatorPluginWidget::onAdd()
 void SKGCalculatorPluginWidget::onUpdate()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGCalculatorPluginWidget::onUpdate", err);
+    SKGTRACEINFUNCRC(10, err);
 
     // Get Parent account
     QString accountname = ui.kDisplayAccountCombo->currentText();
@@ -482,7 +514,7 @@ void SKGCalculatorPluginWidget::onAmortizationComputationDelayed()
 
 void SKGCalculatorPluginWidget::onAmortizationComputation()
 {
-    SKGTRACEIN(10, "SKGCalculatorPluginWidget::onAmortizationComputation");
+    SKGTRACEINFUNC(10);
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     KLocale* loc = KGlobal::locale();
@@ -546,8 +578,9 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
 
 QWidget* SKGCalculatorPluginWidget::zoomableWidget()
 {
-    if (ui.kWidgetSelector->getSelectedMode() == 0) return ui.kInterestView;
-    else {
+    if (ui.kWidgetSelector->getSelectedMode() == 0) {
+        return ui.kInterestView;
+    } else {
         return ui.kAmortizationTable;
     }
 }
