@@ -60,12 +60,12 @@ SKGImportExportPlugin::SKGImportExportPlugin(QWidget* iWidget, QObject* iParent,
     m_install(false)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGImportExportPlugin::SKGImportExportPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGImportExportPlugin::~SKGImportExportPlugin()
 {
-    SKGTRACEIN(10, "SKGImportExportPlugin::~SKGImportExportPlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
 
     m_importAction = NULL;
@@ -82,10 +82,12 @@ SKGImportExportPlugin::~SKGImportExportPlugin()
 
 bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGImportExportPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) return false;
+    if (m_currentBankDocument == NULL) {
+        return false;
+    }
 
     // Tell the host application to load my GUI component
     setComponentData(KGlobal::mainComponent());
@@ -204,14 +206,16 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     // Krunner operations
     QString dirName = QDir::homePath() % "/.skrooge/";
     QStringList fileList = QDir(dirName).entryList(QStringList() << "add_operation_*.txt", QDir::Files);
-    if (fileList.count()) m_currentBankDocument->sendMessage(i18nc("Information message", "You have some krunner's operations to import"));
+    if (fileList.count()) {
+        m_currentBankDocument->sendMessage(i18nc("Information message", "You have some krunner's operations to import"));
+    }
 
     return true;
 }
 
 bool SKGImportExportPlugin::processArguments(const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGImportExportPlugin::processArguments");
+    SKGTRACEINFUNC(10);
     bool output = false;
     int nbArg = iArgument.count();
     if (nbArg) {
@@ -226,7 +230,7 @@ bool SKGImportExportPlugin::processArguments(const QStringList& iArgument)
 
 QWidget* SKGImportExportPlugin::getPreferenceWidget()
 {
-    SKGTRACEIN(10, "SKGImportExportPlugin::getPreferenceWidget");
+    SKGTRACEINFUNC(10);
     QWidget* w = new QWidget();
     ui.setupUi(w);
 
@@ -251,7 +255,10 @@ QWidget* SKGImportExportPlugin::getPreferenceWidget()
                 << "DD-MM-YY"
                 << "MM-DD-YYYY"
                 << "DD-MM-YYYY"
-                << "YYYY-MM-DD";
+                << "YYYY-MM-DD"
+                << "DDMMMYYYY"
+                << "DD-MMM-YY"
+                << "DD-MMM-YYYY";
     ui.kcfg_qif_date_format->addItems(dateFormats);
     ui.kcfg_csv_date_format->addItems(dateFormats);
 
@@ -300,26 +307,48 @@ int SKGImportExportPlugin::getOrder() const
 
 void SKGImportExportPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGImportExportPlugin::refresh");
+    SKGTRACEINFUNC(10);
 
     if (m_currentBankDocument && SKGMainPanel::getMainPanel()) {
         bool test = (m_currentBankDocument->getDatabase() != NULL);
-        if (m_openNotValidatedAction) m_openNotValidatedAction->setEnabled(test);
-        if (m_importAction) m_importAction->setEnabled(test);
-        if (m_exportFileAction) m_exportFileAction->setEnabled(test);
-        if (m_importCsvUnitAction) m_importCsvUnitAction->setEnabled(test);
-        if (m_processingFoundTransfert) m_processingFoundTransfert->setEnabled(test);
-        if (m_processingAnonymize) m_processingAnonymize->setEnabled(test);
-        if (m_processingBank) m_processingBank->setEnabled(test);
+        if (m_openNotValidatedAction) {
+            m_openNotValidatedAction->setEnabled(test);
+        }
+        if (m_importAction) {
+            m_importAction->setEnabled(test);
+        }
+        if (m_exportFileAction) {
+            m_exportFileAction->setEnabled(test);
+        }
+        if (m_importCsvUnitAction) {
+            m_importCsvUnitAction->setEnabled(test);
+        }
+        if (m_processingFoundTransfert) {
+            m_processingFoundTransfert->setEnabled(test);
+        }
+        if (m_processingAnonymize) {
+            m_processingAnonymize->setEnabled(test);
+        }
+        if (m_processingBank) {
+            m_processingBank->setEnabled(test);
+        }
 
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         if (selection.count() > 0 && test) {
             bool onOperation = (selection.at(0).getRealTable() == "operation" &&  selection.at(0).getTable() != "v_operation_consolidated");
-            if (m_validateImportedOperationsAction) m_validateImportedOperationsAction->setEnabled(onOperation);
-            if (m_mergeImportedOperationAction) m_mergeImportedOperationAction->setEnabled(onOperation);
+            if (m_validateImportedOperationsAction) {
+                m_validateImportedOperationsAction->setEnabled(onOperation);
+            }
+            if (m_mergeImportedOperationAction) {
+                m_mergeImportedOperationAction->setEnabled(onOperation);
+            }
         } else {
-            if (m_validateImportedOperationsAction) m_validateImportedOperationsAction->setEnabled(false);
-            if (m_mergeImportedOperationAction) m_mergeImportedOperationAction->setEnabled(false);
+            if (m_validateImportedOperationsAction) {
+                m_validateImportedOperationsAction->setEnabled(false);
+            }
+            if (m_mergeImportedOperationAction) {
+                m_mergeImportedOperationAction->setEnabled(false);
+            }
         }
 
         // Automatic download
@@ -354,7 +383,7 @@ void SKGImportExportPlugin::refresh()
 SKGError SKGImportExportPlugin::importbackends()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::importbackends", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentBankDocument) {
         // Check if already in a transaction
         if (!m_currentBankDocument->checkExistingTransaction()) {
@@ -389,7 +418,9 @@ SKGError SKGImportExportPlugin::importbackends()
             }
 
             QString codec = m_currentBankDocument->getParameter("SKG_LAST_CODEC_USED_FOR_IMPORT");
-            if (codec.isEmpty()) codec = QTextCodec::codecForLocale()->name();
+            if (codec.isEmpty()) {
+                codec = QTextCodec::codecForLocale()->name();
+            }
             IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec))
 
             SKGImportExportManager imp1(m_currentBankDocument, KUrl("." % backends[i]));
@@ -425,11 +456,13 @@ void SKGImportExportPlugin::import(const QString& iFile)
 void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::import", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentBankDocument) {
         QList<KUrl> fileNames;
         QString lastCodecUsed = m_currentBankDocument->getParameter("SKG_LAST_CODEC_USED_FOR_IMPORT");
-        if (lastCodecUsed.isEmpty()) lastCodecUsed = QTextCodec::codecForLocale()->name();
+        if (lastCodecUsed.isEmpty()) {
+            lastCodecUsed = QTextCodec::codecForLocale()->name();
+        }
         QString codec;
 
         if (iFiles.isEmpty()) {
@@ -498,14 +531,18 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                         parameters["columns_positions"] = skgimportexport_settings::columns_positions();
                         parameters["mode_csv_unit"] = (sender() == m_importCsvUnitAction ? "Y" : "N");
                         parameters["date_format"] = skgimportexport_settings::csv_date_format();
-                        if (!parameters["date_format"].contains("YY")) parameters["date_format"] = "";
+                        if (!parameters["date_format"].contains("YY")) {
+                            parameters["date_format"] = "";
+                        }
 
                         imp1.setImportParameters(parameters);
                     } else if (QFileInfo(fileName.path()).suffix().toUpper() == "QIF") {  // TODO(Stephane MANKOWSKI): Better
                         QMap<QString, QString> parameters = imp1.getImportParameters();
 
                         parameters["date_format"] = skgimportexport_settings::qif_date_format();
-                        if (!parameters["date_format"].contains("YY")) parameters["date_format"] = "";
+                        if (!parameters["date_format"].contains("YY")) {
+                            parameters["date_format"] = "";
+                        }
 
                         imp1.setImportParameters(parameters);
                     }
@@ -536,7 +573,9 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                             QApplication::restoreOverrideCursor();
                             QPointer<KPasswordDialog> dlg = new KPasswordDialog(SKGMainPanel::getMainPanel());
                             dlg->setPrompt(additionalMessage % i18nc("Question", "This file seems to be protected.\nPlease enter the password."));
-                            if (dlg->exec() == QDialog::Accepted) pwd = dlg->password();
+                            if (dlg->exec() == QDialog::Accepted) {
+                                pwd = dlg->password();
+                            }
                             delete dlg;
                             QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
@@ -601,13 +640,17 @@ void SKGImportExportPlugin::onInstall()
 void SKGImportExportPlugin::exportFile()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::exportFile", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentBankDocument) {
         QString lastCodecUsed = m_currentBankDocument->getParameter("SKG_LAST_CODEC_USED_FOR_IMPORT");
-        if (lastCodecUsed.isEmpty()) lastCodecUsed = QTextCodec::codecForLocale()->name();
+        if (lastCodecUsed.isEmpty()) {
+            lastCodecUsed = QTextCodec::codecForLocale()->name();
+        }
         QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", SKGImportExportManager::getExportMimeTypeFilter(),
                            SKGMainPanel::getMainPanel(), QString(), &lastCodecUsed);
-        if (fileName.isEmpty() || !m_currentBankDocument) return;
+        if (fileName.isEmpty() || !m_currentBankDocument) {
+            return;
+        }
 
 
         {
@@ -633,7 +676,7 @@ void SKGImportExportPlugin::exportFile()
 void SKGImportExportPlugin::anonymize()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::anonymize", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentBankDocument) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         SKGImportExportManager imp1(m_currentBankDocument);
@@ -651,7 +694,7 @@ void SKGImportExportPlugin::anonymize()
 void SKGImportExportPlugin::findTransfers()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::findTransfers", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentBankDocument) {
         int NbOperationsMerged = 0;
         {
@@ -677,14 +720,16 @@ void SKGImportExportPlugin::findTransfers()
         SKGMainPanel::displayErrorMessage(err);
 
         // Open last modified operations if setting activated
-        if (!err && NbOperationsMerged) openLastModifiedIfSetting();
+        if (!err && NbOperationsMerged) {
+            openLastModifiedIfSetting();
+        }
     }
 }
 
 void SKGImportExportPlugin::cleanBanks()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::cleanBanks", err);
+    SKGTRACEINFUNCRC(10, err);
     {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Clean bank's imports"), err);
         IFOK(err) {
@@ -709,7 +754,7 @@ void SKGImportExportPlugin::cleanBanks()
 void SKGImportExportPlugin::validateImportedOperations()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::validateImportedOperations", err);
+    SKGTRACEINFUNCRC(10, err);
 
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
@@ -740,7 +785,7 @@ void SKGImportExportPlugin::validateImportedOperations()
 void SKGImportExportPlugin::mergeImportedOperation()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::mergeImportedOperation", err);
+    SKGTRACEINFUNCRC(10, err);
 
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
@@ -808,7 +853,7 @@ void SKGImportExportPlugin::openLastModifiedIfSetting()
 void SKGImportExportPlugin::validateAllOperations()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::validateAllOperations", err);
+    SKGTRACEINFUNCRC(10, err);
     {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Validate all operations"), err);
         err = m_currentBankDocument->executeSqliteOrder("UPDATE operation SET t_imported='Y' WHERE t_imported='P'");
@@ -826,7 +871,7 @@ void SKGImportExportPlugin::validateAllOperations()
 
 SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGImportExportPlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
 
     // Check operations not validated
@@ -935,7 +980,9 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                 IFOK(err) {
                     int pos1 = fileName.indexOf("{");
                     int pos2 = fileName.indexOf("}");
-                    if (pos1 != -1 && pos2 > pos1) err = op.setImportID("KR-" % fileName.mid(pos1 + 1, pos2 - pos1 - 1));
+                    if (pos1 != -1 && pos2 > pos1) {
+                        err = op.setImportID("KR-" % fileName.mid(pos1 + 1, pos2 - pos1 - 1));
+                    }
                 }
                 IFOKDO(err, op.save())
 
