@@ -40,6 +40,9 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
 {
     SKGTRACEINFUNC(10);
 
+    m_timer.setSingleShot(true);
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(dataModified()), Qt::QueuedConnection);
+
     // Initialize animation group
     m_anim = new QParallelAnimationGroup(this);
 
@@ -79,19 +82,19 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     m_menuTransfert = new KAction(i18nc("Noun, a type of operations", "Transfers"), this);
     m_menuTransfert->setCheckable(true);
     m_menuTransfert->setChecked(false);
-    connect(m_menuTransfert, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    connect(m_menuTransfert, SIGNAL(triggered(bool)), this, SLOT(refreshDelayed()));
     addAction(m_menuTransfert);
 
     m_menuTracked = new KAction(i18nc("Noun, a type of operations", "Tracked"), this);
     m_menuTracked->setCheckable(true);
     m_menuTracked->setChecked(true);
-    connect(m_menuTracked, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    connect(m_menuTracked, SIGNAL(triggered(bool)), this, SLOT(refreshDelayed()));
     addAction(m_menuTracked);
 
     m_menuSuboperation = new KAction(i18nc("Noun, a type of operations", "On suboperations"), this);
     m_menuSuboperation->setCheckable(true);
     m_menuSuboperation->setChecked(false);
-    connect(m_menuSuboperation, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    connect(m_menuSuboperation, SIGNAL(triggered(bool)), this, SLOT(refreshDelayed()));
     addAction(m_menuSuboperation);
 
     {
@@ -139,8 +142,8 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     }
 
     // Refresh
-    connect(m_periodEdit1, SIGNAL(changed()), this, SLOT(dataModified()), Qt::QueuedConnection);
-    connect(m_periodEdit2, SIGNAL(changed()), this, SLOT(dataModified()), Qt::QueuedConnection);
+    connect(m_periodEdit1, SIGNAL(changed()), this, SLOT(refreshDelayed()), Qt::QueuedConnection);
+    connect(m_periodEdit2, SIGNAL(changed()), this, SLOT(refreshDelayed()), Qt::QueuedConnection);
     connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
@@ -188,7 +191,7 @@ void SKGOperationBoardWidget::setState(const QString& iState)
     if (m_periodEdit2 && !period2.isEmpty()) {
         m_periodEdit2->setState(period2);
     }
-    dataModified("", 0);
+    refreshDelayed();
 }
 
 void SKGOperationBoardWidget::onOpen(const QString& iLink)
@@ -229,12 +232,17 @@ void SKGOperationBoardWidget::onOpen(const QString& iLink)
                                            "&operationWhereClause=" % SKGServices::encodeForUrl(wc));
 }
 
+void SKGOperationBoardWidget::refreshDelayed()
+{
+    m_timer.start(300);
+}
+
 void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
     SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
     QString table = (m_menuSuboperation && m_menuSuboperation->isChecked() ? "v_operation_consolidated" : "v_operation_display");
-    if (iTableName == table || iTableName.isEmpty()) {
+    if (m_periodEdit1 && m_periodEdit2 && (iTableName == table || iTableName.isEmpty())) {
         // Set titles
         ui.kLabel->setText(m_periodEdit1->text());
         ui.kLabel_previous->setText(m_periodEdit2->text());
@@ -257,15 +265,15 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
 
             SKGReportBank* bk = qobject_cast< SKGReportBank* >(doc->getReport());
             if (bk) {
-                QVariantList table = bk->getIncomeVsExpenditure(m_menuSuboperation && m_menuSuboperation->isChecked(),
-                                     m_menuTransfert && m_menuTransfert->isChecked(),
-                                     m_menuTracked && m_menuTracked->isChecked(),
-                                     m_periodEdit1->getWhereClause(),
-                                     m_periodEdit2->getWhereClause());
+                QVariantList table2 = bk->getIncomeVsExpenditure(m_menuSuboperation && m_menuSuboperation->isChecked(),
+                                      m_menuTransfert && m_menuTransfert->isChecked(),
+                                      m_menuTracked && m_menuTracked->isChecked(),
+                                      m_periodEdit1->getWhereClause(),
+                                      m_periodEdit2->getWhereClause());
                 delete bk;
 
-                QList<QVariant> l1 = table.value(1).toList();
-                QList<QVariant> l2 = table.value(2).toList();
+                QList<QVariant> l1 = table2.value(1).toList();
+                QList<QVariant> l2 = table2.value(2).toList();
                 double income_previous_month = l1.value(2).toDouble();
                 double expense_previous_month = l2.value(2).toDouble();
                 double income_month = l1.value(3).toDouble();
