@@ -26,6 +26,7 @@
 #include <KAboutData>
 #include <KGenericFactory>
 #include <KStandardDirs>
+#include <KToolBarPopupAction>
 
 #include <QDomDocument>
 
@@ -61,7 +62,7 @@ SKGOperationPlugin::SKGOperationPlugin(QWidget* iWidget, QObject* iParent, const
     SKGInterfacePlugin(iParent),
     m_duplicateAction(NULL), m_createTemplateAction(NULL), m_switchToPointedAction(NULL), m_openHighLights(NULL), m_openLastModified(NULL),
     m_openSuboperations(NULL), m_openDuplicate(NULL), m_groupOperation(NULL), m_ungroupOperation(NULL), m_mergeOperationAction(NULL),
-    m_open(NULL), m_currentBankDocument(NULL)
+    m_open(NULL), m_applyTemplateAction(NULL), m_applyTemplateMenu(NULL), m_currentBankDocument(NULL)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -82,6 +83,8 @@ SKGOperationPlugin::~SKGOperationPlugin()
     m_openDuplicate = NULL;
     m_mergeOperationAction = NULL;
     m_open = NULL;
+    m_applyTemplateAction = NULL;
+    m_applyTemplateMenu = NULL;
 }
 
 bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -253,9 +256,59 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     connect(m_mergeOperationAction, SIGNAL(triggered(bool)), SLOT(onMergeSubOperations()));
     m_mergeOperationAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_M);
     registerGlobalAction("merge_sub_operations", m_mergeOperationAction);
+
+    m_applyTemplateAction = new KToolBarPopupAction(KIcon("edit-apply-template"), i18nc("Verb, action to apply a template", "Apply template"), this);
+    m_applyTemplateMenu = static_cast<KMenu*>(m_applyTemplateAction->menu());
+    connect(m_applyTemplateMenu , SIGNAL(aboutToShow()), this, SLOT(onShowApplyTemplateMenu()));
+    m_applyTemplateAction->setStickyMenu(false);
+    m_applyTemplateAction->setData(1);
+    registerGlobalAction("edit_apply_template", m_applyTemplateAction);
+
+
     return true;
 }
 
+void SKGOperationPlugin::onShowApplyTemplateMenu()
+{
+    if (m_applyTemplateMenu && m_currentBankDocument) {
+        // Clean Menu
+        QMenu* m = m_applyTemplateMenu;
+        m->clear();
+
+        // Search templates
+        SKGStringListList listTmp;
+        m_currentBankDocument->executeSelectSqliteOrder(
+            "SELECT t_displayname, id, t_bookmarked FROM v_operation_displayname WHERE t_template='Y' ORDER BY t_bookmarked DESC, t_PAYEE ASC",
+            listTmp);
+
+        // Build menus
+        int count = 0;
+        bool fav = true;
+        int nb = listTmp.count();
+        for (int i = 1; i < nb; ++i) {
+            // Add more sub menu
+            if (count == 8) {
+                m = m->addMenu(i18nc("More items in a menu", "More"));
+                count = 0;
+            }
+            count++;
+
+            // Add separator for bookmarked templates
+            if (fav && listTmp.at(i).at(2) == "N" && i > 1) {
+                m->addSeparator();
+            }
+            fav = (listTmp.at(i).at(2) == "Y");
+
+            // Add actions
+            QAction* act = m->addAction(KIcon("skrooge_template"), listTmp.at(i).at(0));
+            if (act) {
+                act->setData(listTmp.at(i).at(1));
+                connect(act, SIGNAL(triggered()), this, SLOT(onApplyTemplate()));
+            }
+        }
+    }
+}
+
 void SKGOperationPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
@@ -299,6 +352,9 @@ void SKGOperationPlugin::refresh()
             if (m_mergeOperationAction) {
                 m_mergeOperationAction->setEnabled(onOperation);
             }
+            if (m_applyTemplateAction) {
+                m_applyTemplateAction->setEnabled(onOperation);
+            }
         } else {
             if (m_duplicateAction) {
                 m_duplicateAction->setEnabled(false);
@@ -318,6 +374,9 @@ void SKGOperationPlugin::refresh()
             if (m_mergeOperationAction) {
                 m_mergeOperationAction->setEnabled(false);
             }
+            if (m_applyTemplateAction) {
+                m_applyTemplateAction->setEnabled(false);
+            }
         }
     }
 }
@@ -409,6 +468,51 @@ bool SKGOperationPlugin::isInPagesChooser() const
     return true;
 }
 
+void SKGOperationPlugin::onApplyTemplate()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(10, err);
+    QAction* act = qobject_cast<QAction*>(sender());
+    if (act) {
+        // Get template
+        SKGOperationObject temp(m_currentBankDocument, SKGServices::stringToInt(act->data().toString()));
+
+        // Get Selection
+        if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
+            QStringList listUUID;
+
+            SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+            int nb = selection.count();
+            {
+                SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Apply template"), err, nb);
+                for (int i = 0; !err && i < nb; ++i) {
+                    SKGOperationObject operationObj(selection.at(i));
+
+                    SKGOperationObject op;
+                    IFOKDO(err, temp.duplicate(op))
+                    IFOKDO(err, op.mergeAttribute(operationObj, SKGOperationObject::PROPORTIONAL))
+                    listUUID.push_back(op.getUniqueID());
+
+                    IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
+                }
+            }
+
+            // status bar
+            IFOK(err) {
+                err = SKGError(0, i18nc("Successful message after an user action", "Template applied."));
+                SKGOperationPluginWidget* w = qobject_cast<SKGOperationPluginWidget*>(SKGMainPanel::getMainPanel()->currentPage());
+                if (w) {
+                    w->getTableView()->selectObjects(listUUID, true);
+                }
+            } else {
+                err.addError(ERR_FAIL, i18nc("Error message",  "Apply of template failed"));
+            }
+        }
+        // Display error
+        SKGMainPanel::displayErrorMessage(err);
+    }
+}
+
 void SKGOperationPlugin::onGroupOperation()
 {
     SKGError err;
@@ -826,7 +930,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Search duplicate number on operation
     if (!iIgnoredAdvice.contains("skgoperationplugin_duplicate")) {
-        SKGTRACEINFUNC(10);
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT count(1), t_ACCOUNT, i_number FROM v_operation_display WHERE i_number!=0 GROUP BY t_ACCOUNT, i_number HAVING count(1)>1 ORDER BY count(1) DESC", result);
         int nb = result.count();
@@ -850,7 +953,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations not reconciliated
     if (!iIgnoredAdvice.contains("skgoperationplugin_notreconciliated")) {
-        SKGTRACEINFUNC(10);
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT count(1), t_ACCOUNT FROM v_operation_display WHERE t_status='N' GROUP BY t_ACCOUNT HAVING count(1)>100 ORDER BY count(1) DESC", result);
         int nb = result.count();
@@ -873,7 +975,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations without mode
     if (!iIgnoredAdvice.contains("skgimportexportplugin_notvalidated")) {
-        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("operation", "t_template='N' AND t_mode='' AND d_date<>'0000-00-00'", exist);
         if (exist) {
@@ -891,7 +992,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations without category
     if (!iIgnoredAdvice.contains("skgoperationplugin_nocategory")) {
-        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='N' AND EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)", exist);
         if (exist) {
@@ -908,7 +1008,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     if (!iIgnoredAdvice.contains("skgoperationplugin_transfer_nocategory")) {
-        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='Y' AND EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)", exist);
         if (exist) {
@@ -926,7 +1025,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations without payee
     if (!iIgnoredAdvice.contains("skgoperationplugin_nopayee")) {
-        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='N' AND r_payee_id=0", exist);
         if (exist) {
@@ -943,7 +1041,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     if (!iIgnoredAdvice.contains("skgoperationplugin_transfer_nopayee")) {
-        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='Y' AND r_payee_id=0", exist);
         if (exist) {
@@ -961,7 +1058,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations in group of only one transaction
     if (!iIgnoredAdvice.contains("skgoperationplugin_groupofone")) {
-        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=v_operation_display.i_group_id)<2", exist);
         if (exist) {
@@ -980,7 +1076,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check simple operations with comment not aligned with the comment of the suboperation
     if (!iIgnoredAdvice.contains("skgoperationplugin_commentsnotaligned")) {
-        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("operation op, suboperation so", "so.rd_operation_id=op.id AND so.t_comment<>op.t_comment AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1", exist);
         if (exist) {
@@ -999,7 +1094,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check simple operations with date not aligned with the date of the suboperation
     if (!iIgnoredAdvice.contains("skgoperationplugin_datesnotaligned")) {
-        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("operation op, suboperation so", "so.rd_operation_id=op.id AND so.d_date<>op.d_date AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1", exist);
         if (exist) {
@@ -1018,7 +1112,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Too much money in your account
     if (!iIgnoredAdvice.contains("skgoperationplugin_too_much_money")) {
-        SKGTRACEINFUNC(10);
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name, f_RATE FROM v_account_display WHERE t_close='N' AND f_RATE>0 AND (t_maxamount_enabled='N' OR f_CURRENTAMOUNT<f_maxamount*0.9) ORDER BY f_RATE DESC", result);
         int nb = result.count();
@@ -1049,7 +1142,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Not enough money in your account
     if (!iIgnoredAdvice.contains("skgoperationplugin_minimum_limit")) {
-        SKGTRACEINFUNC(10);
         SKGStringListList result;
 
         // Get accounts with amount close or below the minimum limit
@@ -1070,7 +1162,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Not enough money in your account
     if (!iIgnoredAdvice.contains("skgoperationplugin_maximum_limit")) {
-        SKGTRACEINFUNC(10);
         SKGStringListList result;
 
         // Get accounts with amount over the maximum limit
@@ -1091,7 +1182,6 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Not enough money in your account
     if (!iIgnoredAdvice.contains("skgoperationplugin_close_minimum_limit")) {
-        SKGTRACEINFUNC(10);
         SKGStringListList result;
 
         // Get accounts with amount close or below the minimum limit
