@@ -125,6 +125,7 @@ private Q_SLOTS:
     void onFastEdition();
     void onDoubleClick();
     void onQuantityChanged();
+    void onDateChanged(const QDate& iDate);
     void onSubopCellChanged(int row, int column);
     void onRemoveSubOperation(int iRow);
     void onRefreshInformationZone();
@@ -154,7 +155,7 @@ private:
     void displaySubOperations();
     void displaySubOperations(const SKGOperationObject& iOperation , bool iKeepId = true);
     double getRemainingQuantity();
-    void addSubOperationLine(int row, const QString& category, const QString& tracker, const QString& comment, double quantity, const QString& formula, int id = 0);
+    void addSubOperationLine(int row, const QDate& date, const QString& category, const QString& tracker, const QString& comment, double quantity, const QString& formula, int id = 0);
     SKGError updateSelection(const SKGObjectBase::SKGListSKGObjectBase& iSelection, bool forceCreation = false);
     void fillNumber();
     QString currentAccount();
@@ -178,6 +179,9 @@ private:
 
     SKGSplitTableDelegate* m_tableDelegate;
     QTimer m_timer;
+
+    QStringList m_attributesForSplit;
+    QDate m_previousDate;
 };
 
 #endif  // SKGOPERATIONPLUGINWIDGET_H
