@@ -28,25 +28,9 @@
 #include "skgcombobox.h"
 #include "skgcalculatoredit.h"
 #include "skgmainpanel.h"
+#include "skgdateedit.h"
 
-/**
- * Index for amount attribute
- */
-static const int AMOUNTINDEX = 1;
-/**
- * Index for category attribute;
- */
-static const int CATEGORYINDEX = 0;
-/**
- * Index for comment attribute
- */
-static const int COMMENTINDEX = 2;
-/**
- * Index for refund attribute
- */
-static const int REFUNDINDEX = 3;
-
-SKGSplitTableDelegate::SKGSplitTableDelegate(QObject* iParent, SKGDocument* iDoc) : QItemDelegate(iParent), m_document(iDoc) {}
+SKGSplitTableDelegate::SKGSplitTableDelegate(QObject* iParent, SKGDocument* iDoc, const QStringList& iListAttribut) : QItemDelegate(iParent), m_document(iDoc), m_listAttributes(iListAttribut) {}
 
 SKGSplitTableDelegate::~SKGSplitTableDelegate()
 {
@@ -57,19 +41,23 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
         const QStyleOptionViewItem& option ,
         const QModelIndex& index) const
 {
-    if (index.column() == CATEGORYINDEX) {
+    if (index.column() == m_listAttributes.indexOf("t_category")) {
         SKGComboBox* editor = new SKGComboBox(iParent);
         editor->setEditable(true);
-        if (m_document) SKGMainPanel::fillWithDistinctValue(editor, m_document, "category", "t_fullname", "");
+        if (m_document) {
+            SKGMainPanel::fillWithDistinctValue(editor, m_document, "category", "t_fullname", "");
+        }
 
         return editor;
-    } else if (index.column() == COMMENTINDEX) {
+    } else if (index.column() == m_listAttributes.indexOf("t_comment")) {
         SKGComboBox* editor = new SKGComboBox(iParent);
         editor->setEditable(true);
-        if (m_document) SKGMainPanel::fillWithDistinctValue(editor, m_document, "v_operation_all_comment", "t_comment", "");
+        if (m_document) {
+            SKGMainPanel::fillWithDistinctValue(editor, m_document, "v_operation_all_comment", "t_comment", "");
+        }
 
         return editor;
-    } else if (index.column() == AMOUNTINDEX) {
+    } else if (index.column() == m_listAttributes.indexOf("f_value")) {
         SKGCalculatorEdit* editor = new SKGCalculatorEdit(iParent);
         editor->setMode(SKGCalculatorEdit::EXPRESSION);
         QMapIterator<QString, double> i(m_parameters);
@@ -79,10 +67,16 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
         }
 
         return editor;
-    } else if (index.column() == REFUNDINDEX) {
+    } else if (index.column() == m_listAttributes.indexOf("t_refund")) {
         SKGComboBox* editor = new SKGComboBox(iParent);
         editor->setEditable(true);
-        if (m_document) SKGMainPanel::fillWithDistinctValue(editor, m_document, "refund", "t_name", "t_close='N'");
+        if (m_document) {
+            SKGMainPanel::fillWithDistinctValue(editor, m_document, "refund", "t_name", "t_close='N'");
+        }
+
+        return editor;
+    }  else if (index.column() == m_listAttributes.indexOf("d_date")) {
+        SKGDateEdit* editor = new SKGDateEdit(iParent);
 
         return editor;
     }
@@ -92,11 +86,16 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
 
 void SKGSplitTableDelegate::setEditorData(QWidget* editor, const QModelIndex& index) const
 {
-    if (index.column() == AMOUNTINDEX) {
+    if (index.column() == m_listAttributes.indexOf("f_value")) {
         SKGCalculatorEdit* calculator = static_cast<SKGCalculatorEdit*>(editor);
         if (calculator) {
             calculator->setText(index.model()->data(index, Qt::ToolTipRole).toString());
         }
+    } else if (index.column() == m_listAttributes.indexOf("d_date")) {
+        SKGDateEdit* date = static_cast<SKGDateEdit*>(editor);
+        if (date) {
+            date->setDate(SKGServices::stringToTime(index.model()->data(index, Qt::ToolTipRole).toString()).date());
+        }
     } else {
         QItemDelegate::setEditorData(editor, index);
     }
@@ -104,15 +103,24 @@ void SKGSplitTableDelegate::setEditorData(QWidget* editor, const QModelIndex& in
 
 void SKGSplitTableDelegate::setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const
 {
-    if (index.column() == AMOUNTINDEX) {
+    if (index.column() == m_listAttributes.indexOf("f_value")) {
         SKGCalculatorEdit* calculator = static_cast<SKGCalculatorEdit*>(editor);
         if (calculator && model) {
             QString f = calculator->formula();
             QString t = SKGServices::doubleToString(calculator->value());
-            if (f.isEmpty()) f = t;
+            if (f.isEmpty()) {
+                f = t;
+            }
             model->setData(index, f, Qt::ToolTipRole);
             model->setData(index, t, Qt::DisplayRole);
         }
+    } else if (index.column() == m_listAttributes.indexOf("d_date")) {
+        SKGDateEdit* date = static_cast<SKGDateEdit*>(editor);
+        if (date && model) {
+            QString d = SKGServices::dateToSqlString(date->date());
+            model->setData(index, d, Qt::ToolTipRole);
+            model->setData(index, d, Qt::DisplayRole);
+        }
     } else {
         QItemDelegate::setModelData(editor, model, index);
     }
