@@ -44,20 +44,22 @@ K_EXPORT_PLUGIN(SKGPayeePluginFactory("skrooge_payee", "skrooge_payee"))
 SKGPayeePlugin::SKGPayeePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGPayeePlugin::SKGPayeePlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGPayeePlugin::~SKGPayeePlugin()
 {
-    SKGTRACEIN(10, "SKGPayeePlugin::~SKGPayeePlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
 }
 
 bool SKGPayeePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGPayeePlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
-    if (qobject_cast<SKGDocumentBank*>(iDocument) == NULL) return false;
+    if (qobject_cast<SKGDocumentBank*>(iDocument) == NULL) {
+        return false;
+    }
 
     m_currentBankDocument = iDocument;
 
@@ -77,7 +79,7 @@ bool SKGPayeePlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
 
 SKGTabPage* SKGPayeePlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGPayeePlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGPayeePluginWidget(m_currentBankDocument);
 }
 
@@ -120,7 +122,7 @@ bool SKGPayeePlugin::isInPagesChooser() const
 
 SKGAdviceList SKGPayeePlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGPayeePlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
     // Check unused payee
     if (!iIgnoredAdvice.contains("skgpayeeplugin_unused")) {
@@ -144,7 +146,7 @@ SKGAdviceList SKGPayeePlugin::advice(const QStringList& iIgnoredAdvice)
 void SKGPayeePlugin::deleteUnusedPayees() const
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGPayeePlugin::deleteUnusedPayees", err);
+    _SKGTRACEINFUNCRC(10, err);
     if (m_currentBankDocument) {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused payees")  , err);
 
