@@ -31,7 +31,7 @@
 SKGReportBoardWidget::SKGReportBoardWidget(SKGDocumentBank* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Report"), true)
 {
-    SKGTRACEIN(10, "SKGReportBoardWidget::SKGReportBoardWidget");
+    SKGTRACEINFUNC(10);
 
     // This must be done at the beginning
     this->setMinimumSize(200, 200);
@@ -58,7 +58,7 @@ SKGReportBoardWidget::SKGReportBoardWidget(SKGDocumentBank* iDocument)
 
 SKGReportBoardWidget::~SKGReportBoardWidget()
 {
-    SKGTRACEIN(10, "SKGReportBoardWidget::~SKGReportBoardWidget");
+    SKGTRACEINFUNC(10);
     m_graph = NULL;
     m_menuRename = NULL;
 }
@@ -70,7 +70,9 @@ QString SKGReportBoardWidget::getState()
     doc.appendChild(root);
 
     root.setAttribute("title", getMainTitle());
-    if (m_graph) root.setAttribute("graph", m_graph->getState());
+    if (m_graph) {
+        root.setAttribute("graph", m_graph->getState());
+    }
     return doc.toString();
 
     // return ( graph ? graph->getState() : "" );
@@ -83,13 +85,16 @@ void SKGReportBoardWidget::setState(const QString& iState)
         QDomElement root = doc.documentElement();
 
         QString title = root.attribute("title");
-        if (!title.isEmpty()) setMainTitle(title);
+        if (!title.isEmpty()) {
+            setMainTitle(title);
+        }
 
 
         QString graphS = root.attribute("graph");
         if (m_graph) {
-            if (graphS.isEmpty()) m_graph->setState(iState);
-            else {
+            if (graphS.isEmpty()) {
+                m_graph->setState(iState);
+            } else {
                 m_graph->setState(graphS);
             }
         }
@@ -110,12 +115,14 @@ void SKGReportBoardWidget::onRenameTitle()
 
 void SKGReportBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEIN(10, "SKGReportBoardWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
     if (iTableName == "operation" || iTableName.isEmpty()) {
         bool exist = false;
         getDocument()->existObjects("account", "", exist);
-        if (parentWidget()) parentWidget()->setVisible(exist);
+        if (parentWidget()) {
+            parentWidget()->setVisible(exist);
+        }
     }
 }
 
