@@ -57,22 +57,24 @@ SKGReportPlugin::SKGReportPlugin(QWidget* iWidget, QObject* iParent, const QVari
     m_openReportAction(NULL), m_currentBankDocument(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGReportPlugin::SKGReportPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGReportPlugin::~SKGReportPlugin()
 {
-    SKGTRACEIN(10, "SKGReportPlugin::~SKGReportPlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
     m_openReportAction = NULL;
 }
 
 bool SKGReportPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGReportPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) return false;
+    if (m_currentBankDocument == NULL) {
+        return false;
+    }
 
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_report/skrooge_report.rc");
@@ -97,16 +99,20 @@ bool SKGReportPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
 
 void SKGReportPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGReportPlugin::refresh");
+    SKGTRACEINFUNC(10);
     if (SKGMainPanel::getMainPanel()) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
         if (selection.count() > 0) {
             QString table = selection.at(0).getRealTable();
             bool onOperation = (table == "operation" || table == "account" || table == "unit" || table == "category" || table == "refund" || table == "payee" || table == "rule");
-            if (m_openReportAction) m_openReportAction->setEnabled(onOperation);
+            if (m_openReportAction) {
+                m_openReportAction->setEnabled(onOperation);
+            }
         } else {
-            if (m_openReportAction) m_openReportAction->setEnabled(false);
+            if (m_openReportAction) {
+                m_openReportAction->setEnabled(false);
+            }
         }
     }
 }
@@ -130,13 +136,13 @@ SKGBoardWidget* SKGReportPlugin::getDashboardWidget(int iIndex)
 
 SKGTabPage* SKGReportPlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGReportPlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGReportPluginWidget(m_currentBankDocument);
 }
 
 QWidget* SKGReportPlugin::getPreferenceWidget()
 {
-    SKGTRACEIN(10, "SKGReportPlugin::getPreferenceWidget");
+    SKGTRACEINFUNC(10);
     QWidget* w = new QWidget();
     ui.setupUi(w);
     return w;
@@ -184,7 +190,7 @@ bool SKGReportPlugin::isInPagesChooser() const
 void SKGReportPlugin::onOpenReport()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGReportPlugin::onOpenReport", err);
+    SKGTRACEINFUNCRC(10, err);
     if (SKGMainPanel::getMainPanel()) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
@@ -302,7 +308,7 @@ void SKGReportPlugin::onOpenReport()
 
 SKGAdviceList SKGReportPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGReportPlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
 
     // Very old operation
