@@ -46,7 +46,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     }
 
     m_timer.setSingleShot(true);
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(refreshActivated()), Qt::QueuedConnection);
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(dataModified()), Qt::QueuedConnection);
 
     ui.setupUi(this);
 
@@ -197,7 +197,7 @@ void SKGReportPluginWidget::onResetInternalFilter()
     ui.kTitle->hide();
     ui.kResetInternalFilter->hide();
 
-    dataModified("", 0);
+    m_timer.start(300);
 }
 
 QString SKGReportPluginWidget::getState()
@@ -352,20 +352,20 @@ void SKGReportPluginWidget::setState(const QString& iState)
             timeline = '1';
         }
 
-        QDomDocument doc("SKGML");
-        QDomElement root = doc.createElement("parameters");
-        doc.appendChild(root);
+        QDomDocument doc2("SKGML");
+        QDomElement root2 = doc2.createElement("parameters");
+        doc2.appendChild(root2);
 
-        root.setAttribute("period", period);
+        root2.setAttribute("period", period);
         if (period == "4") {
-            root.setAttribute("date_begin", date_begin);
-            root.setAttribute("date_end", date_end);
+            root2.setAttribute("date_begin", date_begin);
+            root2.setAttribute("date_end", date_end);
         }
-        root.setAttribute("interval", interval);
-        root.setAttribute("nb_intervals", nb_interval);
-        root.setAttribute("timeline", timeline);
+        root2.setAttribute("interval", interval);
+        root2.setAttribute("nb_intervals", nb_interval);
+        root2.setAttribute("timeline", timeline);
 
-        periodDef = doc.toString();
+        periodDef = doc2.toString();
     }
     ui.kPeriod->setState(periodDef);
 
@@ -406,7 +406,7 @@ void SKGReportPluginWidget::setState(const QString& iState)
     if (!m_operationWhereClause.isEmpty()) {
         // We keep a copy of given state in case of bookmark
         m_lastState = doc;
-        dataModified("", 0);
+        m_timer.start(300);
     } else {
         m_lastState.clear();
     }
@@ -757,15 +757,10 @@ void SKGReportPluginWidget::refresh()
     m_timer.start(300);
 }
 
-void SKGReportPluginWidget::refreshActivated()
-{
-    dataModified("", 0);
-}
-
 void SKGReportPluginWidget::pageChanged()
 {
     if (m_refreshNeeded) {
-        dataModified("", 0);
+        m_timer.start(300);
     }
 }
 
