@@ -102,7 +102,6 @@ void SKGScheduledPlugin::refresh()
             QString doc_id = m_currentBankDocument->getUniqueIdentifier();
             if (m_docUniqueIdentifier != doc_id && m_currentBankDocument->getParameter("SKG_DB_BANK_VERSION") >= "0.5") {
                 m_docUniqueIdentifier = doc_id;
-                m_cacheAdvice.clear();
 
                 SKGError err;
                 // Read Setting
@@ -315,7 +314,6 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Recurrent operation with the last inserted operation having a different amount
     if (!iIgnoredAdvice.contains("skgscheduledplugin_notuptodate")) {
-        SKGTRACEINFUNC(10);
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT r.id, r.rd_operation_id, r.f_CURRENTAMOUNT, r2.f_CURRENTAMOUNT FROM v_recurrentoperation_display r INNER JOIN (SELECT MAX(d_date), f_CURRENTAMOUNT, r_recurrentoperation_id FROM v_operation_display GROUP BY r_recurrentoperation_id) r2 WHERE r2.r_recurrentoperation_id=r.id AND ABS(r.f_CURRENTAMOUNT-r2.f_CURRENTAMOUNT)>" % SKGServices::doubleToString(EPSILON), result);
         int nb = result.count();
@@ -344,34 +342,30 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Possible recurrent operations
     if (!iIgnoredAdvice.contains("skgscheduledplugin_possibleschedule")) {
-        SKGTRACEINFUNC(10);
-        if (m_counterAdvice % 10 != 0) {
-            output.append(m_cacheAdvice);
-        } else {
-            m_cacheAdvice.clear();
-            SKGStringListList result;
-            m_currentBankDocument->executeSelectSqliteOrder("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1, v_operation_tmp1 op2 "
-                    "WHERE op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.rc_unit_id=op2.rc_unit_id AND op1.d_date>(SELECT date('now','-2 month')) AND op2.d_date>(SELECT date('now','-3 month')) "
-                    "AND op1.t_TRANSFER='N' AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.d_date=date(op2.d_date, '+1 month') "
-                    "AND NOT EXISTS (SELECT 1 FROM recurrentoperation ro, v_operation_tmp1 op2  WHERE ro.rd_operation_id=op2.id AND ro.i_period_increment=1 AND ro.t_period_unit='M' AND op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.rc_unit_id=op2.rc_unit_id)", result);
-            int nb = result.count();
-            for (int i = 1; i < nb; ++i) {  // Ignore header
-                // Get parameters
-                QStringList line = result.at(i);
-                QString id = line.at(0);
-                QString name = line.at(1);
+        SKGStringListList result;
 
-                SKGAdvice ad;
-                ad.setUUID("skgscheduledplugin_possibleschedule|" % id);
-                ad.setPriority(4);
-                ad.setShortMessage(i18nc("Advice on making the best (short)", "Possible schedule '%1'", name));
-                ad.setLongMessage(i18nc("Advice on making the best (long)", "The operation '%1' seems to be regularly created and could be scheduled", name));
-                QStringList autoCorrections;
-                autoCorrections.push_back(i18nc("Advice on making the best (action)", "Monthly schedule the operation '%1'", name));
-                ad.setAutoCorrections(autoCorrections);
-                output.push_back(ad);
-                m_cacheAdvice.push_back(ad);
-            }
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1 WHERE op1.id||'#'||op1.f_QUANTITY IN (SELECT op1.id||'#'||op2.f_QUANTITY FROM operation op1, v_operation_tmp1 op2 "
+                "WHERE op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.rc_unit_id=op2.rc_unit_id "
+                "AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND op1.d_date=date(op2.d_date, '+1 month') "
+                "AND op1.d_date>(SELECT date('now','-2 month')) AND op2.d_date>(SELECT date('now','-3 month'))) "
+                "AND op1.t_TRANSFER='N' "
+                "AND NOT EXISTS (SELECT 1 FROM recurrentoperation ro, v_operation_tmp1 rop  WHERE ro.rd_operation_id=rop.id AND ro.i_period_increment=1 AND ro.t_period_unit='M' AND op1.rd_account_id=rop.rd_account_id AND op1.r_payee_id=rop.r_payee_id AND op1.f_QUANTITY=rop.f_QUANTITY AND op1.rc_unit_id=rop.rc_unit_id)", result);
+        int nb = result.count();
+        for (int i = 1; i < nb; ++i) {  // Ignore header
+            // Get parameters
+            QStringList line = result.at(i);
+            QString id = line.at(0);
+            QString name = line.at(1);
+
+            SKGAdvice ad;
+            ad.setUUID("skgscheduledplugin_possibleschedule|" % id);
+            ad.setPriority(4);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Possible schedule '%1'", name));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "The operation '%1' seems to be regularly created and could be scheduled", name));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Monthly schedule the operation '%1'", name));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
         }
     }
     m_counterAdvice++;
