@@ -38,8 +38,10 @@
 SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(1, "SKGScheduledPluginWidget::SKGScheduledPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -92,7 +94,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
 
 SKGScheduledPluginWidget::~SKGScheduledPluginWidget()
 {
-    SKGTRACEIN(1, "SKGScheduledPluginWidget::~SKGScheduledPluginWidget");
+    SKGTRACEINFUNC(1);
 }
 
 bool SKGScheduledPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -111,7 +113,7 @@ bool SKGScheduledPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 QString SKGScheduledPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGScheduledPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -121,7 +123,7 @@ QString SKGScheduledPluginWidget::getState()
 
 void SKGScheduledPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGScheduledPluginWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -162,7 +164,9 @@ void SKGScheduledPluginWidget::onJumpToTheOperation()
             recOp.getParentOperation(op);
 
             wc += SKGServices::intToString(op.getID());
-            if (i < nb - 1) wc += ',';
+            if (i < nb - 1) {
+                wc += ',';
+            }
         }
         wc += ')';
 
@@ -174,7 +178,7 @@ void SKGScheduledPluginWidget::onJumpToTheOperation()
 
 void SKGScheduledPluginWidget::onSelectionChanged()
 {
-    SKGTRACEIN(10, "SKGScheduledPluginWidget::onSelectionChanged");
+    SKGTRACEINFUNC(10);
 
     int nb = getNbSelectedObjects();
     ui.kFirstOccurenceDate->setEnabled(nb <= 1);
@@ -218,8 +222,9 @@ void SKGScheduledPluginWidget::onNbOccurrenceChanged()
             ui.kNbTimesVal->setValue(1);
         } else {
             int nbd = firstDate.daysTo(lastDate);
-            if (punit == SKGRecurrentOperationObject::DAY) nbd = nbd / p;
-            else if (punit == SKGRecurrentOperationObject::MONTH) {
+            if (punit == SKGRecurrentOperationObject::DAY) {
+                nbd = nbd / p;
+            } else if (punit == SKGRecurrentOperationObject::MONTH) {
                 nbd = (lastDate.day() >= firstDate.day() ? 0 : -1) + (lastDate.year() - firstDate.year()) * 12 + (lastDate.month() - firstDate.month());
             } else if (punit == SKGRecurrentOperationObject::YEAR) {
                 nbd = nbd / (365 * p);
@@ -233,8 +238,9 @@ void SKGScheduledPluginWidget::onNbOccurrenceChanged()
     } else {
         // We must compute the date
         p *= (ui.kNbTimesVal->value() - 1);
-        if (punit == SKGRecurrentOperationObject::DAY) firstDate = firstDate.addDays(p);
-        else if (punit == SKGRecurrentOperationObject::MONTH) {
+        if (punit == SKGRecurrentOperationObject::DAY) {
+            firstDate = firstDate.addDays(p);
+        } else if (punit == SKGRecurrentOperationObject::MONTH) {
             firstDate = firstDate.addMonths(p);
         } else if (punit == SKGRecurrentOperationObject::YEAR) {
             firstDate = firstDate.addYears(p);
@@ -249,7 +255,7 @@ void SKGScheduledPluginWidget::onNbOccurrenceChanged()
 void SKGScheduledPluginWidget::onUpdate()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGScheduledPluginWidget::onUpdate", err);
+    SKGTRACEINFUNCRC(10, err);
     {
         // Get Selection
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
@@ -261,7 +267,9 @@ void SKGScheduledPluginWidget::onUpdate()
             SKGRecurrentOperationObject recOp = SKGRecurrentOperationObject(selection.at(i).getDocument(), selection.at(i).getID());
 
             // Update it
-            if (nb == 1) err = recOp.setDate(ui.kFirstOccurenceDate->date());
+            if (nb == 1) {
+                err = recOp.setDate(ui.kFirstOccurenceDate->date());
+            }
             IFOKDO(err, recOp.setPeriodIncrement(ui.kOnceEveryVal->value()))
             IFOKDO(err, recOp.setPeriodUnit(static_cast<SKGRecurrentOperationObject::PeriodUnit>(ui.kOnceEveryUnit->currentIndex())))
             IFOKDO(err, recOp.setWarnDays(ui.kRemindMeVal->value()))
@@ -293,7 +301,7 @@ void SKGScheduledPluginWidget::onProcessImmediately()
 void SKGScheduledPluginWidget::onProcess(bool iImmediately)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGScheduledPluginWidget::onProcess", err);
+    SKGTRACEINFUNCRC(10, err);
     {
         // Get Selection
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
