@@ -101,11 +101,13 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
 
     if (iTableName == "operation" || iTableName == "rule" || iTableName.isEmpty()) {
         // Remove all item of the layout
-        QLayoutItem* child = NULL;
-        while ((child = m_layout->takeAt(0)) != 0) {
-            QWidget* w = child->widget();
-            delete w;
-            delete child;
+        while (m_layout->count()) {
+            QLayoutItem* child = m_layout->takeAt(0);
+            if (child) {
+                QWidget* w = child->widget();
+                delete w;
+                delete child;
+            }
         }
 
         // Fill layout
