@@ -39,8 +39,10 @@
 SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(1, "SKGSearchPluginWidget::SKGSearchPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -87,9 +89,10 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
 
     // Fill combo boxes
     QStringList attributeForQuery;
-    attributeForQuery << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_TRANSFER" << "t_UNIT" << "t_ACCOUNT" << "t_TOACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND" << "f_BALANCE";
+    attributeForQuery << "d_DATEOP" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_TRANSFER" << "t_UNIT" << "t_ACCOUNT" << "t_TOACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND" << "f_BALANCE";
     QStringList attributeForUpdate;
-    attributeForUpdate << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_status" << "t_bookmarked" << "t_imported" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_ACCOUNT" << "t_REALREFUND" << "t_UNIT";
+    attributeForUpdate << "d_DATEOP" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_status" << "t_bookmarked" << "t_imported" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_ACCOUNT" << "t_REALREFUND" << "t_UNIT";
+    // WARNING: trigger must be modified if this list is modifier
 
     // Adding properties
     QStringList properties;
@@ -150,7 +153,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
 
 SKGSearchPluginWidget::~SKGSearchPluginWidget()
 {
-    SKGTRACEIN(1, "SKGSearchPluginWidget::~SKGSearchPluginWidget");
+    SKGTRACEINFUNC(1);
 }
 
 bool SKGSearchPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -171,7 +174,7 @@ bool SKGSearchPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 QString SKGSearchPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGSearchPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -182,7 +185,7 @@ QString SKGSearchPluginWidget::getState()
 
 void SKGSearchPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGSearchPluginWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -190,7 +193,9 @@ void SKGSearchPluginWidget::setState(const QString& iState)
     QString currentPage = root.attribute("currentPage");
     QString xmlsearchcondition = root.attribute("xmlsearchcondition");
 
-    if (currentPage.isEmpty()) currentPage = '0';
+    if (currentPage.isEmpty()) {
+        currentPage = '0';
+    }
 
     ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
     ui.kQueryCreator->setXMLCondition(xmlsearchcondition);
@@ -224,7 +229,7 @@ int SKGSearchPluginWidget::getNbSelectedObjects()
 
 void SKGSearchPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEIN(1, "SKGSearchPluginWidget::dataModified");
+    SKGTRACEINFUNC(1);
     Q_UNUSED(iIdTransaction);
 
     // Refresh account list
@@ -236,7 +241,7 @@ void SKGSearchPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 void SKGSearchPluginWidget::onAddRule()
 {
     SKGError err;
-    SKGTRACEINRC(1, "SKGSearchPluginWidget::onAddRule", err);
+    SKGTRACEINFUNCRC(1, err);
     {
         SKGRuleObject rule;
         {
@@ -267,7 +272,7 @@ void SKGSearchPluginWidget::onAddRule()
 void SKGSearchPluginWidget::onOpen()
 {
     SKGError err;
-    SKGTRACEINRC(1, "SKGSearchPluginWidget::onOpen", err);
+    SKGTRACEINFUNCRC(1, err);
     SKGRuleObject rule;
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     rule = SKGRuleObject(getDocument());
@@ -287,7 +292,7 @@ void SKGSearchPluginWidget::onOpen()
 void SKGSearchPluginWidget::onModifyRule()
 {
     SKGError err;
-    SKGTRACEINRC(1, "SKGSearchPluginWidget::onModifyRule", err);
+    SKGTRACEINFUNCRC(1, err);
     {
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Search and process update"), err);
         SKGObjectBase::SKGListSKGObjectBase rules = getSelectedObjects();
@@ -328,7 +333,9 @@ void SKGSearchPluginWidget::onSelectionChanged()
         ui.kQueryCreator->setXMLCondition(rule.getXMLSearchDefinition());
 
         int index = qMax(0, static_cast<int>(rule.getActionType()));
-        if (ui.kWidgetSelector->getSelectedMode() != -1) ui.kWidgetSelector->setSelectedMode(index);
+        if (ui.kWidgetSelector->getSelectedMode() != -1) {
+            ui.kWidgetSelector->setSelectedMode(index);
+        }
         if (index == 1) {
             // Set update mode
             ui.kActionCreator->setXMLCondition(rule.getXMLActionDefinition());
@@ -353,7 +360,7 @@ void SKGSearchPluginWidget::onSelectionChanged()
 void SKGSearchPluginWidget::onTop()
 {
     SKGError err;
-    SKGTRACEINRC(1, "SKGSearchPluginWidget::onTop", err);
+    SKGTRACEINFUNCRC(1, err);
 
     // Get rules
     SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
@@ -366,7 +373,9 @@ void SKGSearchPluginWidget::onTop()
             double order = 1;
             SKGStringListList result;
             err = getDocument()->executeSelectSqliteOrder("SELECT min(f_sortorder) from rule", result);
-            if (!err && result.count() == 2)  order = SKGServices::stringToDouble(result.at(1).at(0)) - 1;
+            if (!err && result.count() == 2) {
+                order = SKGServices::stringToDouble(result.at(1).at(0)) - 1;
+            }
 
             IFOKDO(err, rule.setOrder(order))
             IFOKDO(err, rule.save())
@@ -387,7 +396,7 @@ void SKGSearchPluginWidget::onTop()
 void SKGSearchPluginWidget::onUp()
 {
     SKGError err;
-    SKGTRACEINRC(1, "SKGSearchPluginWidget::onUp", err);
+    SKGTRACEINFUNCRC(1, err);
 
     // Get rules
     SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
@@ -427,7 +436,7 @@ void SKGSearchPluginWidget::onUp()
 void SKGSearchPluginWidget::onDown()
 {
     SKGError err;
-    SKGTRACEINRC(1, "SKGSearchPluginWidget::onDown", err);
+    SKGTRACEINFUNCRC(1, err);
 
     // Get rules
     SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
@@ -467,7 +476,7 @@ void SKGSearchPluginWidget::onDown()
 void SKGSearchPluginWidget::onBottom()
 {
     SKGError err;
-    SKGTRACEINRC(1, "SKGSearchPluginWidget::onBottom", err);
+    SKGTRACEINFUNCRC(1, err);
 
     // Get rules
     SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
@@ -480,7 +489,9 @@ void SKGSearchPluginWidget::onBottom()
             double order = 1;
             SKGStringListList result;
             err = getDocument()->executeSelectSqliteOrder("SELECT max(f_sortorder) from rule", result);
-            if (!err && result.count() == 2) order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+            if (!err && result.count() == 2) {
+                order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+            }
 
             IFOKDO(err, rule.setOrder(order))
             IFOKDO(err, rule.save())
@@ -500,7 +511,7 @@ void SKGSearchPluginWidget::onBottom()
 
 void SKGSearchPluginWidget::open(const SKGRuleObject& iRule, OpenMode iMode)
 {
-    _SKGTRACEIN(10, "SKGSearchPluginWidget::open");
+    _SKGTRACEINFUNC(10);
 
     // Build where clause and title
     QString wc = "i_SUBOPID in (SELECT i_SUBOPID FROM v_operation_prop WHERE " % iRule.getSelectSqlOrder() % ')';
@@ -545,15 +556,21 @@ void SKGSearchPluginWidget::onEditorModified()
         SKGStringListList result;
         int vAll = 0;
         getDocument()->executeSelectSqliteOrder("SELECT count(distinct(id)) from v_operation_prop WHERE " % wc, result);
-        if (result.count() == 2) vAll = SKGServices::stringToInt(result.at(1).at(0));
+        if (result.count() == 2) {
+            vAll = SKGServices::stringToInt(result.at(1).at(0));
+        }
 
         int vImported = 0;
         getDocument()->executeSelectSqliteOrder("SELECT count(distinct(id)) from v_operation_prop WHERE t_imported!='N' AND " % wc, result);
-        if (result.count() == 2) vImported = SKGServices::stringToInt(result.at(1).at(0));
+        if (result.count() == 2) {
+            vImported = SKGServices::stringToInt(result.at(1).at(0));
+        }
 
         int vNotValidatedl = 0;
         getDocument()->executeSelectSqliteOrder("SELECT count(distinct(id)) from v_operation_prop WHERE t_imported='P' AND " % wc, result);
-        if (result.count() == 2) vNotValidatedl = SKGServices::stringToInt(result.at(1).at(0));
+        if (result.count() == 2) {
+            vNotValidatedl = SKGServices::stringToInt(result.at(1).at(0));
+        }
 
         ui.kQueryInfo->setText(i18np("%1 operation found (%2 imported, %3 not yet validated).", "%1 operations found (%2 imported, %3 not yet validated).", vAll, vImported, vNotValidatedl));
     }
@@ -603,7 +620,9 @@ bool SKGSearchPluginWidget::isEditor()
 
 void SKGSearchPluginWidget::activateEditor()
 {
-    if (ui.kWidgetSelector->getSelectedMode() == -1) ui.kWidgetSelector->setSelectedMode(0);
+    if (ui.kWidgetSelector->getSelectedMode() == -1) {
+        ui.kWidgetSelector->setSelectedMode(0);
+    }
 }
 
 #include "skgsearchpluginwidget.moc"
