@@ -115,11 +115,11 @@ public:
 protected:
     /**
      * Event filtering
-     * @param object object
-     * @param event event
+     * @param iObject object
+     * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* object, QEvent* event);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
@@ -141,4 +141,4 @@ private:
     Ui::skgsearchplugin_base ui;
 };
 
-#endif // SKGSEARCHPLUGINWIDGET_H
+#endif  // SKGSEARCHPLUGINWIDGET_H
