@@ -34,8 +34,10 @@
 SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(1, "SKGTrackerPluginWidget::SKGTrackerPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -78,7 +80,7 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
 
 SKGTrackerPluginWidget::~SKGTrackerPluginWidget()
 {
-    SKGTRACEIN(1, "SKGTrackerPluginWidget::~SKGTrackerPluginWidget");
+    SKGTRACEINFUNC(1);
 }
 
 bool SKGTrackerPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -99,7 +101,7 @@ bool SKGTrackerPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 void SKGTrackerPluginWidget::onSelectionChanged()
 {
-    SKGTRACEIN(10, "SKGTrackerPluginWidget::onSelectionChanged");
+    SKGTRACEINFUNC(10);
 
     int nbSelect = ui.kView->getView()->getNbSelectedObjects();
     if (nbSelect == 1) {
@@ -118,7 +120,7 @@ void SKGTrackerPluginWidget::onSelectionChanged()
 
 QString SKGTrackerPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGTrackerPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -128,7 +130,7 @@ QString SKGTrackerPluginWidget::getState()
 
 void SKGTrackerPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGTrackerPluginWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -147,7 +149,7 @@ QWidget* SKGTrackerPluginWidget::mainWidget()
 
 void SKGTrackerPluginWidget::onEditorModified()
 {
-    _SKGTRACEIN(10, "SKGTrackerPluginWidget::onEditorModified");
+    _SKGTRACEINFUNC(10);
     int nb = ui.kView->getView()->getNbSelectedObjects();
     ui.kModifyButton->setEnabled(!ui.kNameInput->text().isEmpty() && nb >= 1);
     ui.kAddButton->setEnabled(!ui.kNameInput->text().isEmpty());
@@ -155,7 +157,7 @@ void SKGTrackerPluginWidget::onEditorModified()
 
 void SKGTrackerPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
-    SKGTRACEIN(10, "SKGTrackerPluginWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
 
     if (!iLightTransaction) {
@@ -170,7 +172,7 @@ void SKGTrackerPluginWidget::dataModified(const QString& iTableName, int iIdTran
 void SKGTrackerPluginWidget::onAddTracker()
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGTrackerPluginWidget::onAddTracker", err);
+    _SKGTRACEINFUNCRC(10, err);
 
     QString name = ui.kNameInput->text();
     SKGTrackerObject tracker;
@@ -197,7 +199,7 @@ void SKGTrackerPluginWidget::onAddTracker()
 void SKGTrackerPluginWidget::onModifyTracker()
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGTrackerPluginWidget::onModifyTracker", err);
+    _SKGTRACEINFUNCRC(10, err);
     // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
