@@ -31,7 +31,7 @@
 SKGUnitBoardWidget::SKGUnitBoardWidget(SKGDocument* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Title of a dashboard widget", "Quotes"))
 {
-    SKGTRACEIN(10, "SKGUnitBoardWidget::SKGUnitBoardWidget");
+    SKGTRACEINFUNC(10);
 
     // Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
@@ -88,7 +88,7 @@ SKGUnitBoardWidget::SKGUnitBoardWidget(SKGDocument* iDocument)
 
 SKGUnitBoardWidget::~SKGUnitBoardWidget()
 {
-    SKGTRACEIN(10, "SKGUnitBoardWidget::~SKGUnitBoardWidget");
+    SKGTRACEINFUNC(10);
     m_menuIndexes = NULL;
     m_menuShares = NULL;
     m_menuSharesOwnedOnly = NULL;
@@ -118,19 +118,31 @@ void SKGUnitBoardWidget::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    if (m_menuCurrencies) m_menuCurrencies->setChecked(root.attribute("m_menuCurrencies") == "Y");
-    if (m_menuObjects) m_menuObjects->setChecked(root.attribute("m_menuObjects") == "Y");
-    if (m_menuIndexes) m_menuIndexes->setChecked(root.attribute("menuIndexes") != "N");
-    if (m_menuShares) m_menuShares->setChecked(root.attribute("menuShares") != "N");
-    if (m_menuSharesOwnedOnly) m_menuSharesOwnedOnly->setChecked(root.attribute("menuSharesOwnedOnly") != "N");
-    if (m_menuFavorite) m_menuFavorite->setChecked(root.attribute("menuFavorite") == "Y");
+    if (m_menuCurrencies) {
+        m_menuCurrencies->setChecked(root.attribute("m_menuCurrencies") == "Y");
+    }
+    if (m_menuObjects) {
+        m_menuObjects->setChecked(root.attribute("m_menuObjects") == "Y");
+    }
+    if (m_menuIndexes) {
+        m_menuIndexes->setChecked(root.attribute("menuIndexes") != "N");
+    }
+    if (m_menuShares) {
+        m_menuShares->setChecked(root.attribute("menuShares") != "N");
+    }
+    if (m_menuSharesOwnedOnly) {
+        m_menuSharesOwnedOnly->setChecked(root.attribute("menuSharesOwnedOnly") != "N");
+    }
+    if (m_menuFavorite) {
+        m_menuFavorite->setChecked(root.attribute("menuFavorite") == "Y");
+    }
 
     dataModified("", 0);
 }
 
 void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEIN(10, "SKGUnitBoardWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
 
     if (iTableName == "v_unit_display" || iTableName.isEmpty()) {
@@ -144,30 +156,40 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
             if (m_menuSharesOwnedOnly && m_menuShares && m_menuIndexes) {
                 m_menuSharesOwnedOnly->setEnabled(m_menuShares->isChecked());
                 m_menuShares->setEnabled(!m_menuSharesOwnedOnly->isChecked());
-                if (!m_menuShares->isChecked()) m_menuSharesOwnedOnly->setChecked(false);
+                if (!m_menuShares->isChecked()) {
+                    m_menuSharesOwnedOnly->setChecked(false);
+                }
 
                 if (m_menuIndexes->isChecked()) {
                     wc = "t_type='I'";
                 }
                 if (m_menuShares->isChecked()) {
-                    if (!wc.isEmpty()) wc += " OR ";
-                    if (m_menuSharesOwnedOnly->isChecked()) wc += "(t_type='S' AND f_QUANTITYOWNED>0)";
-                    else {
+                    if (!wc.isEmpty()) {
+                        wc += " OR ";
+                    }
+                    if (m_menuSharesOwnedOnly->isChecked()) {
+                        wc += "(t_type='S' AND f_QUANTITYOWNED>0)";
+                    } else {
                         wc += "t_type='S'";
                     }
                 }
                 if (m_menuCurrencies->isChecked()) {
-                    if (!wc.isEmpty()) wc += " OR ";
+                    if (!wc.isEmpty()) {
+                        wc += " OR ";
+                    }
                     wc += "t_type IN ('1','2','C')";
                 }
                 if (m_menuObjects->isChecked()) {
-                    if (!wc.isEmpty()) wc += " OR ";
+                    if (!wc.isEmpty()) {
+                        wc += " OR ";
+                    }
                     wc += "t_type='O'";
                 }
             }
 
-            if (wc.isEmpty()) wc = "1=0";
-            else if (m_menuFavorite && m_menuFavorite->isChecked()) {
+            if (wc.isEmpty()) {
+                wc = "1=0";
+            } else if (m_menuFavorite && m_menuFavorite->isChecked()) {
                 wc = "t_bookmarked='Y' AND (" % wc % ')';
             }
 
@@ -190,7 +212,9 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                         html += QString("<tr><td><a href=\"skg://Skrooge_operation_plugin/?operationWhereClause=rc_unit_id=" % SKGServices::intToString(obj.getID()) %
                                         "&title=" % SKGServices::encodeForUrl(i18nc("A list of operations made on the specified unit", "Operations with unit equal to '%1'",  obj.getName())) %
                                         "&title_icon=view-currency-list&currentPage=-1" % "\">") % SKGServices::stringToHtml(obj.getDisplayName()) % "</a></td><td align=\"right\">";
-                        if (obj.getType() == SKGUnitObject::INDEX) primary.Symbol = ' ';
+                        if (obj.getType() == SKGUnitObject::INDEX) {
+                            primary.Symbol = ' ';
+                        }
                         html += doc->formatMoney(SKGServices::stringToDouble(obj.getAttribute("f_CURRENTAMOUNT")), primary);
                         html += "</td><td>(";
                         double val = obj.getDailyChange();
@@ -208,7 +232,9 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
             // No widget if no account
             bool exist = false;
             getDocument()->existObjects("account", "", exist);
-            if (parentWidget()) setVisible(exist);
+            if (parentWidget()) {
+                setVisible(exist);
+            }
         }
     }
 }
