@@ -53,22 +53,24 @@ SKGUnitPlugin::SKGUnitPlugin(QWidget* iWidget, QObject* iParent, const QVariantL
       m_splitShareAction(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGUnitPlugin::SKGUnitPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGUnitPlugin::~SKGUnitPlugin()
 {
-    SKGTRACEIN(10, "SKGUnitPlugin::~SKGUnitPlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
     m_splitShareAction = NULL;
 }
 
 bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGUnitPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) return false;
+    if (m_currentBankDocument == NULL) {
+        return false;
+    }
 
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_unit/skrooge_unit.rc");
@@ -114,7 +116,7 @@ SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
 
 void SKGUnitPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGUnitPlugin::refresh");
+    SKGTRACEINFUNC(10);
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         bool test = (m_currentBankDocument->getDatabase() != NULL);
         if (m_splitShareAction) {
@@ -150,7 +152,9 @@ void SKGUnitPlugin::refresh()
                     } else if (skgunit_settings::download_on_open()) {
                         // Check frequency
                         QString lastAutomaticDownload = m_currentBankDocument->getParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD");
-                        if (lastAutomaticDownload.isEmpty()) lastAutomaticDownload = "1970-01-01";
+                        if (lastAutomaticDownload.isEmpty()) {
+                            lastAutomaticDownload = "1970-01-01";
+                        }
                         QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
                         if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgunit_settings::download_frequency() == 0) ||
                                 (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgunit_settings::download_frequency() == 1) ||
@@ -183,13 +187,13 @@ void SKGUnitPlugin::refresh()
 
 SKGTabPage* SKGUnitPlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGUnitPlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGUnitPluginWidget(m_currentBankDocument);
 }
 
 QWidget* SKGUnitPlugin::getPreferenceWidget()
 {
-    SKGTRACEIN(10, "SKGUnitPlugin::getPreferenceWidget");
+    SKGTRACEINFUNC(10);
     QWidget* w = new QWidget();
     ui.setupUi(w);
 
@@ -243,7 +247,7 @@ bool SKGUnitPlugin::isInPagesChooser() const
 void SKGUnitPlugin::onSplitShare()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitPlugin::onSplitShare", err);
+    SKGTRACEINFUNCRC(10, err);
 
     // Get Selection
     if (SKGMainPanel::getMainPanel()) {
@@ -274,7 +278,7 @@ void SKGUnitPlugin::onSplitShare()
 
 SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGUnitPlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
 
     // Get all currencies
@@ -339,7 +343,9 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget download units to have a better view of your accounts"));
             QStringList autoCorrections;
             autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
-            if (!internet_code.isEmpty()) autoCorrections.push_back(i18nc("Advice on making the best (action)", "Download '%1'", unit));
+            if (!internet_code.isEmpty()) {
+                autoCorrections.push_back(i18nc("Advice on making the best (action)", "Download '%1'", unit));
+            }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -496,7 +502,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
 void SKGUnitPlugin::deleteUnusedUnits() const
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGUnitPlugin::deleteUnusedUnits", err);
+    _SKGTRACEINFUNCRC(10, err);
     if (m_currentBankDocument) {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused units")  , err);
 
