@@ -46,8 +46,10 @@
 SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(10, "SKGUnitPluginWidget::SKGUnitPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(10);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
     ui.kGraph->setShadowVisible(false);
@@ -67,7 +69,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     ui.kUnitTableViewEdition->getShowWidget()->addItem("all", i18nc("Noun, items to display", "All"), "",
             "",
             "currency;share;index;object",  // Check when checked
-            "highlighted", // Uncheck when checked
+            "highlighted",  // Uncheck when checked
             "", "",
             Qt::META + Qt::Key_A);
     ui.kUnitTableViewEdition->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "bookmarks", "t_bookmarked='Y'", "", "all;currency;share;index;object", "all", "", Qt::META + Qt::Key_H);
@@ -199,8 +201,9 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     iDocument->existObjects("unit", "t_type='1'", primaryUnit);
     iDocument->existObjects("unit", "t_type='2'", secondaryUnit);
     if (primaryUnit) {
-        if (secondaryUnit) ui.kTypeCreatorUnit->setCurrentIndex(2);
-        else {
+        if (secondaryUnit) {
+            ui.kTypeCreatorUnit->setCurrentIndex(2);
+        } else {
             ui.kTypeCreatorUnit->setCurrentIndex(1);
         }
     } else {
@@ -263,7 +266,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
 
 SKGUnitPluginWidget::~SKGUnitPluginWidget()
 {
-    SKGTRACEIN(10, "SKGUnitPluginWidget::~SKGUnitPluginWidget");
+    SKGTRACEINFUNC(10);
 }
 
 bool SKGUnitPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -294,12 +297,14 @@ void SKGUnitPluginWidget::fillSourceList()
     ui.kDeleteSource->hide();
 
     // Set previous selected itemData
-    if (!current.isEmpty() && ui.kDownloadSource->contains(current)) ui.kDownloadSource->setCurrentItem(current);
+    if (!current.isEmpty() && ui.kDownloadSource->contains(current)) {
+        ui.kDownloadSource->setCurrentItem(current);
+    }
 }
 
 void SKGUnitPluginWidget::onSelectionChanged()
 {
-    SKGTRACEIN(10, "SKGUnitPluginWidget::onSelectionChanged");
+    SKGTRACEINFUNC(10);
     // Mapping
     SKGUnitObject unit;
 
@@ -362,7 +367,9 @@ void SKGUnitPluginWidget::onSelectionChanged()
     ui.kGraph->setData(table, primaryUnit, secondaryUnit, SKGTableWithGraph::LIMITS);
 
     // Correction bug 2299394 vvv
-    if (ui.kUnitValueTableViewEdition->isAutoResized()) ui.kUnitValueTableViewEdition->resizeColumnsToContentsDelayed();
+    if (ui.kUnitValueTableViewEdition->isAutoResized()) {
+        ui.kUnitValueTableViewEdition->resizeColumnsToContentsDelayed();
+    }
     // Correction bug 2299394 ^^^
 
     onUnitCreatorModified();
@@ -371,7 +378,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
 
 void SKGUnitPluginWidget::onSelectionValueChanged()
 {
-    SKGTRACEIN(10, "SKGUnitPluginWidget::onSelectionValueChanged");
+    SKGTRACEINFUNC(10);
     // Mapping
     QItemSelectionModel* selModel = ui.kUnitValueTableViewEdition->selectionModel();
     if (selModel) {
@@ -401,7 +408,7 @@ void SKGUnitPluginWidget::onSelectionValueChanged()
 
 void SKGUnitPluginWidget::onUnitCreatorModified()
 {
-    SKGTRACEIN(10, "SKGUnitPluginWidget::onUnitCreatorModified");
+    SKGTRACEINFUNC(10);
 
     bool activated = ui.kWidgetSelector->getSelectedMode() != -1 &&
                      !ui.kNameCreatorUnit->text().isEmpty()  &&
@@ -413,13 +420,15 @@ void SKGUnitPluginWidget::onUnitCreatorModified()
     ui.kUnitUpdate->setEnabled(activated && nbSelect > 0 && ui.kWidgetSelector->getSelectedMode() == 1);
 
     ui.kWidgetSelector->setEnabledMode(2, nbSelect == 1);
-    if (!(activated && nbSelect > 0) && ui.kWidgetSelector->getSelectedMode() == 2) ui.kWidgetSelector->setSelectedMode(0);
+    if (!(activated && nbSelect > 0) && ui.kWidgetSelector->getSelectedMode() == 2) {
+        ui.kWidgetSelector->setSelectedMode(0);
+    }
 }
 
 void SKGUnitPluginWidget::onAddUnit()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitPluginWidget::onAddUnit", err);
+    SKGTRACEINFUNCRC(10, err);
     int mode = ui.kWidgetSelector->getSelectedMode();
 
     if (mode == 0) {
@@ -476,7 +485,7 @@ void SKGUnitPluginWidget::onAddUnit()
 void SKGUnitPluginWidget::onModifyUnit()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitPluginWidget::onModifyUnit", err);
+    SKGTRACEINFUNCRC(10, err);
     // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
 
@@ -509,10 +518,16 @@ void SKGUnitPluginWidget::onModifyUnit()
             IFOKDO(err, unitObj.setSymbol(ui.kSymbolCreatorUnit->text()))
             IFOKDO(err, unitObj.setCountry(ui.kCountryCreatorUnit->text()))
             IFOKDO(err, unitObj.setInternetCode(ui.kInternetCreatorUnit->text()))
-            if (!err && ui.kTypeCreatorUnit->text() != NOUPDATE) err = unitObj.setType(static_cast<SKGUnitObject::UnitType>(ui.kTypeCreatorUnit->itemData(ui.kTypeCreatorUnit->currentIndex()).toInt()));
+            if (!err && ui.kTypeCreatorUnit->text() != NOUPDATE) {
+                err = unitObj.setType(static_cast<SKGUnitObject::UnitType>(ui.kTypeCreatorUnit->itemData(ui.kTypeCreatorUnit->currentIndex()).toInt()));
+            }
             IFOKDO(err, unitObj.setNumberDecimal(ui.kNbDecimal->value()))
-            if (!err && ui.kUnitCreatorUnit->text() != NOUPDATE) err = unitObj.setUnit(ui.kUnitCreatorUnit->getUnit());
-            if (!err && ui.kDownloadSource->text() != NOUPDATE) err = unitObj.setDownloadSource(ui.kDownloadSource->text());
+            if (!err && ui.kUnitCreatorUnit->text() != NOUPDATE) {
+                err = unitObj.setUnit(ui.kUnitCreatorUnit->getUnit());
+            }
+            if (!err && ui.kDownloadSource->text() != NOUPDATE) {
+                err = unitObj.setDownloadSource(ui.kDownloadSource->text());
+            }
             IFOKDO(err, unitObj.save())
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
@@ -531,8 +546,9 @@ void SKGUnitPluginWidget::onModifyUnit()
 SKGUnitObject::UnitDownloadMode SKGUnitPluginWidget::getDownloadModeFromSettings()
 {
     SKGUnitObject::UnitDownloadMode mode = SKGUnitObject::LAST;
-    if (skgunit_settings::last()) mode = SKGUnitObject::LAST;
-    else if (skgunit_settings::last_monthly()) {
+    if (skgunit_settings::last()) {
+        mode = SKGUnitObject::LAST;
+    } else if (skgunit_settings::last_monthly()) {
         mode = SKGUnitObject::LAST_MONTHLY;
     } else if (skgunit_settings::last_weekly()) {
         mode = SKGUnitObject::LAST_WEEKLY;
@@ -551,7 +567,7 @@ SKGUnitObject::UnitDownloadMode SKGUnitPluginWidget::getDownloadModeFromSettings
 SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, SKGUnitObject::UnitDownloadMode mode)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitPluginWidget::downloadUnitValue", err);
+    SKGTRACEINFUNCRC(10, err);
 
     QString unitname = iUnit.getName();
     QString code = iUnit.getInternetCode();
@@ -567,12 +583,13 @@ SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, SKGU
 void SKGUnitPluginWidget::onDownloadUnitValue()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitPluginWidget::onDownloadUnitValue", err);
+    SKGTRACEINFUNCRC(10, err);
 
     SKGUnitObject::UnitDownloadMode mode = SKGUnitObject::LAST;
     KAction* act = qobject_cast<KAction*>(sender());
-    if (act) mode = static_cast<SKGUnitObject::UnitDownloadMode>(act->data().toInt());
-    else {
+    if (act) {
+        mode = static_cast<SKGUnitObject::UnitDownloadMode>(act->data().toInt());
+    } else {
         mode = SKGUnitPluginWidget::getDownloadModeFromSettings();
     }
 
@@ -600,7 +617,7 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
 void SKGUnitPluginWidget::onSimplify()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitPluginWidget::onSimplify", err);
+    SKGTRACEINFUNCRC(10, err);
 
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
     int nb = selection.count();
@@ -629,7 +646,9 @@ SKGObjectBase::SKGListSKGObjectBase SKGUnitPluginWidget::getSelectedObjects()
     if (ui.kUnitValueTableViewEdition->hasFocus()) {
         output = ui.kUnitValueTableViewEdition->getSelectedObjects();
     }
-    if (output.count() == 0) output = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
+    if (output.count() == 0) {
+        output = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
+    }
     return output;
 }
 
@@ -639,14 +658,16 @@ int SKGUnitPluginWidget::getNbSelectedObjects()
     if (ui.kUnitValueTableViewEdition->hasFocus()) {
         output = ui.kUnitValueTableViewEdition->getNbSelectedObjects();
     }
-    if (output == 0) output = ui.kUnitTableViewEdition->getView()->getNbSelectedObjects();
+    if (output == 0) {
+        output = ui.kUnitTableViewEdition->getView()->getNbSelectedObjects();
+    }
     return output;
 }
 
 
 QString SKGUnitPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGUnitPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -666,7 +687,7 @@ QString SKGUnitPluginWidget::getState()
 
 void SKGUnitPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGUnitPluginWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -676,10 +697,16 @@ void SKGUnitPluginWidget::setState(const QString& iState)
     QString currentPage = root.attribute("currentPage");
     QString obsolete = root.attribute("obsolete");
 
-    if (currentPage.isEmpty()) currentPage = '0';
+    if (currentPage.isEmpty()) {
+        currentPage = '0';
+    }
 
-    if (!splitter1State.isEmpty()) ui.kMainSplitter->restoreState(QByteArray::fromHex(splitter1State.toAscii()));
-    if (!splitter2State.isEmpty()) ui.kValuesSplitter->restoreState(QByteArray::fromHex(splitter2State.toAscii()));
+    if (!splitter1State.isEmpty()) {
+        ui.kMainSplitter->restoreState(QByteArray::fromHex(splitter1State.toAscii()));
+    }
+    if (!splitter2State.isEmpty()) {
+        ui.kValuesSplitter->restoreState(QByteArray::fromHex(splitter2State.toAscii()));
+    }
     ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
     ui.kObsolete->setChecked(obsolete == "Y");
 
@@ -696,12 +723,14 @@ QString SKGUnitPluginWidget::getDefaultStateAttribute()
 
 void SKGUnitPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEIN(10, "SKGUnitPluginWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
 
     if (iTableName == "unitvalue" || iTableName.isEmpty()) {
         // Correction bug 2299394 vvv
-        if (ui.kUnitValueTableViewEdition->isAutoResized()) ui.kUnitValueTableViewEdition->resizeColumnsToContentsDelayed();
+        if (ui.kUnitValueTableViewEdition->isAutoResized()) {
+            ui.kUnitValueTableViewEdition->resizeColumnsToContentsDelayed();
+        }
         // Correction bug 2299394 ^^^
     }
 }
@@ -724,7 +753,9 @@ bool SKGUnitPluginWidget::isEditor()
 
 void SKGUnitPluginWidget::activateEditor()
 {
-    if (ui.kWidgetSelector->getSelectedMode() == -1) ui.kWidgetSelector->setSelectedMode(0);
+    if (ui.kWidgetSelector->getSelectedMode() == -1) {
+        ui.kWidgetSelector->setSelectedMode(0);
+    }
     ui.kCurrencyList->setFocus();
 }
 
@@ -751,8 +782,9 @@ void SKGUnitPluginWidget::refreshUnitList()
 
 QWidget* SKGUnitPluginWidget::mainWidget()
 {
-    if (ui.kUnitValueTableViewEdition->hasFocus())
+    if (ui.kUnitValueTableViewEdition->hasFocus()) {
         return ui.kUnitValueTableViewEdition;
+    }
     return ui.kUnitTableViewEdition->getView();
 }
 
@@ -829,7 +861,7 @@ void SKGUnitPluginWidget::onPutNewHotStuff()
 void SKGUnitPluginWidget::onOpenURL()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitPluginWidget::onOpenURL", err);
+    SKGTRACEINFUNCRC(10, err);
 
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
     int nb = selection.count();
