@@ -56,19 +56,25 @@ void SKGDataEngine::init()
 
     // Get the document behind the current document
     SKGMainPanel* panel = SKGMainPanel::getMainPanel();
-    if (panel) setDocument(qobject_cast<SKGDocumentBank*> (panel->getDocument()));
+    if (panel) {
+        setDocument(qobject_cast<SKGDocumentBank*> (panel->getDocument()));
+    }
 }
 
 QStringList SKGDataEngine::sources() const
 {
     QStringList sources;
-    if (this->getDocument()) sources << SRC_ACCOUNTS << SRC_INCOMESANDEXPENDITURES << SRC_BANKS << SRC_HIGHLIGHTED << SRC_SCHEDULED << SRC_UNITS << SRC_ADVICES;
+    if (this->getDocument()) {
+        sources << SRC_ACCOUNTS << SRC_INCOMESANDEXPENDITURES << SRC_BANKS << SRC_HIGHLIGHTED << SRC_SCHEDULED << SRC_UNITS << SRC_ADVICES;
+    }
     return sources;
 }
 
 bool SKGDataEngine::updateSourceEvent(const QString& source)
 {
-    if (!document) return false;
+    if (!document) {
+        return false;
+    }
     if (source == SRC_ACCOUNTS) {
         return getAccountData();
     } else if (source == SRC_INCOMESANDEXPENDITURES) {
@@ -95,7 +101,9 @@ bool SKGDataEngine::sourceRequestEvent(const QString& source)
 bool SKGDataEngine::getAccountData()
 {
     removeAllData(SRC_ACCOUNTS);
-    if (!document) return false;
+    if (!document) {
+        return false;
+    }
 
     SKGStringListList sqlResult;
 
@@ -123,7 +131,9 @@ bool SKGDataEngine::getAccountData()
 bool SKGDataEngine::getIncomeExpenditureData()
 {
     removeAllData(SRC_INCOMESANDEXPENDITURES);
-    if (!document) return false;
+    if (!document) {
+        return false;
+    }
 
     QDate date = QDate::currentDate();
 
@@ -151,7 +161,9 @@ bool SKGDataEngine::getIncomeExpenditureData()
 bool SKGDataEngine::getHighlightedOperationData()
 {
     removeAllData(SRC_HIGHLIGHTED);
-    if (!document) return false;
+    if (!document) {
+        return false;
+    }
 
     SKGStringListList sqlResult;
 
@@ -178,7 +190,9 @@ bool SKGDataEngine::getHighlightedOperationData()
 bool SKGDataEngine::getScheduledOperationData()
 {
     removeAllData(SRC_SCHEDULED);
-    if (!document) return false;
+    if (!document) {
+        return false;
+    }
 
     SKGStringListList sqlResult;
 
@@ -205,7 +219,9 @@ bool SKGDataEngine::getScheduledOperationData()
 bool SKGDataEngine::getUnitsData()
 {
     removeAllData(SRC_UNITS);
-    if (!document) return false;
+    if (!document) {
+        return false;
+    }
 
     SKGStringListList sqlResult;
 
@@ -238,7 +254,9 @@ bool SKGDataEngine::getUnitsData()
 bool SKGDataEngine::getAdviceData()
 {
     removeAllData(SRC_ADVICES);
-    if (!document) return false;
+    if (!document) {
+        return false;
+    }
 
     // Get list of ignored advice
     QString currentMonth = QDate::currentDate().toString("yyyy-MM");
@@ -272,7 +290,9 @@ bool SKGDataEngine::getAdviceData()
 bool SKGDataEngine::getInterestsData()
 {
     removeAllData(SRC_INTERESTS);
-    if (!document) return false;
+    if (!document) {
+        return false;
+    }
 
     SKGStringListList sqlResult;
 
@@ -307,7 +327,9 @@ bool SKGDataEngine::getInterestsData()
 bool SKGDataEngine::getAlarmsData()
 {
     removeAllData(SRC_ALARMS);
-    if (!document) return false;
+    if (!document) {
+        return false;
+    }
 
     SKGStringListList sqlResult;
 
@@ -341,7 +363,9 @@ void SKGDataEngine::setDocument(SKGDocumentBank* iDocument)
     document = iDocument;
 
     // Whenever a table is modified, update sources
-    if (document) connect(document, SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(updateAllSources()));  // TODO(Stephane MANKOWSKI) How to updale only modified sources
+    if (document) {
+        connect(document, SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(updateAllSources()));    // TODO(Stephane MANKOWSKI) How to updale only modified sources
+    }
 }
 /*
 transactionEnded(int trans)
