@@ -59,7 +59,20 @@ SKGObjectModel(SKGDocumentBank* iDocument,
 {
     SKGTRACEINFUNC(1);
 
-
+    m_operationTable = "";
+    m_recurrentoperationTable = "";
+    m_trackerTable = "";
+    m_accountTable = "";
+    m_unitTable = "";
+    m_unitvalueTable = "";
+    m_suboperationTable = "";
+    m_categoryTable = "";
+    m_ruleTable = "";
+    m_interestTable = "";
+    m_interestResultTable = "";
+    m_payeeTable = "";
+    m_budgetTable = "";
+    m_budgetRuleTable = "";
     m_isResetRealyNeeded = iResetOnCreation;
     refresh();
 }
