@@ -73,7 +73,9 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
         SKGServices::SKGAttributesList attributes;
         m_document->getAttributesDescription(m_table, attributes);
         foreach(const SKGServices::SKGAttributeInfo & att, attributes) {
-            if (iListAttribute.count() == 0 || iListAttribute.contains(att.name)) listAtts.push_back(att);
+            if (iListAttribute.count() == 0 || iListAttribute.contains(att.name)) {
+                listAtts.push_back(att);
+            }
         }
 
         // Adding properties
@@ -244,10 +246,18 @@ QString SKGQueryCreator::getXMLCondition()
 
                         elementElement.setAttribute("attribute", attname);
                         elementElement.setAttribute("operator", root2.attribute("operator"));
-                        if (root2.hasAttribute("value")) elementElement.setAttribute("value", root2.attribute("value"));
-                        if (root2.hasAttribute("value2")) elementElement.setAttribute("value2", root2.attribute("value2"));
-                        if (root2.hasAttribute("att2")) elementElement.setAttribute("att2", root2.attribute("att2"));
-                        if (root2.hasAttribute("att2s")) elementElement.setAttribute("att2s", root2.attribute("att2s"));
+                        if (root2.hasAttribute("value")) {
+                            elementElement.setAttribute("value", root2.attribute("value"));
+                        }
+                        if (root2.hasAttribute("value2")) {
+                            elementElement.setAttribute("value2", root2.attribute("value2"));
+                        }
+                        if (root2.hasAttribute("att2")) {
+                            elementElement.setAttribute("att2", root2.attribute("att2"));
+                        }
+                        if (root2.hasAttribute("att2s")) {
+                            elementElement.setAttribute("att2s", root2.attribute("att2s"));
+                        }
 
                         atLeastOne = true;
                         empty = false;
@@ -255,9 +265,13 @@ QString SKGQueryCreator::getXMLCondition()
                 }
             }
 
-            if (!atLeastOne) element.removeChild(elementLine);
+            if (!atLeastOne) {
+                element.removeChild(elementLine);
+            }
+        }
+        if (!empty) {
+            output = doc.toString();
         }
-        if (!empty) output = doc.toString();
     }
 
     return output;
@@ -273,11 +287,15 @@ void SKGQueryCreator::onCloseEditor()
         lineEmpty = true;
         for (int i = 0; lineEmpty && i < nbCol; ++i) {
             QTableWidgetItem* it = ui.kList->item(j, i);
-            if (it && !it->text().isEmpty()) lineEmpty = false;
+            if (it && !it->text().isEmpty()) {
+                lineEmpty = false;
+            }
         }
     }
 
-    if (!lineEmpty) addNewLine();
+    if (!lineEmpty) {
+        addNewLine();
+    }
 }
 
 void SKGQueryCreator::onAddColumn()
