@@ -42,7 +42,7 @@ QWidget* SKGQueryDelegate::createEditor(QWidget* iParent,
                                         const QStyleOptionViewItem& option ,
                                         const QModelIndex& index) const
 {
-    SKGTRACEIN(1, "SKGQueryDelegate::createEditor");
+    SKGTRACEINFUNC(1);
     Q_UNUSED(option);
 
     QTableWidgetItem* it_h = (static_cast<QTableWidget*>(this->parent()))->horizontalHeaderItem(index.column());
@@ -55,7 +55,7 @@ QWidget* SKGQueryDelegate::createEditor(QWidget* iParent,
 
 void SKGQueryDelegate::setEditorData(QWidget* editor, const QModelIndex& index) const
 {
-    SKGTRACEIN(1, "SKGQueryDelegate::setEditorData");
+    SKGTRACEINFUNC(1);
     SKGPredicatCreator* pred = qobject_cast<SKGPredicatCreator*>(editor);
     if (pred) {
         pred->setXmlDescription(index.model()->data(index, Qt::UserRole).toString());
@@ -67,7 +67,7 @@ void SKGQueryDelegate::setEditorData(QWidget* editor, const QModelIndex& index)
 void SKGQueryDelegate::setModelData(QWidget* editor, QAbstractItemModel* model,
                                     const QModelIndex& index) const
 {
-    SKGTRACEIN(1, "SKGQueryDelegate::setModelData");
+    SKGTRACEINFUNC(1);
     SKGPredicatCreator* pred = qobject_cast<SKGPredicatCreator*>(editor);
     if (pred && model) {
         QString xml = pred->xmlDescription();
