@@ -82,7 +82,9 @@ void SKGUnitComboBox::refershList()
     if (m_document) {
         SKGMainPanel::fillWithDistinctValue(this, m_document, "unit", "ifnull(t_symbol,t_name)", m_fillWhereClause);
         SKGServices::SKGUnitInfo primary = m_document->getPrimaryUnit();
-        if (!primary.Symbol.isEmpty()) this->setCurrentIndex(this->findText(primary.Symbol));
+        if (!primary.Symbol.isEmpty()) {
+            this->setCurrentIndex(this->findText(primary.Symbol));
+        }
     }
 }
 
@@ -94,7 +96,9 @@ void SKGUnitComboBox::dataModified(const QString& iTableName, int iIdTransaction
     if (m_document) {
         QSqlDatabase* db = m_document->getDatabase();
         setEnabled(db != NULL);
-        if (db != NULL && (iTableName == "unit" || iTableName.isEmpty())) refershList();
+        if (db != NULL && (iTableName == "unit" || iTableName.isEmpty())) {
+            refershList();
+        }
     }
 }
 
