@@ -28,6 +28,7 @@
 #include "skgsuboperationobject.h"
 #include "skgunitobject.h"
 #include "skginterestobject.h"
+#include "skgpayeeobject.h"
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
@@ -125,6 +126,28 @@ SKGError SKGAccountObject::getBank(SKGBankObject& oBank) const
     return err;
 }
 
+SKGError SKGAccountObject::setLinkedAccount(const SKGAccountObject& iAccount)
+{
+    return setAttribute("r_account_id", SKGServices::intToString(iAccount.getID()));
+}
+
+SKGError SKGAccountObject::getLinkedAccount(SKGAccountObject& oAccount) const
+{
+    SKGError err = getDocument()->getObject("v_account", "id=" % getAttribute("r_account_id"), oAccount);
+    return err;
+}
+
+SKGError SKGAccountObject::getLinkedByAccounts(SKGListSKGObjectBase& oAccounts) const
+{
+    SKGError err;
+    if (getDocument()) {
+        err = getDocument()->getObjects("v_account",
+                                        "r_account_id=" % SKGServices::intToString(getID()) ,
+                                        oAccounts);
+    }
+    return err;
+}
+
 SKGError SKGAccountObject::setNumber(const QString& iNumber)
 {
     return setAttribute("t_number", iNumber);
@@ -690,6 +713,70 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
     return err;
 }
 
+SKGError SKGAccountObject::transferDeferredOperations(const SKGAccountObject& iTargetAccount, const QDate& iDate)
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(10, err);
+    //
+    SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+    if (doc) {
+        // Get pointed operations
+        SKGObjectBase::SKGListSKGObjectBase operations;
+        IFOKDO(err, getDocument()->getObjects("v_operation", "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='P'", operations))
+        int nb = operations.count();
+        if (nb) {
+            SKGOperationObject mergedOperations;
+            SKGOperationObject balancedOperations;
+            for (int i = 0; !err && i < nb; ++i) {
+                SKGOperationObject op(operations.at(i));
+
+                // Create the balance operation
+                SKGOperationObject opdup;
+                IFOKDO(err, op.duplicate(opdup, iDate))
+
+                SKGListSKGObjectBase subops;
+                IFOKDO(err, opdup.getSubOperations(subops))
+                int nbsupops = subops.count();
+                for (int j = 0; !err && j < nbsupops; ++j) {
+                    SKGSubOperationObject subop(subops.at(j));
+                    IFOKDO(err, subop.setDate(op.getDate()))
+                    IFOKDO(err, subop.setQuantity(-subop.getQuantity()))
+                    IFOKDO(err, subop.save())
+                }
+
+                if (i == 0) {
+                    mergedOperations = opdup;
+                } else {
+                    IFOKDO(err, mergedOperations.mergeSuboperations(opdup))
+                }
+
+                // Create the duplicate in target account
+                SKGOperationObject opduptarget;
+                IFOKDO(err, op.duplicate(opduptarget))
+                IFOKDO(err, opduptarget.setDate(op.getDate()))
+                IFOKDO(err, opduptarget.setParentAccount(iTargetAccount))
+                IFOKDO(err, opduptarget.setImported(op.isImported()))
+                IFOKDO(err, opduptarget.setImportID(op.getImportID()))
+                IFOKDO(err, opduptarget.setGroupOperation(mergedOperations))
+                IFOKDO(err, opduptarget.setStatus(SKGOperationObject::POINTED))
+                IFOKDO(err, opduptarget.save())
+                IFOKDO(err, mergedOperations.load())  // To reload the modif done by the setGroupOperation
+
+                // Check the operation
+                IFOKDO(err, op.setStatus(SKGOperationObject::CHECKED))
+                IFOKDO(err, op.save())
+            }
+
+            // Check the balance operation
+            IFOKDO(err, mergedOperations.setPayee(SKGPayeeObject()))
+            IFOKDO(err, mergedOperations.setStatus(SKGOperationObject::CHECKED))
+            IFOKDO(err, mergedOperations.save())
+        }
+    }
+
+    return err;
+}
+
 SKGError SKGAccountObject::autoReconcile(double iBalance)
 {
     SKGError err;
@@ -771,11 +858,11 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
     SKGTRACEINFUNCRC(10, err);
 
     // Get initial balances
-    double balance1;
+    double balance1 = 0.0;
     SKGUnitObject unit1;
     err = getInitialBalance(balance1, unit1);
 
-    double balance2;
+    double balance2 = 0.0;
     SKGUnitObject unit2;
     IFOKDO(err, const_cast<SKGAccountObject*>(&iAccount)->getInitialBalance(balance2, unit2))
 
