@@ -64,16 +64,22 @@ QString SKGBudgetObject::getWhereclauseId() const
     QString output = SKGObjectBase::getWhereclauseId();
     if (output.isEmpty()) {
         QString y = getAttribute("i_year");
-        if (!y.isEmpty()) output = "i_year=" % y;
+        if (!y.isEmpty()) {
+            output = "i_year=" % y;
+        }
 
         QString m = getAttribute("i_month");
         if (!m.isEmpty()) {
-            if (!output.isEmpty()) output = output % " AND ";
+            if (!output.isEmpty()) {
+                output = output % " AND ";
+            }
             output = output % "i_month=" % m;
         }
 
         QString r = getAttribute("rc_category_id");
-        if (!output.isEmpty()) output = output % " AND ";
+        if (!output.isEmpty()) {
+            output = output % " AND ";
+        }
         output = output % "rc_category_id=" % (r.isEmpty() ? "0" : r);
     }
     return output;
@@ -149,7 +155,7 @@ SKGError SKGBudgetObject::removeCategory()
 SKGError SKGBudgetObject::process()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGBudgetObject::process", err);
+    SKGTRACEINFUNCRC(10, err);
     // Main values
     int m = getMonth();
     int y = getYear();
@@ -243,7 +249,7 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
 {
     Q_UNUSED(iUseScheduledOperation);
     SKGError err;
-    SKGTRACEINRC(10, "SKGBudgetObject::createAutomaticBudget", err);
+    SKGTRACEINFUNCRC(10, err);
     QString baseYear = SKGServices::intToString(iBaseYear);
     int fistMonth = 0;
     if (iDocument) {
@@ -252,7 +258,9 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
                   "SELECT MIN(STRFTIME('%m', d_date)) FROM operation WHERE i_group_id = 0 AND STRFTIME('%Y', d_date) = '" % baseYear %
                   "' AND t_template='N'",
                   listTmp);
-        if (listTmp.count() == 2)  fistMonth = SKGServices::stringToInt(listTmp.at(1).at(0));
+        if (listTmp.count() == 2) {
+            fistMonth = SKGServices::stringToInt(listTmp.at(1).at(0));
+        }
     }
     if (!err && iDocument) {
         SKGStringListList listTmp;
@@ -326,7 +334,7 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
 SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank* iDocument, int iYear, int iMonth, bool iBalanceYear)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGBudgetObject::balanceBudget", err);
+    SKGTRACEINFUNCRC(10, err);
     if (iDocument) {
         err = iDocument->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Balance budgets"), 2);
 
