@@ -180,7 +180,7 @@ SKGError SKGBudgetRuleObject::getTransferCategory(SKGCategoryObject& oCategory)
 SKGError SKGBudgetRuleObject::processAllRules(SKGDocumentBank* iDocument)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGBudgetRuleObject::processAllRules", err);
+    SKGTRACEINFUNCRC(10, err);
     if (iDocument) {
         // Initialize
         err = iDocument->executeSqliteOrder("UPDATE budget SET f_budgeted_modified=f_budgeted  WHERE f_budgeted_modified!=f_budgeted");
