@@ -59,8 +59,9 @@ const SKGCategoryObject& SKGCategoryObject::operator= (const SKGObjectBase& iObj
 SKGError SKGCategoryObject::setName(const QString& iName)
 {
     SKGError err;
-    if (iName.contains(OBJECTSEPARATOR)) err = SKGError(ERR_FAIL,  i18nc("Error message", "Invalid name '%1' because of the name cannot contain '%2'" , iName, QString(OBJECTSEPARATOR)));
-    else {
+    if (iName.contains(OBJECTSEPARATOR)) {
+        err = SKGError(ERR_FAIL,  i18nc("Error message", "Invalid name '%1' because of the name cannot contain '%2'" , iName, QString(OBJECTSEPARATOR)));
+    } else {
         err = SKGNamedObject::setName(iName);
     }
     return err;
@@ -75,9 +76,12 @@ QString SKGCategoryObject::getWhereclauseId() const
             output = "t_name='" % SKGServices::stringToSqlString(getAttribute("t_name")) % '\'';
         }
         QString rd_category_id = getAttribute("rd_category_id");
-        if (!output.isEmpty()) output += " AND ";
-        if (rd_category_id.isEmpty()) output += "(rd_category_id=0 OR rd_category_id IS NULL OR rd_category_id='')";
-        else {
+        if (!output.isEmpty()) {
+            output += " AND ";
+        }
+        if (rd_category_id.isEmpty()) {
+            output += "(rd_category_id=0 OR rd_category_id IS NULL OR rd_category_id='')";
+        } else {
             output += "rd_category_id=" % rd_category_id;
         }
     }
@@ -96,14 +100,15 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
         bool iRenameIfAlreadyExist)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGCategoryObject::createPathCategory", err);
+    SKGTRACEINFUNCRC(10, err);
 
     // Check if category is already existing
     if (iFullPath.isEmpty()) {
         oCategory = SKGCategoryObject(NULL, 0);
     } else if (iDocument) {
-        if (!iRenameIfAlreadyExist) iDocument->getObject("v_category", "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oCategory);
-        else {
+        if (!iRenameIfAlreadyExist) {
+            iDocument->getObject("v_category", "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oCategory);
+        } else {
             oCategory.resetID();
         }
         if (oCategory.getID() == 0) {
@@ -166,9 +171,10 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
 SKGError SKGCategoryObject::addCategory(SKGCategoryObject& oCategory)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGCategoryObject::addCategory", err);
-    if (getID() == 0)  err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::addCategory")));
-    else {
+    SKGTRACEINFUNCRC(10, err);
+    if (getID() == 0) {
+        err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::addCategory")));
+    } else {
         oCategory = SKGCategoryObject(static_cast<SKGDocumentBank*>(getDocument()));
         err = oCategory.setAttribute("rd_category_id", SKGServices::intToString(getID()));
     }
@@ -178,9 +184,10 @@ SKGError SKGCategoryObject::addCategory(SKGCategoryObject& oCategory)
 SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGCategoryObject::setParentCategory", err);
-    if (iCategory.getID() == 0) err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::setParentCategory")));
-    else {
+    SKGTRACEINFUNCRC(10, err);
+    if (iCategory.getID() == 0) {
+        err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::setParentCategory")));
+    } else {
         // Check if it's a loop
         SKGCategoryObject current = iCategory;
         do {
@@ -207,7 +214,9 @@ SKGError SKGCategoryObject::getParentCategory(SKGCategoryObject& oCategory) cons
 {
     SKGError err;
     QString parent_id = getAttribute("rd_category_id");
-    if (!parent_id.isEmpty() && parent_id != "0") err = getDocument()->getObject("v_category", "id=" % parent_id , oCategory);
+    if (!parent_id.isEmpty() && parent_id != "0") {
+        err = getDocument()->getObject("v_category", "id=" % parent_id , oCategory);
+    }
     return err;
 }
 
