@@ -48,6 +48,7 @@ SKGImportExportManager::SKGImportExportManager(SKGDocumentBank* iDocument,
 {
     setAutomaticValidation(true);
     setAutomaticApplyRules(false);
+    m_since_last_import = true;
 }
 
 SKGImportExportManager::~SKGImportExportManager()
@@ -139,18 +140,15 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         foreach(const QString & val, name.split(' ')) {
             whereClause += " OR t_number='" % val % "'";
         }
-        if (!whereClause.isEmpty()) {
-            SKGObjectBase::SKGListSKGObjectBase listAccount;
-            err = m_document->getObjects("v_account", whereClause, listAccount);
-            IFOK(err) {
-                if (listAccount.count() == 1) {
-                    // Yes ! Only one account found
-                    SKGAccountObject account(listAccount.at(0));
-                    m_defaultAccount = new SKGAccountObject(account);
-                    err = m_document->sendMessage(i18nc("An information message",  "Using account '%1' for import", account.getName()));
-                } else if (listAccount.count() > 1) {
-                    err = m_document->sendMessage(i18nc("An information message",  "More than one possible account found."));
-                }
+
+        SKGObjectBase::SKGListSKGObjectBase listAccount;
+        err = m_document->getObjects("v_account", whereClause % " ORDER BY t_type ASC", listAccount);
+        IFOK(err) {
+            if (listAccount.count() > 0) {
+                // Yes ! Only one account found
+                SKGAccountObject account(listAccount.at(0));
+                m_defaultAccount = new SKGAccountObject(account);
+                err = m_document->sendMessage(i18nc("An information message",  "Using account '%1' for import", account.getName()));
             }
         }
 
@@ -284,7 +282,7 @@ SKGError SKGImportExportManager::finalizeImportation()
     SKGTRACEINFUNCRC(2, err);
     if (m_document && !getImportParameters().contains("donotfinalize")) {
         // Count the number of operations imported but already existing
-        QString wc = "v_operation.t_imported='T' AND v_operation.t_import_id<>'' AND exists (SELECT 1 from v_operation op2 WHERE op2.t_imported!='T' AND op2.rd_account_id=v_operation.rd_account_id AND op2.t_import_id=v_operation.t_import_id AND ABS(op2.f_CURRENTAMOUNT-v_operation.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % ')';
+        QString wc = "v_operation.t_imported='T' AND exists (SELECT 1 from v_operation op2 WHERE op2.t_imported!='T' AND op2.rd_account_id=v_operation.rd_account_id AND op2.t_import_id=v_operation.t_import_id AND ABS(op2.f_CURRENTAMOUNT-v_operation.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % ')';
         int nbOperations;
         err = m_document->getNbObjects("v_operation", wc, nbOperations);
         if (!err && nbOperations) {
