@@ -484,7 +484,7 @@ SKGError SKGOperationObject::getRecurrentOperations(SKGListSKGObjectBase& oRecur
     return err;
 }
 
-SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOne)
+SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOne, SKGOperationObject::AmountAlignmentMode iMode)
 {
     // Merge operation
     SKGError err = setDate(iDeletedOne.getDate());
@@ -508,26 +508,40 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     IFOKDO(err, save())
 
     // Merge suboperations
-    if (qAbs(getCurrentAmount() - iDeletedOne.getCurrentAmount()) > 0.0001) {
+    double currentAmount = getCurrentAmount();
+    double targettAmount = iDeletedOne.getCurrentAmount();
+    if (qAbs(currentAmount - targettAmount) > 0.0001) {
         SKGObjectBase::SKGListSKGObjectBase subOps1;
         IFOKDO(err, getSubOperations(subOps1))
 
         SKGObjectBase::SKGListSKGObjectBase subOps2;
         IFOKDO(err, iDeletedOne.getSubOperations(subOps2))
 
-        if (subOps2.count() == 1 && subOps1.count() == 1) {
-            // Change the quantity of the sub operation
-            SKGSubOperationObject so1(subOps1.at(0));
-            SKGSubOperationObject so2(subOps2.at(0));
-            IFOKDO(err, so1.setQuantity(so2.getQuantity()))
-            IFOKDO(err, so1.save())
-        } else if (subOps2.count() >= 1 && subOps1.count() >= 1) {
-            // Add a split
+        // Align amounts
+        SKGOperationObject::AmountAlignmentMode mode = iMode;
+        if (mode == DEFAULT) {
+            if (subOps2.count() == 1 && subOps1.count() == 1) {
+                mode = PROPORTIONAL;
+            } else if (subOps2.count() >= 1 && subOps1.count() >= 1) {
+                mode = ADDSUBOPERATION;
+            }
+        }
+
+        if (mode == SKGOperationObject::ADDSUBOPERATION) {
+            // Add sub operation to align amount
             SKGSubOperationObject so1;
             IFOKDO(err, addSubOperation(so1))
-            IFOKDO(err, so1.setQuantity(iDeletedOne.getCurrentAmount() - getCurrentAmount()))
+            IFOKDO(err, so1.setQuantity(targettAmount - currentAmount))
             IFOKDO(err, so1.save())
+        } else {
+            // Keep ratio
+            foreach(const SKGObjectBase & sopbase, subOps1) {
+                SKGSubOperationObject sop(sopbase);
+                IFOKDO(err, sop.setQuantity(targettAmount * sop.getQuantity() / currentAmount))
+                IFOKDO(err, sop.save())
+            }
         }
+        IFOKDO(err, load())
         IFOK(err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), SKGDocument::Positive);
     }
 
