@@ -273,8 +273,7 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, con
                 IFOK(err) {
                     int nbdays = QDate::currentDate().daysTo(nextDate);
                     if (nbdays > 0) {
-                        QString objname = op.getDisplayName();
-                        err = getDocument()->sendMessage(i18np("Operation '%2' will be inserted in one day", "Operation '%2' will be inserted in %1 days", nbdays, objname));
+                        err = getDocument()->sendMessage(i18np("Operation '%2' will be inserted in one day", "Operation '%2' will be inserted in %1 days", nbdays, getDisplayName()));
                     }
                 }
             }
