@@ -66,15 +66,24 @@ class SKGBANKMODELER_EXPORT SKGReportBank : public SKGReport
     Q_PROPERTY(QVariantList scheduled_operations READ getScheduledOperations)
 
     /**
-     * The main categories of the month
+     * The main categories of the period
      */
-    Q_PROPERTY(QVariantList categories_month READ getMainCategoriesMonth)
+    Q_PROPERTY(QVariantList categories_period READ getMainCategoriesForPeriod)
 
     /**
-     * The main categories of the previous month
+     * The main categories of the previous period
      */
-    Q_PROPERTY(QVariantList categories_previous_month READ getMainCategoriesPreviousMonth)
+    Q_PROPERTY(QVariantList categories_previous_period READ getMainCategoriesForPreviousPeriod)
 
+    /**
+     * The main categories of the period (for compatibility)
+     */
+    Q_PROPERTY(QVariantList categories_month READ getMainCategoriesForPeriod)
+
+    /**
+     * The main categories of the previous period (for compatibility)
+     */
+    Q_PROPERTY(QVariantList categories_previous_month READ getMainCategoriesForPreviousPeriod)
     /**
      * The income versus expenditure
      */
@@ -133,16 +142,16 @@ public:
     virtual QVariantList getScheduledOperations();
 
     /**
-     * Get the main categories of the month
-     * @return the main categories of the month
+     * Get the main categories of the period
+     * @return the main categories of the period
      */
-    virtual QVariantList getMainCategoriesMonth();
+    virtual QVariantList getMainCategoriesForPeriod();
 
     /**
-     * Get the main categories of the previous month
-     * @return the main categories of the previous month
+     * Get the main categories of the previous period
+     * @return the main categories of the previous period
      */
-    virtual QVariantList getMainCategoriesPreviousMonth();
+    virtual QVariantList getMainCategoriesForPreviousPeriod();
 
     /**
      * Get the main categories variations
@@ -152,9 +161,15 @@ public:
 
     /**
      * Get the income versus expenditure
+     * @param iOnSubOperation the computation is done on sub operation
+     * @param iTransfert the computation includes transferts
+     * @param iTracker the computation includes tracked operations
+     * @param iWhereClause1 the period where clause (if empty then use the period of the report)
+     * @param iWhereClause2 the period where clause (if empty then use the previous period of the report)
+     * @param iTracker the computation includes tracked operations
      * @return the income versus expenditure
      */
-    virtual QVariantList getIncomeVsExpenditure();
+    virtual QVariantList getIncomeVsExpenditure(bool iOnSubOperation = false, bool iTransfert = true, bool iTracker = true, const QString& iWhereClause1 = "", const QString& iWhereClause2 = "");
 
     /**
      * Get advice
