@@ -78,7 +78,9 @@ SKGError SKGRuleObject::save(bool iInsertOrUpdate, bool iReloadAfterSave)
     SKGError err = SKGObjectBase::save(iInsertOrUpdate, iReloadAfterSave);
 
     // Raise alarm
-    if (!err && getActionType() == ALARM) err = execute();
+    if (!err && getActionType() == ALARM) {
+        err = execute();
+    }
 
     return err;
 }
@@ -145,7 +147,9 @@ SKGError SKGRuleObject::setOrder(double iOrder)
         order = 1;
         SKGStringListList result;
         err = getDocument()->executeSelectSqliteOrder("SELECT max(f_sortorder) from rule", result);
-        if (!err && result.count() == 2) order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+        if (!err && result.count() == 2) {
+            order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+        }
     }
     IFOKDO(err, setAttribute("f_sortorder", SKGServices::doubleToString(order)))
     return err;
@@ -156,24 +160,29 @@ QString SKGRuleObject::getSelectSqlOrder(const QString& iAdditionalCondition) co
     QString wc = iAdditionalCondition;
     QString wc2 = SKGRuleObject::getDescriptionFromXML(static_cast<SKGDocument*>(getDocument()), getXMLSearchDefinition(), true, SEARCH);
     if (!wc2.isEmpty()) {
-        if (wc.isEmpty()) wc = wc2;
-        else {
+        if (wc.isEmpty()) {
+            wc = wc2;
+        } else {
             wc = '(' % wc % ") AND (" % wc2 % ')';
         }
     }
-    if (wc.isEmpty()) wc = "1=1";
+    if (wc.isEmpty()) {
+        wc = "1=1";
+    }
     wc = "d_date!='0000-00-00' AND (" % wc % ')';
     return wc;
 }
 
 SKGRuleObject::SKGAlarmInfo SKGRuleObject::getAlarmInfo() const
 {
-    SKGTRACEIN(10, "SKGRuleObject::getAlarmInfo");
+    SKGTRACEINFUNC(10);
     SKGRuleObject::SKGAlarmInfo alarm;
     if (getActionType() == SKGRuleObject::ALARM) {
         // Alarm mode
         QString wc = getSelectSqlOrder();
-        if (wc.isEmpty()) wc = "1=1";
+        if (wc.isEmpty()) {
+            wc = "1=1";
+        }
 
         SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
 
@@ -198,19 +207,22 @@ SKGRuleObject::SKGAlarmInfo SKGRuleObject::getAlarmInfo() const
 SKGError SKGRuleObject::execute(ProcessMode iMode)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGRuleObject::execute", err);
+    SKGTRACEINFUNCRC(10, err);
     if (getActionType() == SKGRuleObject::UPDATE) {
         // Update mode
         QString addSql;
-        if (iMode == IMPORTED) addSql = "t_imported!='N'";
-        else if (iMode == IMPORTEDNOTVALIDATE) {
+        if (iMode == IMPORTED) {
+            addSql = "t_imported!='N'";
+        } else if (iMode == IMPORTEDNOTVALIDATE) {
             addSql = "t_imported='P'";
         } else if (iMode == IMPORTING) {
             addSql = "t_imported='T'";
         }
 
         QString wc = getSelectSqlOrder(addSql);
-        if (wc.isEmpty()) wc = "1=1";
+        if (wc.isEmpty()) {
+            wc = "1=1";
+        }
 
         SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
         if (doc) {
@@ -224,8 +236,12 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                     QString sql = list.at(i);
                     sql.replace("#WC#", wc);
                     err2 = doc->executeSqliteOrder(sql);
-                    if (!err2) err2 = doc->stepForward(i + 1);
-                    if (err2 && !err) err = err2;
+                    if (!err2) {
+                        err2 = doc->stepForward(i + 1);
+                    }
+                    if (err2 && !err) {
+                        err = err2;
+                    }
                 }
             }
 
@@ -234,7 +250,9 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 err = doc->executeSelectSqliteOrder("SELECT changes()", result);
                 if (!err && result.count() == 2) {
                     int nbChanges = SKGServices::stringToInt(result.at(1).at(0));
-                    if (nbChanges) doc->sendMessage(i18np("1 operation modified by %2", "%1 operations modified by %2", nbChanges, getAttribute("i_ORDER")));
+                    if (nbChanges) {
+                        doc->sendMessage(i18np("1 operation modified by %2", "%1 operations modified by %2", nbChanges, getAttribute("i_ORDER")));
+                    }
                 }
             }
 
@@ -243,7 +261,9 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
     } else if (getActionType() == SKGRuleObject::ALARM) {
         // Alarm mode
         QString wc = getSelectSqlOrder();
-        if (wc.isEmpty()) wc = "1=1";
+        if (wc.isEmpty()) {
+            wc = "1=1";
+        }
 
         SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
         if (doc) {
@@ -256,7 +276,9 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 err = doc->executeSelectSqliteOrder(sql, result);
                 if (!err && result.count() == 2) {
                     // Is alarm raised ?
-                    if (result.at(1).at(0) == "1") doc->sendMessage(result.at(1).at(3));
+                    if (result.at(1).at(0) == "1") {
+                        doc->sendMessage(result.at(1).at(3));
+                    }
                 }
             }
         }
@@ -273,108 +295,113 @@ double SKGRuleObject::getOrder() const
 QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QString& iParam1, const QString& iParam2, const QString& iAtt2)
 {
     QString output = iOperator;
-    if (output == "#ATT# LIKE '%#V1S#%'")
+    if (output == "#ATT# LIKE '%#V1S#%'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "contains '#V1S#'").replace("#V1S#", iParam1);
-    else if (output == "#ATT# LIKE '#V1S#%'")
+    } else if (output == "#ATT# NOT LIKE '%#V1S#%'") {
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "does not contain '#V1S#'").replace("#V1S#", iParam1);
+    } else if (output == "#ATT# LIKE '#V1S#%'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "starts with '#V1S#'").replace("#V1S#", iParam1);
-    else if (output == "#ATT# LIKE '%#V1S#'")
+    } else if (output == "#ATT# NOT LIKE '#V1S#%'") {
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "does not start with '#V1S#'").replace("#V1S#", iParam1);
+    } else if (output == "#ATT# LIKE '%#V1S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "ends with '#V1S#'").replace("#V1S#", iParam1);
-    else if (output == "#ATT#=''")
+    } else if (output == "#ATT# NOT LIKE '%#V1S#'") {
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "does not end with '#V1S#'").replace("#V1S#", iParam1);
+    } else if (output == "#ATT#=''") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is empty");
-    else if (output == "#ATT#!=''")
+    } else if (output == "#ATT#!=''") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not empty");
-    else if (output == "REGEXP('#V1S#', #ATT#)")
+    } else if (output == "REGEXP('#V1S#', #ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "regexp '#V1S#'").replace("#V1S#", iParam1);
-    else if (output == "WILDCARD('#V1S#', #ATT#)")
+    } else if (output == "NOT(REGEXP('#V1S#', #ATT#))") {
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "not regexp '#V1S#'").replace("#V1S#", iParam1);
+    } else if (output == "WILDCARD('#V1S#', #ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "wildcard '#V1S#'").replace("#V1S#", iParam1);
-
-    else if (output == "#ATT#=#V1#")
+    } else if (output == "NOT(WILDCARD('#V1S#', #ATT#))") {
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "not wildcard '#V1S#'").replace("#V1S#", iParam1);
+    } else if (output == "#ATT#=#V1#") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#V1#").replace("#V1#", iParam1);
-    else if (output == "#ATT#!=#V1#")
+    } else if (output == "#ATT#!=#V1#") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "!=#V1#").replace("#V1#", iParam1);
-    else if (output == "#ATT#>#V1#")
+    } else if (output == "#ATT#>#V1#") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">#V1#").replace("#V1#", iParam1);
-    else if (output == "#ATT#<#V1#")
+    } else if (output == "#ATT#<#V1#") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<#V1#").replace("#V1#", iParam1);
-    else if (output == "#ATT#>=#V1#")
+    } else if (output == "#ATT#>=#V1#") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">=#V1#").replace("#V1#", iParam1);
-    else if (output == "#ATT#<=#V1#")
+    } else if (output == "#ATT#<=#V1#") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<=#V1#").replace("#V1#", iParam1);
-
-    else if (output == "#ATT#='#V1S#'")
+    } else if (output == "#ATT#='#V1S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "='#V1S#'").replace("#V1S#", iParam1);
-    else if (output == "#ATT#!='#V1S#'")
+    } else if (output == "#ATT#!='#V1S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "!='#V1S#'").replace("#V1S#", iParam1);
-    else if (output == "#ATT#>'#V1S#'")
+    } else if (output == "#ATT#>'#V1S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">'#V1S#'").replace("#V1S#", iParam1);
-    else if (output == "#ATT#<'#V1S#'")
+    } else if (output == "#ATT#<'#V1S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<'#V1S#'").replace("#V1S#", iParam1);
-    else if (output == "#ATT#>='#V1S#'")
+    } else if (output == "#ATT#>='#V1S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">='#V1S#'").replace("#V1S#", iParam1);
-    else if (output == "#ATT#<='#V1S#'")
+    } else if (output == "#ATT#<='#V1S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<='#V1S#'").replace("#V1S#", iParam1);
-
-    else if (output == "#ATT#>=#V1# AND #ATT#<=#V2#")
+    } else if (output == "#ATT#>=#V1# AND #ATT#<=#V2#") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between #V1# and #V2#").replace("#V1#", iParam1).replace("#V2#", iParam2);
-    else if (output == "#ATT#>='#V1S#' AND #ATT#<='#V2S#'")
+    } else if (output == "#ATT#>='#V1S#' AND #ATT#<='#V2S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between '#V1S#' and '#V2S#'").replace("#V1S#", iParam1).replace("#V2S#", iParam2);
-    else if (output == "#ATT#=lower(#ATT#)")
+    } else if (output == "#ATT#=lower(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to lower");
-    else if (output == "#ATT#=upper(#ATT#)")
+    } else if (output == "#ATT#=upper(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to upper");
-    else if (output == "#ATT#=capitalize(#ATT#)")
+    } else if (output == "#ATT#=capitalize(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to capitalize");
-    else if (output == "#ATT#!=lower(#ATT#)")
+    } else if (output == "#ATT#!=lower(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not lower");
-    else if (output == "#ATT#!=upper(#ATT#)")
+    } else if (output == "#ATT#!=upper(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not upper");
-    else if (output == "#ATT#!=capitalize(#ATT#)")
+    } else if (output == "#ATT#!=capitalize(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not capitalize");
-    else if (output == "#ATT#= lower(#ATT#)")
+    } else if (output == "#ATT#= lower(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is lower");
-    else if (output == "#ATT#= upper(#ATT#)")
+    } else if (output == "#ATT#= upper(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is upper");
-    else if (output == "#ATT#= capitalize(#ATT#)")
+    } else if (output == "#ATT#= capitalize(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is capitalize");
-
-    else if (output == "#ATT#=replace(#ATT2#,'#V1S#','#V2S#')")
+    } else if (output == "#ATT#=replace(#ATT2#,'#V1S#','#V2S#')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2# with '#V1S#' replaced by '#V2S#'").replace("#V1S#", iParam1).replace("#V2S#", iParam2).replace("#ATT2#", iAtt2);
-    else if (output == "#ATT#=substr(#ATT2#,'#V1#','#V2#')")
+    } else if (output == "#ATT#=substr(#ATT2#,'#V1#','#V2#')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=substring of #ATT2# from #V1# to #V2#").replace("#V1#", iParam1).replace("#V2#", iParam2).replace("#ATT2#", iAtt2);
-    else if (output == "#ATT#=#ATT2#")
+    } else if (output == "#ATT#=#ATT2#") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2#").replace("#ATT2#", iAtt2);
-    else if (output == "#ATT#=WORD(#ATT2#,#V1S#)")
+    } else if (output == "#ATT#=WORD(#ATT2#,#V1S#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=word(#ATT2#,#V1S#)").replace("#ATT2#", iAtt2).replace("#V1S#", iParam1);
-
-    else if (output == "#ATT#=todate(#ATT2#,'#DF#')")
+    } else if (output == "#ATT#=todate(#ATT2#,'#DF#')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2# as date with format #DF#").replace("#ATT2#", iAtt2).replace("#DF#", iParam2);
-    else if (output == "#ATT#=todate(WORD(#ATT2#,#V1S#),'#DF#')")
+    } else if (output == "#ATT#=todate(WORD(#ATT2#,#V1S#),'#DF#')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=word(#ATT2#,#V1S#) as date with format #DF#").replace("#ATT2#", iAtt2).replace("#V1S#", iParam1).replace("#DF#", iParam2);
-
-    else if (output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))")
+    } else if (output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current month");
-    else if (output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','start of month','-1 month'))")
+    } else if (output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','start of month','-1 month'))") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous month");
-    else if (output == "STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))")
+    } else if (output == "STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current year");
-    else if (output == "STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now','start of month','-1 year'))")
+    } else if (output == "STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now','start of month','-1 year'))") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous year");
-    else if (output == "#ATT#>date('now','-30 day') AND #ATT#<=date('now')")
+    } else if (output == "#ATT#>date('now','-30 day') AND #ATT#<=date('now')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 30 days");
-    else if (output == "#ATT#>date('now','-3 month') AND #ATT#<=date('now')")
+    } else if (output == "#ATT#>date('now','-3 month') AND #ATT#<=date('now')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 months");
-    else if (output == "#ATT#>date('now','-6 month') AND #ATT#<=date('now')")
+    } else if (output == "#ATT#>date('now','-6 month') AND #ATT#<=date('now')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 6 months");
-    else if (output == "#ATT#>date('now','-12 month') AND #ATT#<=date('now')")
+    } else if (output == "#ATT#>date('now','-12 month') AND #ATT#<=date('now')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 12 months");
-    else if (output == "#ATT#>date('now','-2 year') AND #ATT#<=date('now')")
+    } else if (output == "#ATT#>date('now','-2 year') AND #ATT#<=date('now')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 2 years");
-    else if (output == "#ATT#>date('now','-3 year') AND #ATT#<=date('now')")
+    } else if (output == "#ATT#>date('now','-3 year') AND #ATT#<=date('now')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 years");
-    else if (output == "#ATT#>date('now','-5 year') AND #ATT#<=date('now')")
+    } else if (output == "#ATT#>date('now','-5 year') AND #ATT#<=date('now')") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 5 years");
-    else if (output == "ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'")
+    } else if (output == "ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "If total(#ATT#)#OP##V1# then send '#V2S#'").replace("#V1#", iParam1).replace("#V2S#", iParam2).replace("#OP#", iAtt2);
+    }
 
     return output;
 }
@@ -407,8 +434,11 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
         // Mode query
         if (iAttributeType == SKGServices::TEXT) {
             output.push_back("#ATT# LIKE '%#V1S#%'");
+            output.push_back("#ATT# NOT LIKE '%#V1S#%'");
             output.push_back("#ATT# LIKE '#V1S#%'");
+            output.push_back("#ATT# NOT LIKE '#V1S#%'");
             output.push_back("#ATT# LIKE '%#V1S#'");
+            output.push_back("#ATT# NOT LIKE '%#V1S#'");
             output.push_back("#ATT#=''");
             output.push_back("#ATT#!=''");
             output.push_back("#ATT#= lower(#ATT#)");
@@ -418,7 +448,9 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT#= capitalize(#ATT#)");
             output.push_back("#ATT#!=capitalize(#ATT#)");
             output.push_back("REGEXP('#V1S#', #ATT#)");
+            output.push_back("NOT(REGEXP('#V1S#', #ATT#))");
             output.push_back("WILDCARD('#V1S#', #ATT#)");
+            output.push_back("NOT(WILDCARD('#V1S#', #ATT#))");
         }
 
         if (iAttributeType == SKGServices::INTEGER || iAttributeType == SKGServices::FLOAT) {
@@ -516,7 +548,9 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                         elementDescription += part;
                     } else {
                         attribute = "operation." % attribute;
-                        if (iDocument) attribute = iDocument->getDisplay(attribute);
+                        if (iDocument) {
+                            attribute = iDocument->getDisplay(attribute);
+                        }
 
                         if (iType != ALARM) {
                             elementDescription = attribute;
@@ -524,7 +558,9 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                         }
 
                         QString tmp = element.attribute("att2s");
-                        if (tmp.isEmpty()) tmp = element.attribute("operator2");
+                        if (tmp.isEmpty()) {
+                            tmp = element.attribute("operator2");
+                        }
                         QString part = SKGRuleObject::getDisplayForOperator(element.attribute("operator"),
                                        element.attribute("value"),
                                        element.attribute("value2"),
@@ -566,9 +602,9 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                                     while (!stop) {
                                         int posSeparator = cat.indexOf(OBJECTSEPARATOR);
                                         if (posSeparator == -1) {
-                                            if (parentcat.isEmpty())
+                                            if (parentcat.isEmpty()) {
                                                 output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "', 0)");
-                                            else {
+                                            } else {
                                                 output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
                                             }
                                             stop = true;
@@ -576,14 +612,15 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                                             // Get first and second parts of the branch
                                             QString first = cat.mid(0, posSeparator);
                                             QString second = cat.mid(posSeparator + QString(OBJECTSEPARATOR).length(), cat.length() - posSeparator - QString(OBJECTSEPARATOR).length());
-                                            if (parentcat.isEmpty())
+                                            if (parentcat.isEmpty()) {
                                                 output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "', 0)");
-                                            else {
+                                            } else {
                                                 output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
                                             }
 
-                                            if (parentcat.isEmpty()) parentcat = first;
-                                            else {
+                                            if (parentcat.isEmpty()) {
+                                                parentcat = first;
+                                            } else {
                                                 parentcat = parentcat % OBJECTSEPARATOR % first;
                                             }
                                             cat = second;
@@ -613,7 +650,9 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
             }
 
             if (!(iType != SEARCH && iSQL) && !lineDescription.isEmpty()) {
-                if (iType == SEARCH && parenthesisNeeded) lineDescription = '(' % lineDescription % ')';
+                if (iType == SEARCH && parenthesisNeeded) {
+                    lineDescription = '(' % lineDescription % ')';
+                }
                 output.push_back(lineDescription);
             }
         }
@@ -635,7 +674,9 @@ QString SKGRuleObject::getDescriptionFromXML(SKGDocument* iDocument, const QStri
     int nb = list.count();
     for (int i = 0; i < nb; ++i) {
         output.append(list[i]);
-        if (i < nb - 1) output.append(iType != SEARCH ? " , " : (iSQL ? " OR " : i18nc("logical operator in a search query", " or ")));
+        if (i < nb - 1) {
+            output.append(iType != SEARCH ? " , " : (iSQL ? " OR " : i18nc("logical operator in a search query", " or ")));
+        }
     }
     return output;
 }
