@@ -1178,7 +1178,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                                     nbLoaded++;
                                 }
                             }
-                            if (nbLoaded == 0) {
+                            if (nbLoaded == 0 && !data.isEmpty()) {
                                 err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2' in line '%3'", getName(), SKGServices::stringToHtml(price), data), SKGDocument::Warning);    // TODO(Stephane MANKOWSKI) does not work with html
                             }
                         }
@@ -1230,7 +1230,7 @@ SKGError SKGUnitObject::getUrl(QUrl& oUrl) const
         }
     }
 
-    IFKO(err) {
+    IFOK(err) {
         oUrl = QUrl(url);
     }
 
