@@ -21,6 +21,8 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+#include <QUrl>
+
 #include "skgnamedobject.h"
 #include "skgerror.h"
 #include "skgservices.h"
@@ -92,6 +94,13 @@ public:
      */
     explicit SKGUnitObject(const SKGObjectBase& iObject);
 
+
+    /**
+     * Operator affectation
+     * @param iObject the object to copy
+     */
+    virtual const SKGUnitObject& operator= (const SKGObjectBase& iObject);
+
     /**
      * Get unit information
      * @return the unit information
@@ -141,12 +150,6 @@ public:
      */
     static double convert(double iValue, const SKGUnitObject& iUnitFrom, const SKGUnitObject& iUnitTo, const QDate& iDate = QDate::currentDate());
 
-    /**
-     * Operator affectation
-     * @param iObject the object to copy
-     */
-    virtual const SKGUnitObject& operator= (const SKGObjectBase& iObject);
-
     /**
      * Set the symbol of this unit
      * @param iSymbol the symbol
@@ -280,7 +283,15 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError openURL();
+    virtual SKGError openURL() const;
+
+    /**
+     * Get the URL where the values are downloaded
+     * @param oUrl the url
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getUrl(QUrl& oUrl) const;
 
     /**
      * Get the list of sources for the download
