@@ -57,7 +57,9 @@ SKGUnitValueObject::~SKGUnitValueObject()
 
 SKGError SKGUnitValueObject::setQuantity(double iValue)
 {
-    if (iValue < 0) return SKGError(ERR_INVALIDARG, i18nc("Error message", "Value of a currency cannot be a negative value"));
+    if (iValue < 0) {
+        return SKGError(ERR_INVALIDARG, i18nc("Error message", "Value of a currency cannot be a negative value"));
+    }
     return setAttribute("f_quantity", SKGServices::doubleToString(iValue));
 }
 
@@ -92,7 +94,9 @@ QString SKGUnitValueObject::getWhereclauseId() const
 SKGError SKGUnitValueObject::getUnit(SKGUnitObject& oUnit) const
 {
     SKGError err;
-    if (getDocument()) err = getDocument()->getObject("v_unit", "id=" % getAttribute("rd_unit_id"), oUnit);
+    if (getDocument()) {
+        err = getDocument()->getObject("v_unit", "id=" % getAttribute("rd_unit_id"), oUnit);
+    }
     return err;
 }
 #include "skgunitvalueobject.moc"
