@@ -56,10 +56,10 @@ private:
     QWidget* mOriginalParent;
 };
 
-KDatePickerPopup::KDatePickerPopup(Items items, const QDate& date, QWidget* iParent)
+KDatePickerPopup::KDatePickerPopup(Items iItems, const QDate& iDate, QWidget* iParent)
     : QMenu(iParent)
 {
-    mItems = items;
+    mItems = iItems;
 
     mDatePicker = new KDatePicker(this);
     mDatePicker->setCloseButton(false);
@@ -69,7 +69,7 @@ KDatePickerPopup::KDatePickerPopup(Items items, const QDate& date, QWidget* iPar
     connect(mDatePicker, SIGNAL(dateSelected(QDate)),
             SLOT(slotDateChanged(QDate)));
 
-    mDatePicker->setDate(date);
+    mDatePicker->setDate(iDate);
 
     buildMenu();
 }
@@ -90,6 +90,7 @@ void KDatePickerPopup::buildMenu()
     }
 
     if (mItems & Words) {
+        addAction(i18nc("@option yesterday", "&Yesterday"), this, SLOT(slotYesterday()));
         addAction(i18nc("@option today", "&Today"), this, SLOT(slotToday()));
         addAction(i18nc("@option tomorrow", "To&morrow"), this, SLOT(slotTomorrow()));
         addAction(i18nc("@option next week", "Next &Week"), this, SLOT(slotNextWeek()));
@@ -129,6 +130,11 @@ void KDatePickerPopup::slotDateChanged(const QDate& date)
     hide();
 }
 
+void KDatePickerPopup::slotYesterday()
+{
+    emit dateChanged(QDate::currentDate().addDays(-1));
+}
+
 void KDatePickerPopup::slotToday()
 {
     emit dateChanged(QDate::currentDate());
