@@ -33,7 +33,7 @@
 #include "skgtraces.h"
 
 SKGCalculatorEdit::SKGCalculatorEdit(QWidget* iParent)
-    : KLineEdit(iParent), m_lastValue(0), m_lastOperator(0), m_valid(true)
+    : KLineEdit(iParent), m_lastValue(0), m_lastOperator(0), m_currentMode(CALCULATOR), m_valid(true)
 {
     setMode(CALCULATOR);
     m_fontColor = palette().color(QPalette::Text);
