@@ -36,7 +36,9 @@ SKGCalculatorEditDesignerPlugin::SKGCalculatorEditDesignerPlugin(QObject* iParen
 void SKGCalculatorEditDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
 {
     Q_UNUSED(iCore);
-    if (m_initialized) return;
+    if (m_initialized) {
+        return;
+    }
 
     m_initialized = true;
 }
