@@ -37,7 +37,9 @@ SKGFilteredTableView::SKGFilteredTableView(QWidget* iParent)
     ui.kConfigure->setMenu(ui.kView->getHeaderMenu());
 
     connect(ui.kShow, SIGNAL(stateChanged()), this, SLOT(onFilterChanged()), Qt::QueuedConnection);
-    if (SKGMainPanel::getMainPanel()) connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
+    if (SKGMainPanel::getMainPanel()) {
+        connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
+    }
 }
 
 SKGFilteredTableView::~SKGFilteredTableView()
@@ -68,7 +70,9 @@ void SKGFilteredTableView::setState(const QString& iState)
     QString show2 = root.attribute("show");
     QString filter = root.attribute("filter");
 
-    if (!show2.isEmpty()) ui.kShow->setState(show2);
+    if (!show2.isEmpty()) {
+        ui.kShow->setState(show2);
+    }
     getSearchField()->setText(filter);
 
     if (m_objectModel) {
@@ -110,7 +114,9 @@ void SKGFilteredTableView::onFilterChanged()
 
 void SKGFilteredTableView::pageChanged()
 {
-    if (m_refreshNeeded) dataModified("", 0);
+    if (m_refreshNeeded) {
+        dataModified("", 0);
+    }
 }
 
 void SKGFilteredTableView::dataModified(const QString& iTableName, int iIdTransaction)
@@ -125,7 +131,9 @@ void SKGFilteredTableView::dataModified(const QString& iTableName, int iIdTransa
         }
         m_refreshNeeded = false;
 
-        if (getView()->isAutoResized()) getView()->resizeColumnsToContentsDelayed();
+        if (getView()->isAutoResized()) {
+            getView()->resizeColumnsToContentsDelayed();
+        }
 
         getView()->onSelectionChanged();
     }
