@@ -21,13 +21,12 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+#include <QWidget>
 
 #include "ui_skgfilteredtableview.h"
 #include "skgbasegui_export.h"
 #include "skgobjectmodelbase.h"
 
-#include <qwidget.h>
-
 class SKGShow;
 
 /**
@@ -107,4 +106,4 @@ private:
     bool m_refreshNeeded;
 };
 
-#endif // SKGFILTEREDTABLEVIEW_H
+#endif  // SKGFILTEREDTABLEVIEW_H
