@@ -108,7 +108,9 @@ SKGGraphicsView::~SKGGraphicsView()
 void SKGGraphicsView::setScene(QGraphicsScene* iScene)
 {
     graphicsView()->setScene(iScene);
-    if (iScene) iScene->installEventFilter(this);
+    if (iScene) {
+        iScene->installEventFilter(this);
+    }
     onZoom();
 }
 
@@ -119,7 +121,7 @@ QGraphicsView* SKGGraphicsView::graphicsView()
 
 QString SKGGraphicsView::getState() const
 {
-    SKGTRACEIN(10, "SKGGraphicsView::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -131,7 +133,7 @@ QString SKGGraphicsView::getState() const
 
 void SKGGraphicsView::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGGraphicsView::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -145,14 +147,18 @@ KMenu* SKGGraphicsView::getContextualMenu() const
 
 void SKGGraphicsView::showMenu(const QPoint& iPos)
 {
-    if (m_mainMenu) m_mainMenu->popup(graphicsView()->mapToGlobal(iPos));
+    if (m_mainMenu) {
+        m_mainMenu->popup(graphicsView()->mapToGlobal(iPos));
+    }
 }
 
 void SKGGraphicsView::setToolBarVisible(bool iVisibility)
 {
     m_toolBarVisible = iVisibility;
     ui.toolBar->setVisible(m_toolBarVisible);
-    if (m_actShowToolBar) m_actShowToolBar->setChecked(m_toolBarVisible);
+    if (m_actShowToolBar) {
+        m_actShowToolBar->setChecked(m_toolBarVisible);
+    }
 }
 
 bool SKGGraphicsView::isToolBarVisible() const
@@ -193,7 +199,9 @@ bool SKGGraphicsView::eventFilter(QObject* iObject, QEvent* iEvent)
         }
     } else if (iObject == graphicsView() &&  iEvent && iEvent->type() == QEvent::Resize) {
         Q_EMIT resized();
-        if (ui.kZoom->value() == ui.kZoom->resetValue()) m_timer.start(300);
+        if (ui.kZoom->value() == ui.kZoom->resetValue()) {
+            m_timer.start(300);
+        }
     }
     return QWidget::eventFilter(iObject, iEvent);
 }
@@ -205,7 +213,7 @@ void SKGGraphicsView::initializeZoom()
 
 void SKGGraphicsView::onZoom()
 {
-    _SKGTRACEIN(10, "SKGGraphicsView::onZoom");
+    _SKGTRACEINFUNC(10);
     int sliderValue = ui.kZoom->value();
     if (graphicsView()->scene()) {
         if (sliderValue == -10) {
@@ -221,7 +229,7 @@ void SKGGraphicsView::onZoom()
 
 void SKGGraphicsView::onPrint()
 {
-    _SKGTRACEIN(10, "SKGGraphicsView::onPrint");
+    _SKGTRACEINFUNC(10);
     QPrinter printer;
     QPointer<QPrintDialog> dialog = new QPrintDialog(&printer, this);
     if (dialog->exec() == QDialog::Accepted) {
@@ -234,9 +242,11 @@ void SKGGraphicsView::onPrint()
 
 void SKGGraphicsView::onExport()
 {
-    _SKGTRACEIN(10, "SKGGraphicsView::onExport");
+    _SKGTRACEINFUNC(10);
     QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "application/pdf image/svg+xml image/png image/jpeg image/gif image/tiff", this);
-    if (fileName.isEmpty()) return;
+    if (fileName.isEmpty()) {
+        return;
+    }
 
     exportInFile(fileName);
 
@@ -245,7 +255,7 @@ void SKGGraphicsView::onExport()
 
 void SKGGraphicsView::exportInFile(const QString& iFileName)
 {
-    _SKGTRACEIN(10, "SKGGraphicsView::exportInFile");
+    _SKGTRACEINFUNC(10);
     QString extension = QFileInfo(iFileName).suffix().toUpper();
     if (extension == "PDF") {
         QPrinter printer;
@@ -275,7 +285,7 @@ void SKGGraphicsView::exportInFile(const QString& iFileName)
 
 void SKGGraphicsView::onCopy()
 {
-    _SKGTRACEIN(10, "SKGGraphicsView::onCopy");
+    _SKGTRACEINFUNC(10);
     QClipboard* clipboard = QApplication::clipboard();
     if (clipboard) {
         QImage image(graphicsView()->size(), QImage::Format_ARGB32);
