@@ -31,7 +31,7 @@
 SKGHtmlBoardWidget::SKGHtmlBoardWidget(SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, const QStringList& iTablesRefreshing, bool iEnablePreviousMenu)
     : SKGBoardWidget(iDocument, iTitle), m_HtmlTemplate(iTemplate), m_TablesRefreshing(iTablesRefreshing), m_refreshNeeded(false), m_previousMonth(NULL)
 {
-    SKGTRACEIN(10, "SKGHtmlBoardWidget::SKGHtmlBoardWidget");
+    SKGTRACEINFUNC(10);
 
     m_Text = new QLabel();
     m_Text->setObjectName(QString::fromUtf8("m_Text"));
@@ -58,13 +58,13 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(SKGDocument* iDocument, const QString& iT
 
 SKGHtmlBoardWidget::~SKGHtmlBoardWidget()
 {
-    SKGTRACEIN(10, "SKGHtmlBoardWidget::~SKGHtmlBoardWidget");
+    SKGTRACEINFUNC(10);
     m_previousMonth = NULL;
 }
 
 QString SKGHtmlBoardWidget::getState()
 {
-    SKGTRACEIN(10, "SKGHtmlBoardWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -77,25 +77,29 @@ QString SKGHtmlBoardWidget::getState()
 
 void SKGHtmlBoardWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGHtmlBoardWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     // Set state
-    if (m_previousMonth) m_previousMonth->setChecked(root.attribute("previousMonth") != "N");
+    if (m_previousMonth) {
+        m_previousMonth->setChecked(root.attribute("previousMonth") != "N");
+    }
 
     dataModified("", 0);
 }
 
 void SKGHtmlBoardWidget::pageChanged()
 {
-    if (m_refreshNeeded) dataModified();
+    if (m_refreshNeeded) {
+        dataModified();
+    }
 }
 
 void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEIN(10, "SKGHtmlBoardWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
 
     if (m_TablesRefreshing.isEmpty() || m_TablesRefreshing.contains(iTableName) || iTableName.isEmpty()) {
@@ -115,7 +119,9 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
             QDate month = QDate::currentDate();
             month = month.addDays(-month.day() + 1);
             if (m_previousMonth) {
-                if (m_previousMonth->isChecked()) month = month.addMonths(-1);
+                if (m_previousMonth->isChecked()) {
+                    month = month.addMonths(-1);
+                }
             } else {
                 // No mode "month" ==> we force to the infinite
                 month = QDate(2999, 12, 31);
@@ -126,7 +132,7 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
             setMainTitle(getOriginalTitle() % (m_previousMonth ? " - " + monthS : ""));
 
             // Set month
-            report->setMonth(monthS);
+            report->setPeriod(monthS);
 
             QString html;
             SKGError err = SKGReport::getReportFromTemplate(report, m_HtmlTemplate, html);
@@ -144,6 +150,8 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
     // TODO(Stephane MANKOWSKI): No widget if no account (must not be hardcoded)
     bool exist = false;
     getDocument()->existObjects("account", "", exist);
-    if (parentWidget()) setVisible(exist);
+    if (parentWidget()) {
+        setVisible(exist);
+    }
 }
 #include "skghtmlboardwidget.h"
