@@ -43,7 +43,9 @@ void SKGInterfacePlugin::refresh() {}
 void SKGInterfacePlugin::registerGlobalAction(const QString& iIdentifier, QAction* iAction)
 {
     actionCollection()->addAction(iIdentifier, iAction);
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction(iIdentifier, iAction, false);
+    if (SKGMainPanel::getMainPanel()) {
+        SKGMainPanel::getMainPanel()->registerGlobalAction(iIdentifier, iAction, false);
+    }
 }
 
 QDockWidget* SKGInterfacePlugin::getDockWidget()
