@@ -44,9 +44,9 @@ void SKGLineEdit::setSubstringCompletionMode(bool iMode)
 
 void SKGLineEdit::makeCompletion(const QString& iText)
 {
-    if (m_substringCompletionMode && completionMode() == KGlobalSettings::CompletionPopup)
+    if (m_substringCompletionMode && completionMode() == KGlobalSettings::CompletionPopup) {
         setCompletedItems(completionObject()->substringCompletion(iText));
-    else {
+    } else {
         KLineEdit::makeCompletion(iText);
     }
 }
