@@ -22,7 +22,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include <klineedit.h>
+#include <KLineEdit>
 #include "skgbasegui_export.h"
 /**
  * This file is a line edit with more features.
@@ -72,4 +72,4 @@ private:
     bool m_substringCompletionMode;
 };
 
-#endif // SKGLINEEDIT_H
+#endif  // SKGLINEEDIT_H
