@@ -36,7 +36,9 @@ SKGLineEditDesignerPlugin::SKGLineEditDesignerPlugin(QObject* iParent)
 void SKGLineEditDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
 {
     Q_UNUSED(iCore);
-    if (m_initialized) return;
+    if (m_initialized) {
+        return;
+    }
 
     m_initialized = true;
 }
