@@ -914,7 +914,7 @@ void SKGMainPanel::setupActions()
     overlay.push_back("bookmarks");
     d->m_overwriteBookmarkStateAction = new KAction(KIcon("document-save", NULL, overlay), i18nc("Noun, user action", "Overwrite bookmark state"), this);
     connect(d->m_overwriteBookmarkStateAction, SIGNAL(triggered()), this, SLOT(overwriteBookmarkState()));
-    d->m_overwriteBookmarkStateAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_S);
+    d->m_overwriteBookmarkStateAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_B);
     registerGlobalAction("tab_overwritebookmark", d->m_overwriteBookmarkStateAction);
 
     //
@@ -1755,6 +1755,7 @@ SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const
                 w->setNextPages(empty);
             }
             SKGTRACEL(1) << "opening plugin [" << plugin->objectName() << ']' << endl;
+            Q_EMIT pageOpened();
         }
     } else {
         getDocument()->sendMessage(i18nc("An information message",  "Impossible to open the page because the plugin was not found"), SKGDocument::Error);
@@ -2146,7 +2147,7 @@ void SKGMainPanel::notify(int iTransaction)
                 }
             }
 
-            if (nbMessages < 21) {
+            if (nbMessages < 21 || !SKGServices::getEnvVariable("SKGTEST").isEmpty()) {
                 // Display a simple notification
                 /*KNotification* notify = new KNotification(KGlobal::mainComponent().aboutData()->appName() % "_info_event" , this);
                 notify->setText(message);
