@@ -48,24 +48,26 @@ SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
       m_whereClause(iWhereClause),
       m_parentAttribute(iParentAttribute), m_refreshBlocked(false)
 {
-    SKGTRACEIN(1, "SKGObjectModelBase::SKGObjectModelBase");
+    SKGTRACEINFUNC(1);
 
     setTable(iTable);
 
     connect(m_document, SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)));
-    if (SKGMainPanel::getMainPanel()) connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
+    if (SKGMainPanel::getMainPanel()) {
+        connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
+    }
 }
 
 SKGObjectModelBase::~SKGObjectModelBase()
 {
-    SKGTRACEIN(1, "SKGObjectModelBase::~SKGObjectModelBase");
+    SKGTRACEINFUNC(1);
     clear();
     m_document = NULL;
 }
 
 void SKGObjectModelBase::clear()
 {
-    SKGTRACEIN(1, "SKGObjectModelBase::clear");
+    SKGTRACEINFUNC(1);
     QHashIterator<int, SKGObjectBase*> i(m_objectsHashTable);
     while (i.hasNext()) {
         i.next();
@@ -83,7 +85,9 @@ void SKGObjectModelBase::clear()
 
 int SKGObjectModelBase::getID(const SKGObjectBase* obj, int row) const
 {
-    if (!m_parentAttribute.isEmpty()) return (obj ? obj->getID() : 0);
+    if (!m_parentAttribute.isEmpty()) {
+        return (obj ? obj->getID() : 0);
+    }
     return (obj ? 100 * (obj->getID()) + row : 0);
 }
 
@@ -94,17 +98,21 @@ QList<SKGDocument::SKGModelTemplate> SKGObjectModelBase::getSchemas() const
 
 void SKGObjectModelBase::setSupportedAttributes(const QStringList& iListAttribute)
 {
-    SKGTRACEIN(1, "SKGObjectModelBase::setSupportedAttributes");
+    SKGTRACEINFUNC(1);
     m_listSupported.clear();
     m_listVisibility.clear();
     m_listSize.clear();
 
     QStringList l = iListAttribute;
-    if (m_listSchema.count())  l += SKGServices::splitCSVLine(m_listSchema.at(0).schema);
+    if (m_listSchema.count()) {
+        l += SKGServices::splitCSVLine(m_listSchema.at(0).schema);
+    }
 
     QStringList attributesAvailables;
     QStringList attributesAvailablesTmp;
-    if (m_listSchema.count())  attributesAvailablesTmp = SKGServices::splitCSVLine(m_listSchema.at(0).schema);
+    if (m_listSchema.count()) {
+        attributesAvailablesTmp = SKGServices::splitCSVLine(m_listSchema.at(0).schema);
+    }
     int nb = attributesAvailablesTmp.count();
     for (int i = 0; i < nb; ++i) {
         attributesAvailables.push_back(attributesAvailablesTmp.at(i).split('|').at(0));
@@ -119,10 +127,13 @@ void SKGObjectModelBase::setSupportedAttributes(const QStringList& iListAttribut
         if (nbValues > 0 && !m_listSupported.contains(att) && attributesAvailables.contains(att)) {
             m_listSupported.push_back(att);
             bool visible = true;
-            if (nbValues > 1) visible = (i == 0 || values.at(1) == "Y");  // First column is always visible to support grouping
+            if (nbValues > 1) {
+                visible = (i == 0 || values.at(1) == "Y");    // First column is always visible to support grouping
+            }
             m_listVisibility.push_back(visible);
-            if (nbValues > 2) m_listSize.push_back(SKGServices::stringToInt(values.at(2)));
-            else {
+            if (nbValues > 2) {
+                m_listSize.push_back(SKGServices::stringToInt(values.at(2)));
+            } else {
                 m_listSize.push_back(-1);
             }
         }
@@ -133,7 +144,9 @@ void SKGObjectModelBase::setSupportedAttributes(const QStringList& iListAttribut
 
 bool SKGObjectModelBase::setFilter(const QString& iWhereClause)
 {
-    if (iWhereClause != m_whereClause) m_isResetRealyNeeded = true;
+    if (iWhereClause != m_whereClause) {
+        m_isResetRealyNeeded = true;
+    }
     m_whereClause = iWhereClause;
     return m_isResetRealyNeeded;
 }
@@ -141,10 +154,14 @@ bool SKGObjectModelBase::setFilter(const QString& iWhereClause)
 void SKGObjectModelBase::setTable(const QString& iTable)
 {
     if (iTable != m_table) {
-        if (!m_table.isEmpty()) m_isResetRealyNeeded = true;
+        if (!m_table.isEmpty()) {
+            m_isResetRealyNeeded = true;
+        }
         m_table = iTable;
         m_realTable = SKGServices::getRealTable(m_table);
-        if (m_document) m_listSchema = m_document->getDisplaySchemas(m_realTable);
+        if (m_document) {
+            m_listSchema = m_document->getDisplaySchemas(m_realTable);
+        }
     }
 }
 
@@ -188,7 +205,7 @@ SKGDocument* SKGObjectModelBase::getDocument() const
 
 void SKGObjectModelBase::buidCache()
 {
-    SKGTRACEIN(1, "SKGObjectModelBase::buidCache");
+    SKGTRACEINFUNC(1);
     m_doctransactionTable = (getRealTable() == "doctransaction");
     m_nodeTable = (getRealTable() == "node");
 
@@ -211,13 +228,15 @@ bool SKGObjectModelBase::isRefreshBlocked()
 
 void SKGObjectModelBase::refresh()
 {
-    if (!m_isResetRealyNeeded || isRefreshBlocked()) return;
-    SKGTRACEIN(1, "SKGObjectModelBase::refresh");
+    if (!m_isResetRealyNeeded || isRefreshBlocked()) {
+        return;
+    }
+    SKGTRACEINFUNC(1);
     SKGTRACEL(1) << "Table:" << getTable() << endl;
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     Q_EMIT beforeReset();
     {
-        _SKGTRACEIN(10, "QAbstractItemModel::refresh-remove");
+        _SKGTRACEINFUNC(10);
         clear();
         m_listAttibutes.clear();
         m_listAttributeTypes.clear();
@@ -226,7 +245,7 @@ void SKGObjectModelBase::refresh()
     }
 
     {
-        _SKGTRACEIN(10, "QAbstractItemModel::refresh-fill");
+        _SKGTRACEINFUNC(10);
         QStringList listAttibutesTmp;
         if (m_document && m_document->getAttributesList(m_table, listAttibutesTmp).isSucceeded()) {
             m_isResetRealyNeeded = false;
@@ -241,8 +260,9 @@ void SKGObjectModelBase::refresh()
                     QString att = m_listSupported.at(i);
                     if (listAttibutesTmp.contains(att) || att.startsWith(QLatin1String("p_"))) {
                         m_listAttibutes.push_back(att);
-                        if (att.startsWith(QLatin1String("t_")) || att.startsWith(QLatin1String("p_"))) m_listAttributeTypes.push_back(SKGServices::TEXT);
-                        else if (att.startsWith(QLatin1String("f_"))) {
+                        if (att.startsWith(QLatin1String("t_")) || att.startsWith(QLatin1String("p_"))) {
+                            m_listAttributeTypes.push_back(SKGServices::TEXT);
+                        } else if (att.startsWith(QLatin1String("f_"))) {
                             m_listAttributeTypes.push_back(SKGServices::FLOAT);
                         } else if (att.startsWith(QLatin1String("i_"))) {
                             m_listAttributeTypes.push_back(SKGServices::INTEGER);
@@ -268,7 +288,9 @@ void SKGObjectModelBase::refresh()
                         if (p != -1) {
                             m_listAttibutes.removeAt(p);
                             m_listAttributeTypes.removeAt(p);
-                            if (p < i) --i;
+                            if (p < i) {
+                                --i;
+                            }
                         }
                     }
                 }
@@ -277,14 +299,18 @@ void SKGObjectModelBase::refresh()
             // Get objects
             QString wc = m_whereClause;
             if (!m_groupby.isEmpty()) {
-                if (wc.isEmpty()) wc = "1=1";
-                if (m_groupby.startsWith(QLatin1String("p_")))
+                if (wc.isEmpty()) {
+                    wc = "1=1";
+                }
+                if (m_groupby.startsWith(QLatin1String("p_"))) {
                     wc += " ORDER BY (SELECT t_value FROM parameters WHERE t_uuid_parent=" % getTable() % ".id||'-" % getRealTable() % "' AND t_name='" % m_groupby % "')";
-                else {
+                } else {
                     wc += " ORDER BY " % m_groupby;
                 }
             }
-            if (m_document) m_document->getObjects(m_table, wc , m_listObjects);
+            if (m_document) {
+                m_document->getObjects(m_table, wc , m_listObjects);
+            }
 
             // Initialize object to treat
             QString currentGroup;
@@ -302,18 +328,22 @@ void SKGObjectModelBase::refresh()
                     // Grouping by tree
                     if (!m_parentAttribute.isEmpty()) {
                         int idp = SKGServices::stringToInt(c->getAttribute(m_parentAttribute));
-                        if (idp > 0) idparent = idp;
+                        if (idp > 0) {
+                            idparent = idp;
+                        }
                     }
                 } else {
                     // Grouping on specified attribute
                     QString att = getAttributeForGrouping(*c, m_groupby);
                     if (groupByDate) {
                         QDate date = SKGServices::stringToTime(att).date();
-                        if (date == QDate::currentDate()) att = i18nc("A group name for grouping by date attibute", "Today");
-                        else if (date > QDate::currentDate()) {
+                        if (date == QDate::currentDate()) {
+                            att = i18nc("A group name for grouping by date attibute", "Today");
+                        } else if (date > QDate::currentDate()) {
                             // In future
-                            if (date < QDate::currentDate().addDays(7)) att = i18nc("A group name for grouping by date attibute", "Next 7 days");
-                            else if (date < QDate::currentDate().addDays(15)) {
+                            if (date < QDate::currentDate().addDays(7)) {
+                                att = i18nc("A group name for grouping by date attibute", "Next 7 days");
+                            } else if (date < QDate::currentDate().addDays(15)) {
                                 att = i18nc("A group name for grouping by date attibute", "Next 15 days");
                             } else if (date < QDate::currentDate().addMonths(1)) {
                                 att = i18nc("A group name for grouping by date attibute", "Next month");
@@ -330,8 +360,9 @@ void SKGObjectModelBase::refresh()
                             }
                         } else {
                             // In the past
-                            if (date > QDate::currentDate().addDays(-7)) att = i18nc("A group name for grouping by date attibute", "Last 7 days");
-                            else if (date > QDate::currentDate().addDays(-15)) {
+                            if (date > QDate::currentDate().addDays(-7)) {
+                                att = i18nc("A group name for grouping by date attibute", "Last 7 days");
+                            } else if (date > QDate::currentDate().addDays(-15)) {
                                 att = i18nc("A group name for grouping by date attibute", "Last 15 days");
                             } else if (date > QDate::currentDate().addMonths(-1)) {
                                 att = i18nc("A group name for grouping by date attibute", "Last month");
@@ -350,8 +381,9 @@ void SKGObjectModelBase::refresh()
                     } else if (groupByNum) {
                         if (att != QChar(8734)) {
                             double d = SKGServices::stringToDouble(att);
-                            if (d > 10000.0) att = i18nc("A group name for grouping by numerical attibute", "> 10000");
-                            else if (d > 1000.0) {
+                            if (d > 10000.0) {
+                                att = i18nc("A group name for grouping by numerical attibute", "> 10000");
+                            } else if (d > 1000.0) {
                                 att = i18nc("A group name for grouping by numerical attibute", "> 1000");
                             } else if (d > 100.0) {
                                 att = i18nc("A group name for grouping by numerical attibute", "> 100");
@@ -409,7 +441,7 @@ void SKGObjectModelBase::refresh()
         buidCache();
 
         {
-            SKGTRACEIN(1, "SKGObjectModelBase::refresh-reset");
+            SKGTRACEINFUNC(1);
             QAbstractItemModel::reset();
         }
     }
@@ -419,20 +451,28 @@ void SKGObjectModelBase::refresh()
 
 bool SKGObjectModelBase::hasChildren(const QModelIndex& iParent) const
 {
-    if (iParent.column() > 0) return false;
-    _SKGTRACEIN(10, "SKGObjectModelBase::hasChildren");
+    if (iParent.column() > 0) {
+        return false;
+    }
+    _SKGTRACEINFUNC(10);
 
-    if (iParent.isValid() && m_parentAttribute.isEmpty() && m_groupby.isEmpty()) return false;
+    if (iParent.isValid() && m_parentAttribute.isEmpty() && m_groupby.isEmpty()) {
+        return false;
+    }
     return QAbstractItemModel::hasChildren(iParent);
 }
 
 int SKGObjectModelBase::rowCount(const QModelIndex& iParent) const
 {
-    if (iParent.column() > 0) return 0;
-    _SKGTRACEIN(10, "SKGObjectModelBase::rowCount");
+    if (iParent.column() > 0) {
+        return 0;
+    }
+    _SKGTRACEINFUNC(10);
 
     int idParent = 0;
-    if (iParent.isValid()) idParent = iParent.internalId();
+    if (iParent.isValid()) {
+        idParent = iParent.internalId();
+    }
 
     return m_parentChildRelations.value(idParent).count();
 }
@@ -445,11 +485,15 @@ int SKGObjectModelBase::columnCount(const QModelIndex& iParent) const
 
 QModelIndex SKGObjectModelBase::index(int row, int column, const QModelIndex& iParent) const
 {
-    if (!hasIndex(row, column, iParent)) return QModelIndex();
-    _SKGTRACEIN(10, "SKGObjectModelBase::index");
+    if (!hasIndex(row, column, iParent)) {
+        return QModelIndex();
+    }
+    _SKGTRACEINFUNC(10);
 
     int idParent = 0;
-    if (iParent.isValid())  idParent = iParent.internalId();
+    if (iParent.isValid()) {
+        idParent = iParent.internalId();
+    }
 
     int idChild = m_parentChildRelations.value(idParent).at(row);
 
@@ -459,11 +503,15 @@ QModelIndex SKGObjectModelBase::index(int row, int column, const QModelIndex& iP
 
 QModelIndex SKGObjectModelBase::parent(const QModelIndex& iIndex) const
 {
-    if (!iIndex.isValid()) return QModelIndex();
-    _SKGTRACEIN(10, "SKGObjectModelBase::parent");
+    if (!iIndex.isValid()) {
+        return QModelIndex();
+    }
+    _SKGTRACEINFUNC(10);
 
     int idChild = 0;
-    if (iIndex.isValid()) idChild = iIndex.internalId();
+    if (iIndex.isValid()) {
+        idChild = iIndex.internalId();
+    }
 
     int idParent = m_childParentRelations.value(idChild);
     int row = m_objectsHashTableRows.value(idParent);
@@ -492,21 +540,23 @@ SKGServices::AttributeType SKGObjectModelBase::getAttributeType(int iIndex) cons
 
 QVariant SKGObjectModelBase::headerData(int section, Qt::Orientation orientation, int role) const
 {
-    _SKGTRACEIN(10, "SKGObjectModelBase::headerData");
+    _SKGTRACEINFUNC(10);
 
     if (orientation == Qt::Horizontal) {
         if (role == Qt::DisplayRole) {
             QString att;
-            if (section >= 0 && section < m_listAttibutes.count()) att = m_listAttibutes.at(section);
-            else {
+            if (section >= 0 && section < m_listAttibutes.count()) {
+                att = m_listAttibutes.at(section);
+            } else {
                 att = SKGServices::intToString(section);
             }
 
             return getDocument()->getDisplay(getTable() % '.' % att);
         } else if (role == Qt::UserRole) {
             QString att;
-            if (section >= 0 && section < m_listAttibutes.count()) att = m_listAttibutes.at(section);
-            else {
+            if (section >= 0 && section < m_listAttibutes.count()) {
+                att = m_listAttibutes.at(section);
+            } else {
                 att = SKGServices::intToString(section);
             }
 
@@ -518,13 +568,16 @@ QVariant SKGObjectModelBase::headerData(int section, Qt::Orientation orientation
             if (indexAtt >= 0 && indexAtt < m_listVisibility.count()) {
                 bool visible = m_listVisibility.at(indexAtt);
                 att += QString("|") % (visible ? "Y" : "N");
-                if (indexAtt >= 0 && indexAtt < m_listSize.count()) att += '|' % SKGServices::intToString(m_listSize.at(indexAtt));
+                if (indexAtt >= 0 && indexAtt < m_listSize.count()) {
+                    att += '|' % SKGServices::intToString(m_listSize.at(indexAtt));
+                }
             }
             return att;
         } else if (role == Qt::DecorationRole) {
             QString att;
-            if (section >= 0 && section < m_listAttibutes.count()) att = m_listAttibutes.at(section);
-            else {
+            if (section >= 0 && section < m_listAttibutes.count()) {
+                att = m_listAttibutes.at(section);
+            } else {
                 att = SKGServices::intToString(section);
             }
 
@@ -538,21 +591,25 @@ SKGObjectBase SKGObjectModelBase::getObject(const QModelIndex& iIndex) const
 {
     SKGObjectBase* obj = getObjectPointer(iIndex);
     SKGObjectBase output;
-    if (obj != NULL) output = *obj;
+    if (obj != NULL) {
+        output = *obj;
+    }
     return output;
 }
 
 SKGObjectBase* SKGObjectModelBase::getObjectPointer(const QModelIndex& iIndex) const
 {
-    _SKGTRACEIN(10, "SKGObjectModelBase::getObject");
+    _SKGTRACEINFUNC(10);
     // SKGTRACE << "getObject:" << index.internalId() << endl;
     return m_objectsHashTable.value(iIndex.internalId());
 }
 
 QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
 {
-    if (!iIndex.isValid()) return QVariant();
-    _SKGTRACEIN(10, "SKGObjectModelBase::data");
+    if (!iIndex.isValid()) {
+        return QVariant();
+    }
+    _SKGTRACEINFUNC(10);
 
     switch (iRole) {
     case Qt::BackgroundRole: {
@@ -607,11 +664,13 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
                     return dval;
                 }
             }
-            default:
-            {}
+            default: {
+            }
             }
 
-            if (m_doctransactionTable && att == "t_savestep") return "";
+            if (m_doctransactionTable && att == "t_savestep") {
+                return "";
+            }
 
             // return val+"("+SKGServices::intToString(rowCount(index))+")";
             return val;
@@ -639,7 +698,9 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
             QVariant value_displayed = SKGObjectModelBase::data(iIndex, Qt::UserRole);
             bool ok = false;
             double value_double = value_displayed.toDouble(&ok);
-            if (ok && value_double < 0) return m_fontNegativeColor;
+            if (ok && value_double < 0) {
+                return m_fontNegativeColor;
+            }
         }
         break;
     }
@@ -654,7 +715,9 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
         QString att = m_listAttibutes.at(iIndex.column());
         if (obj->getTable().isEmpty()) {
             // This is a group
-            if (iIndex.column() == 0) return qVariantFromValue(static_cast<QIcon>(KIcon("arrow-right")));;
+            if (iIndex.column() == 0) {
+                return qVariantFromValue(static_cast<QIcon>(KIcon("arrow-right")));
+            };
             return "";
         } else {
             if (iIndex.column() == 0 && m_nodeTable) {
@@ -663,7 +726,9 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
             } else if (iIndex.column() == 0 && m_doctransactionTable) {
                 return qVariantFromValue(static_cast<QIcon>(KIcon(obj->getAttribute("t_mode") == "U" ? "edit-undo" : "edit-redo")));
             } else if (m_doctransactionTable && att == "t_savestep") {
-                if (obj->getAttribute("t_savestep") == "Y") return qVariantFromValue(static_cast<QIcon>(KIcon("document-save")));
+                if (obj->getAttribute("t_savestep") == "Y") {
+                    return qVariantFromValue(static_cast<QIcon>(KIcon("document-save")));
+                }
             }
         }
         break;
@@ -681,7 +746,9 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
                 int nbMessages = msg.count();
                 if (nbMessages) {
                     for (int i = 0; i < nbMessages; ++i) {
-                        if (i != 0) toolTipString += '\n';
+                        if (i != 0) {
+                            toolTipString += '\n';
+                        }
                         toolTipString += msg.at(i);
                     }
                 }
@@ -694,14 +761,20 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
                 QString shortDate = KGlobal::locale()->formatDate(dval, KLocale::ShortDate);
 
 
-                if (shortDate != fancyDate) toolTipString = shortDate;
+                if (shortDate != fancyDate) {
+                    toolTipString = shortDate;
+                }
             }
 
             // Add properties
             QStringList props = obj->getProperties();
-            if (props.count() > 0 && !toolTipString.isEmpty()) toolTipString += '\n';
+            if (props.count() > 0 && !toolTipString.isEmpty()) {
+                toolTipString += '\n';
+            }
             foreach(const QString & prop, props) {
-                if (!toolTipString.isEmpty()) toolTipString += '\n';
+                if (!toolTipString.isEmpty()) {
+                    toolTipString += '\n';
+                }
                 toolTipString += i18nc("To display a property and its value", "%1=%2", prop, obj->getProperty(prop));
             }
 
@@ -714,12 +787,14 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
     }
     case 99: {
         SKGObjectBase* obj = getObjectPointer(iIndex);
-        if (obj) return SKGServices::stringToDouble(obj->getAttribute("f_sortorder"));
+        if (obj) {
+            return SKGServices::stringToDouble(obj->getAttribute("f_sortorder"));
+        }
 
         break;
     }
-    default :
-    {}
+    default : {
+    }
     }
 
     return QVariant();
@@ -727,19 +802,27 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
 
 Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex& iIndex) const
 {
-    _SKGTRACEIN(10, "SKGObjectModelBase::flags");
+    _SKGTRACEINFUNC(10);
 
     Qt::ItemFlags f = QAbstractItemModel::flags(iIndex) | Qt::ItemIsDropEnabled;
 
-    if (iIndex.isValid()) f |= Qt::ItemIsUserCheckable;
+    if (iIndex.isValid()) {
+        f |= Qt::ItemIsUserCheckable;
+    }
 
-    if (m_nodeTable && iIndex.isValid()) f |= Qt::ItemIsEditable | Qt::ItemIsDragEnabled;
+    if (m_nodeTable && iIndex.isValid()) {
+        f |= Qt::ItemIsEditable | Qt::ItemIsDragEnabled;
+    }
 
     if (iIndex.isValid()) {
         QString att = m_listAttibutes.at(iIndex.column());
-        if (att.toLower() == att || !getDocument()->getRealAttribute(att).isEmpty()) f |= Qt::ItemIsEditable;
+        if (att.toLower() == att || !getDocument()->getRealAttribute(att).isEmpty()) {
+            f |= Qt::ItemIsEditable;
+        }
         SKGObjectBase* obj = getObjectPointer(iIndex);
-        if (obj->getTable().isEmpty()) f = Qt::ItemIsEnabled;
+        if (obj->getTable().isEmpty()) {
+            f = Qt::ItemIsEnabled;
+        }
     }
 
     return f;
@@ -747,7 +830,9 @@ Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex& iIndex) const
 
 bool SKGObjectModelBase::setData(const QModelIndex& iIndex, const QVariant& iValue, int iRole)
 {
-    if (!iIndex.isValid()) return false;
+    if (!iIndex.isValid()) {
+        return false;
+    }
 
     if (iRole == Qt::EditRole) {
         SKGError err;
@@ -819,9 +904,15 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
                                       const QModelIndex& iParent)
 {
     Q_UNUSED(iRow);
-    if (iAction == Qt::IgnoreAction) return true;
-    if (!iData || !(iData->hasFormat("application/skg.node.ids") || iData->hasUrls())) return false;  // TODO(Stephane MANKOWSKI): accept all
-    if (iColumn > 0) return false;
+    if (iAction == Qt::IgnoreAction) {
+        return true;
+    }
+    if (!iData || !(iData->hasFormat("application/skg.node.ids") || iData->hasUrls())) {
+        return false;    // TODO(Stephane MANKOWSKI): accept all
+    }
+    if (iColumn > 0) {
+        return false;
+    }
 
     SKGError err;
     // Drop files
@@ -870,13 +961,16 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
                 min = previousObject.getOrder();
             }
 
-            if (iRow >= rowCount(parentIndex)) max = min + 1;
-            else {
+            if (iRow >= rowCount(parentIndex)) {
+                max = min + 1;
+            } else {
                 QModelIndex nextIndex = SKGObjectModelBase::index(iRow, 0, parentIndex);
                 SKGNodeObject nextObject(getObject(nextIndex));
                 max = nextObject.getOrder();
             }
-            if (max <= min) max = min + 1;
+            if (max <= min) {
+                max = min + 1;
+            }
 
             while (!stream.atEnd() && !err) {
                 int o_id;
@@ -888,8 +982,9 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
                 SKGNodeObject child(getDocument(), o_id);
                 err = child.load();
                 IFOK(err) {
-                    if (parentIndex.isValid()) err = child.setParentNode(parentNode);
-                    else {
+                    if (parentIndex.isValid()) {
+                        err = child.setParentNode(parentNode);
+                    } else {
                         err = child.removeParentNode();
                     }
                 }
@@ -908,13 +1003,15 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
 
 void SKGObjectModelBase::pageChanged()
 {
-    if (m_isResetRealyNeeded) dataModified("", 0);
+    if (m_isResetRealyNeeded) {
+        dataModified("", 0);
+    }
 }
 
 void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransaction)
 {
     if (getTable() == iTableName || iTableName.isEmpty()) {
-        SKGTRACEIN(1, "SKGObjectModelBase::dataModified");
+        SKGTRACEINFUNC(1);
         SKGTRACEL(1) << "getTable=" << getRealTable() << endl;
         SKGTRACEL(1) << "Parameters=" << iTableName << " , " << iIdTransaction << endl;
         SKGTabPage* page = SKGTabPage::parentTabPage(qobject_cast< QWidget* >(this->QObject::parent()));
