@@ -21,14 +21,15 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+
+#include <KGlobal>
+#include <QAbstractItemModel>
+#include <QStringList>
+
 #include "skgobjectbase.h"
 #include "skgbasegui_export.h"
 #include "skgdocument.h"
 
-#include <kglobal.h>
-#include <QAbstractItemModel>
-#include <QStringList>
-
 class QWidget;
 /**
  * The Table model managing SKGObjectBase
@@ -325,7 +326,6 @@ protected Q_SLOTS:
     virtual void buidCache();
 
 protected:
-
     /**
      *list of attributes
      */
