@@ -27,14 +27,41 @@
 #include "skgservices.h"
 #include "skgobjectmodelbase.h"
 
+/**
+ * This private class of SKGObjectBase
+ */
+class SKGSortFilterProxyModelPrivate
+{
+public:
+    /**
+     * the previous sort column
+     */
+    int m_previous;
+
+    /**
+     * the current sort column
+     */
+    int m_current;
+
+    /**
+     * to know if we are in a sub sort
+     */
+    bool m_insubsort;
+};
+
+
 SKGSortFilterProxyModel::SKGSortFilterProxyModel(QObject* iParent)
-    : QSortFilterProxyModel(iParent)
+    : QSortFilterProxyModel(iParent), d(new SKGSortFilterProxyModelPrivate)
 {
     _SKGTRACEINFUNC(10);
 
     setSortCaseSensitivity(Qt::CaseInsensitive);
     setSortLocaleAware(true);
     setFilterKeyColumn(0);
+
+    d->m_previous = -1;
+    d->m_current = -1;
+    d->m_insubsort = false;
 }
 
 SKGSortFilterProxyModel::~SKGSortFilterProxyModel()
@@ -42,20 +69,53 @@ SKGSortFilterProxyModel::~SKGSortFilterProxyModel()
     _SKGTRACEINFUNC(10);
 }
 
+int SKGSortFilterProxyModel::getPreviousSortColumn() const
+{
+    return d->m_previous;
+}
+
+void SKGSortFilterProxyModel::setPreviousSortColumn(int iCol) const
+{
+    d->m_previous = iCol;
+}
+
 bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
                                        const QModelIndex& right) const
 {
     // Get source
     SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(this->sourceModel());
-    if (model) {
+    if (model && d) {
+        // Set previous column
+        if (!d->m_insubsort) {
+            int newCol = left.column();
+            if (newCol != d->m_current && d->m_current != -1) {
+                d->m_previous = d->m_current;
+            }
+
+            d->m_current = newCol;
+        }
+
+        // Comparison
         QVariant leftData = model->data(left, Qt::UserRole);
         QVariant rightData = model->data(right, Qt::UserRole);
         SKGObjectBase* leftObj = model->getObjectPointer(left);
         if (leftData == rightData && leftObj) {
-            if (leftObj->getTable().isEmpty() && left.column() != 0) {
+            if (leftObj->getTable().isEmpty() && d->m_current != 0) {
                 // Groups
-                return SKGSortFilterProxyModel::lessThan(model->index(left.row(), 0), model->index(right.row(), 0));
+                d->m_insubsort = true;
+                bool test = SKGSortFilterProxyModel::lessThan(model->index(left.row(), 0), model->index(right.row(), 0));
+                d->m_insubsort = false;
+                return test;
             }
+            // Compare on previous column
+            if (!d->m_insubsort && d->m_previous != -1) {
+                d->m_insubsort = true;
+                bool test = QSortFilterProxyModel::lessThan(model->index(left.row(), d->m_previous), model->index(right.row(), d->m_previous));
+                d->m_insubsort = false;
+                return test;
+            }
+
+            // Compare on ID for stability
             SKGObjectBase* rightObj = model->getObjectPointer(right);
             return (rightObj && leftObj->getID() < rightObj->getID());
         } else {
