@@ -25,11 +25,20 @@
 
 #include <QSortFilterProxyModel>
 #include "skgbasegui_export.h"
+
+class SKGSortFilterProxyModelPrivate;
+
 /**
  * This class is a proxy model with better filter mechanism
  */
 class SKGBASEGUI_EXPORT SKGSortFilterProxyModel : public QSortFilterProxyModel
 {
+    Q_OBJECT
+    /**
+     * The previous sort column
+     */
+    Q_PROPERTY(int previousSortColumn READ getPreviousSortColumn WRITE setPreviousSortColumn USER true)
+
 public:
     /**
      * Contructor
@@ -42,6 +51,19 @@ public:
      */
     virtual ~SKGSortFilterProxyModel();
 
+    /**
+     * @brief Set the previous sort column (-1 = none).
+     *
+     * @param iCol the column index
+     */
+    virtual void setPreviousSortColumn(int iCol) const;
+
+    /**
+     * @brief Get the previous sort column (-1 = none).
+     * @return the column index
+     */
+    virtual int getPreviousSortColumn() const;
+
 protected:
     /**
      * To know if a row must be displayed or not
@@ -61,6 +83,8 @@ protected:
 
 private:
     bool filterAcceptsRowWords(int source_row, const QModelIndex& source_parent, const QStringList& iWords) const;
+
+    SKGSortFilterProxyModelPrivate* const d;
 };
 
 #endif
