@@ -278,6 +278,12 @@ public Q_SLOTS:
      */
     virtual void setMaxColor(const QColor& iColor = Qt::green);
 
+    /**
+     * Set the pareto color
+     * @param iColor the color
+     */
+    virtual void setParetoColor(const QColor& iColor = Qt::darkRed);
+
     /**
      * Set the average color
      * @param iColor the color
@@ -349,6 +355,12 @@ public Q_SLOTS:
      */
     virtual bool switchLinearRegressionVisibility();
 
+    /**
+     * Switch the pareto curve visibility
+     * @return the new visibility
+     */
+    virtual bool switchParetoVisibility();
+
     /**
      * Switch the legend visibility
      * @return the new visibility
@@ -389,6 +401,7 @@ private Q_SLOTS:
     void onFilterModified();
     void onDisplayModeChanged();
     void onChangeColor();
+    void onHorizontalScrollBarChanged(int);
     void refresh();
     void redrawText();
     void redrawGraph();
@@ -404,6 +417,9 @@ private:
     int getAverageColumnIndex() const;
     int getMinColumnIndex() const;
 
+    QStringList getSumItems(const QString& iString) const;
+    void addSums(SKGStringListList& ioTable, int& iNblines);
+
     static bool listSort(const QStringList& s1, const QStringList& s2);
     static Qt::SortOrder m_sortOrder;
     static int m_sortColumn;
@@ -422,6 +438,7 @@ private:
     bool m_graphTypeVisible;
     bool m_limitVisible;
     bool m_linearRegressionVisible;
+    bool m_paretoVisible;
     bool m_legendVisible;
     bool m_graphVisible;
     bool m_tableVisible;
@@ -434,6 +451,7 @@ private:
     QTimer m_timerRedraw;
     QAction* m_actShowLimits;
     QAction* m_actShowLinearRegression;
+    QAction* m_actShowPareto;
     QAction* m_actShowLegend;
     QAction* m_actShowZero;
     QAction* m_allPositiveMenu;
@@ -452,6 +470,7 @@ private:
     QColor m_gridColor;
     QColor m_minColor;
     QColor m_maxColor;
+    QColor m_paretoColor;
     QColor m_averageColor;
     QColor m_tendencyColor;
     QColor m_outlineColor;
