@@ -31,7 +31,6 @@
 
 #include <QDomDocument>
 #include <QHeaderView>
-#include <QSortFilterProxyModel>
 #include <QBasicTimer>
 #include <QEvent>
 #include <QMouseEvent>
@@ -58,6 +57,7 @@
 #include "skgobjectbase.h"
 #include "skgmainpanel.h"
 #include "skgtableview.h"
+#include "skgsortfilterproxymodel.h"
 
 SKGTreeView::SKGTreeView(QWidget* iParent)
     : QTreeView(iParent),
@@ -179,6 +179,10 @@ QString SKGTreeView::getState()
         if (isSortingEnabled()) {
             root.setAttribute("sortOrder", SKGServices::intToString(static_cast<int>(hHeader->sortIndicatorOrder())));
             root.setAttribute("sortColumn", m_model->getAttribute(hHeader->sortIndicatorSection()));
+
+            if (m_proxyModel) {
+                root.setAttribute("sortPreviousColumn", SKGServices::intToString(m_proxyModel->getPreviousSortColumn()));
+            }
         }
         root.setAttribute("groupBy", m_groupby);
 
@@ -251,6 +255,7 @@ void SKGTreeView::setState(const QString& iState)
 
         QString sortOrder = root.attribute("sortOrder");
         QString sortColumn = root.attribute("sortColumn");
+        QString sortPreviousColumn = root.attribute("sortPreviousColumn");
         m_groupby = root.attribute("groupBy");
         QString columns = root.attribute("columns");
         QString columnsSize = root.attribute("columnsSize");
@@ -296,6 +301,9 @@ void SKGTreeView::setState(const QString& iState)
         }
 
         // Set sort
+        if (m_proxyModel && !sortPreviousColumn.isEmpty()) {
+            m_proxyModel->setPreviousSortColumn(SKGServices::stringToInt(sortPreviousColumn));
+        }
         if (m_model && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty()) {
             int index = SKGServices::splitCSVLine(columns, ';').indexOf(sortColumn);
             if (index == -1) {
@@ -1266,7 +1274,7 @@ void SKGTreeView::setModel(QAbstractItemModel* iModel)
 {
     if (iModel != this->model()) {
         m_model = static_cast<SKGObjectModelBase*>(iModel);
-        m_proxyModel = qobject_cast<QSortFilterProxyModel*> (iModel);
+        m_proxyModel = qobject_cast<SKGSortFilterProxyModel*> (iModel);
         if (m_proxyModel) {
             m_model = static_cast<SKGObjectModelBase*>(m_proxyModel->sourceModel());
         }
