@@ -35,7 +35,7 @@
 
 SKGUniqueApplication::SKGUniqueApplication(SKGDocument* iDoc) : KUniqueApplication(), m_splash(NULL), m_doc(iDoc), m_widget(NULL)
 {
-    SKGTRACEIN(1, "SKGUniqueApplication::SKGUniqueApplication");
+    SKGTRACEINFUNC(1);
 //    setAttribute(Qt::AA_DontUseNativeMenuBar, !SKGServices::getenv("SKGNATIVEMENU").isEmpty());
 
     m_timer.setSingleShot(true);
@@ -47,7 +47,7 @@ SKGUniqueApplication::SKGUniqueApplication(SKGDocument* iDoc) : KUniqueApplicati
  */
 SKGUniqueApplication::~SKGUniqueApplication()
 {
-    SKGTRACEIN(1, "SKGUniqueApplication::~SKGUniqueApplication");
+    SKGTRACEINFUNC(1);
     m_splash = NULL;
     m_doc = NULL;
     m_widget = NULL;
@@ -59,7 +59,7 @@ SKGUniqueApplication::~SKGUniqueApplication()
  */
 int SKGUniqueApplication::newInstance()
 {
-    SKGTRACEIN(1, "SKGUniqueApplication::newInstance");
+    SKGTRACEINFUNC(1);
 
     // Build list of arguments
     QStringList argument;
@@ -101,7 +101,7 @@ int SKGUniqueApplication::newInstance()
     }
 
     if (m_splash) {
-        SKGTRACEIN(1, "SKGUniqueApplication::newInstance-finish splash screen");
+        SKGTRACEINFUNC(1);
 
         m_splash->clearMessage();
         // m_splash->finish(m_widget); wait 2s
