@@ -21,12 +21,13 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+#include <QWidget>
+
+#include <KGlobal>
+
 #include "skgbasegui_export.h"
 #include "skgobjectbase.h"
 
-#include <QWidget>
-
-#include <kglobal.h>
 class SKGDocument;
 
 /**
@@ -107,4 +108,4 @@ private:
     SKGDocument*  m_document;
 };
 
-#endif // SKGWIDGET_H
+#endif  // SKGWIDGET_H
