@@ -117,7 +117,9 @@ void SKGWidgetSelector::setSelectedMode(int iMode)
         // Set current mode
         // int previousmode = m_currentMode;
         m_currentMode = iMode;
-        if (m_currentMode >= m_listWidgets.count()) m_currentMode = -1;
+        if (m_currentMode >= m_listWidgets.count()) {
+            m_currentMode = -1;
+        }
 
         // Show widgets
         if (m_currentMode >= 0) {
@@ -137,7 +139,9 @@ void SKGWidgetSelector::setSelectedMode(int iMode)
             }
         }
 
-        if (m_currentMode < -1) this->hide();
+        if (m_currentMode < -1) {
+            this->hide();
+        }
 
         emit selectedModeChanged(m_currentMode);
     }
@@ -145,7 +149,9 @@ void SKGWidgetSelector::setSelectedMode(int iMode)
 
 void SKGWidgetSelector::setEnabledMode(int iMode, bool iEnabled)
 {
-    if (iMode >= 0 && iMode < m_listButton.count()) m_listButton.at(iMode)->setEnabled(iEnabled);
+    if (iMode >= 0 && iMode < m_listButton.count()) {
+        m_listButton.at(iMode)->setEnabled(iEnabled);
+    }
 }
 
 void SKGWidgetSelector::onButtonClicked()
@@ -155,7 +161,9 @@ void SKGWidgetSelector::onButtonClicked()
     if (m_currentMode == newMode) {
         if (getAlwaysOneOpen()) {
             --newMode;
-            if (newMode == -1) newMode = m_listButton.count() - 1;
+            if (newMode == -1) {
+                newMode = m_listButton.count() - 1;
+            }
         } else {
             newMode = -1;
         }
