@@ -36,7 +36,9 @@ SKGWidgetSelectorDesignerPlugin::SKGWidgetSelectorDesignerPlugin(QObject* iParen
 void SKGWidgetSelectorDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
 {
     Q_UNUSED(iCore);
-    if (m_initialized) return;
+    if (m_initialized) {
+        return;
+    }
 
     m_initialized = true;
 }
