@@ -48,7 +48,9 @@ void SKGZoomSelector::setValue(int iValue, bool iEmitEvent)
 {
     bool previous = ui.kZoomSlider->blockSignals(!iEmitEvent);
     ui.kZoomSlider->setValue(iValue);
-    if (ui.kZoomOriginal) ui.kZoomOriginal->setChecked(iValue == m_resetValue);
+    if (ui.kZoomOriginal) {
+        ui.kZoomOriginal->setChecked(iValue == m_resetValue);
+    }
     ui.kZoomSlider->blockSignals(previous);
 }
 
@@ -90,9 +92,15 @@ void SKGZoomSelector::onZoomChangedDelayed()
 void SKGZoomSelector::onZoomChanged()
 {
     int val = ui.kZoomSlider->value();
-    if (ui.kZoomIn) ui.kZoomIn->setEnabled(val < 10);
-    if (ui.kZoomOut) ui.kZoomOut->setEnabled(val > -10);
-    if (ui.kZoomOriginal) ui.kZoomOriginal->setChecked(val == m_resetValue);
+    if (ui.kZoomIn) {
+        ui.kZoomIn->setEnabled(val < 10);
+    }
+    if (ui.kZoomOut) {
+        ui.kZoomOut->setEnabled(val > -10);
+    }
+    if (ui.kZoomOriginal) {
+        ui.kZoomOriginal->setChecked(val == m_resetValue);
+    }
 
     Q_EMIT changed(val);
 }
