@@ -161,6 +161,12 @@ static const int ERR_INSTALL = 13;
  */
 static const int ERR_CORRUPTION = 14;
 
+/**
+ * @var ERR_READACCESS
+ * Error number
+ */
+static const int ERR_READACCESS = 15;
+
 /**
  * @brief For a not modified field
  **/
