@@ -172,13 +172,13 @@ public Q_SLOTS:
      * Get unique identifier
      * @return the unique identifier
      */
-    virtual QString getUniqueIdentifier();
+    virtual QString getUniqueIdentifier() const;
 
     /**
      * Get database identifier
      * @return the database identifier
      */
-    virtual QString getDatabaseIdentifier();
+    virtual QString getDatabaseIdentifier() const;
 
     /**
      * Call the progress callstack.
@@ -748,6 +748,15 @@ public Q_SLOTS:
      */
     virtual SKGError executeSqliteOrder(const QString& iSqlOrder, int* iLastId = NULL) const;
 
+    /**
+     * Execute a select sqlite order returning one value and return the result in @p oResult
+     * @param iSqlOrder the sql order
+     * @param oResult the result of the select
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError executeSingleSelectSqliteOrder(const QString& iSqlOrder, QString& oResult) const;
+
     /**
     * Execute a select sqlite order and return the result in @p oResult
     * @param iSqlOrder the sql order
