@@ -47,7 +47,7 @@ SKGError::~SKGError()
     m_previousError = NULL;
 }
 
-const SKGError& SKGError::operator= (const SKGError& iError)
+SKGError& SKGError::operator= (const SKGError& iError)
 {
     if (Q_LIKELY(&iError != this)) {
         delete m_previousError;
