@@ -99,7 +99,7 @@ public:
     * Operator affectation
     * @param iError the error to copy
     */
-    const SKGError& operator= (const SKGError& iError);
+    SKGError& operator= (const SKGError& iError);
 
     /**
     * To know if this is an error or not. Equivalent to @see isSucceeded
