@@ -32,11 +32,11 @@
  */
 class SKGBASEMODELER_EXPORT SKGNamedObject : public SKGObjectBase
 {
-    Q_OBJECT;
+    Q_OBJECT
     /**
      * Name of the object
      */
-    Q_PROPERTY(QString name READ getName WRITE setName USER true);
+    Q_PROPERTY(QString name READ getName WRITE setName USER true)
 
 public:
     /**
@@ -71,7 +71,7 @@ public:
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGNamedObject(const SKGObjectBase& iObject);
+    explicit SKGNamedObject(const SKGObjectBase& iObject);
 
     /**
      * Operator affectation
