@@ -54,8 +54,9 @@ const SKGNodeObject& SKGNodeObject::operator= (const SKGObjectBase& iObject)
 SKGError SKGNodeObject::setName(const QString& iName)
 {
     SKGError err;
-    if (iName.contains(OBJECTSEPARATOR)) err = SKGError(ERR_FAIL, i18nc("Error message: an invalid character was found", "The name '%1' is invalid : the '%2' character is forbidden ", iName, QString(OBJECTSEPARATOR)));
-    else {
+    if (iName.contains(OBJECTSEPARATOR)) {
+        err = SKGError(ERR_FAIL, i18nc("Error message: an invalid character was found", "The name '%1' is invalid : the '%2' character is forbidden ", iName, QString(OBJECTSEPARATOR)));
+    } else {
         err = SKGNamedObject::setName(iName);
     }
     return err;
@@ -70,9 +71,12 @@ QString SKGNodeObject::getWhereclauseId() const
             output = "t_name='" % SKGServices::stringToSqlString(getAttribute("t_name")) % '\'';
         }
         QString rd_node_id = getAttribute("rd_node_id");
-        if (!output.isEmpty()) output += " AND ";
-        if (rd_node_id.isEmpty()) output += "(rd_node_id=0 OR rd_node_id IS NULL OR rd_node_id='')";
-        else {
+        if (!output.isEmpty()) {
+            output += " AND ";
+        }
+        if (rd_node_id.isEmpty()) {
+            output += "(rd_node_id=0 OR rd_node_id IS NULL OR rd_node_id='')";
+        } else {
             output += "rd_node_id=" % rd_node_id;
         }
     }
@@ -107,7 +111,9 @@ SKGError SKGNodeObject::setIcon(const QString& iIcon)
 QIcon SKGNodeObject::getIcon() const
 {
     QStringList overlay;
-    if (isAutoStart()) overlay.push_back("user-online");
+    if (isAutoStart()) {
+        overlay.push_back("user-online");
+    }
     QIcon icon = static_cast<QIcon>(KIcon(getAttribute("t_icon"), NULL, overlay));
     return icon;
 }
@@ -130,7 +136,9 @@ SKGError SKGNodeObject::setOrder(double iOrder)
         order = 1;
         SKGStringListList result;
         err = getDocument()->executeSelectSqliteOrder("SELECT max(f_sortorder) from node", result);
-        if (!err && result.count() == 2) order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+        if (!err && result.count() == 2) {
+            order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+        }
     }
     IFOKDO(err, setAttribute("f_sortorder", SKGServices::doubleToString(order)))
     return err;
@@ -147,10 +155,12 @@ SKGError SKGNodeObject::createPathNode(SKGDocument* iDocument,
                                        bool iRenameIfAlreadyExist)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGNodeObject::createPathNode", err);
+    SKGTRACEINFUNCRC(10, err);
     SKGTRACEL(10) << "Input parameter [iFullPath]=" << iFullPath << endl;
     // Check if node is already existing
-    if (!iRenameIfAlreadyExist && iDocument) iDocument->getObject("v_node", "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oNode);
+    if (!iRenameIfAlreadyExist && iDocument) {
+        iDocument->getObject("v_node", "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oNode);
+    }
     if (oNode.getID() == 0) {
         // No, we have to create it
         // Search node separator
@@ -210,9 +220,10 @@ SKGError SKGNodeObject::createPathNode(SKGDocument* iDocument,
 SKGError SKGNodeObject::addNode(SKGNodeObject& oNode)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGNodeObject::addNode", err);
-    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::addNode")));
-    else {
+    SKGTRACEINFUNCRC(10, err);
+    if (getID() == 0) {
+        err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::addNode")));
+    } else {
         oNode = SKGNodeObject(getDocument());
         err = oNode.setAttribute("rd_node_id", SKGServices::intToString(getID()));
     }
@@ -227,9 +238,10 @@ SKGError SKGNodeObject::removeParentNode()
 SKGError SKGNodeObject::setParentNode(const SKGNodeObject& iNode)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGNodeObject::setParentNode", err);
-    if (iNode.getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::setParentNode")));
-    else {
+    SKGTRACEINFUNCRC(10, err);
+    if (iNode.getID() == 0) {
+        err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::setParentNode")));
+    } else {
         // Check if it's a loop
         SKGNodeObject current = iNode;
         do {
@@ -251,8 +263,9 @@ SKGError SKGNodeObject::getParentNode(SKGNodeObject& oNode) const
 {
     SKGError err;
     QString parent_id = getAttribute("rd_node_id");
-    if (!parent_id.isEmpty()) err = getDocument()->getObject("v_node", "id=" % parent_id , oNode);
-    else {
+    if (!parent_id.isEmpty()) {
+        err = getDocument()->getObject("v_node", "id=" % parent_id , oNode);
+    } else {
         oNode = SKGNodeObject();
     }
     return err;
