@@ -68,7 +68,9 @@ SKGObjectBase::SKGObjectBase(SKGDocument* iDocument, const QString& iTable, int
     d->id = iID;
     d->table = iTable;
     d->document = iDocument;
-    if (Q_LIKELY(d->id != 0)) load();
+    if (Q_LIKELY(d->id != 0)) {
+        load();
+    }
 }
 
 SKGObjectBase::~SKGObjectBase()
@@ -128,10 +130,16 @@ QString SKGObjectBase::getAttributeFromView(const QString& iView, const QString&
 
     SKGStringListList result;
     QString wc = getWhereclauseId();
-    if (wc.isEmpty()) wc = "id=" % SKGServices::intToString(d->id);
+    if (wc.isEmpty()) {
+        wc = "id=" % SKGServices::intToString(d->id);
+    }
     QString sql = "SELECT " % iName % " FROM " % iView % " WHERE " % wc;
-    if (getDocument()) getDocument()->executeSelectSqliteOrder(sql, result);
-    if (result.count() == 2) output = result.at(1).at(0);
+    if (getDocument()) {
+        getDocument()->executeSelectSqliteOrder(sql, result);
+    }
+    if (result.count() == 2) {
+        output = result.at(1).at(0);
+    }
 
     return output;
 }
@@ -152,7 +160,9 @@ void SKGObjectBase::copyFrom(const SKGObjectBase& iObject)
 SKGObjectBase SKGObjectBase::cloneInto(SKGDocument* iDocument)
 {
     SKGDocument* targetDocument = iDocument;
-    if (targetDocument == NULL) targetDocument = d->document;
+    if (targetDocument == NULL) {
+        targetDocument = d->document;
+    }
 
     SKGObjectBase output;
     output.copyFrom(*this);
@@ -201,8 +211,9 @@ SKGError SKGObjectBase::setAttributes(const QStringList& iNames, const QStringLi
         QString att = iNames.at(i);
         QString val = iValues.at(i);
 
-        if (Q_LIKELY(att != "id")) err = setAttribute(att, val);
-        else {
+        if (Q_LIKELY(att != "id")) {
+            err = setAttribute(att, val);
+        } else {
             d->id = SKGServices::stringToInt(val);
         }
     }
@@ -241,7 +252,7 @@ SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue
             } else if (op == i18nc("Key word to modify a string into a field", "upper")) {
                 val = val.toUpper();
             } else if (op == i18nc("Key word to modify a string into a field", "capwords")) {
-                val = KStringHandler::capwords(val);
+                val = KStringHandler::capwords(val.toLower());
             } else if (op == i18nc("Key word to modify a string into a field", "capitalize")) {
                 val = val.left(1).toUpper() % val.right(val.length() - 1).toLower();
             } else if (op == i18nc("Key word to modify a string into a field", "trim")) {
@@ -269,7 +280,9 @@ QString SKGObjectBase::getAttribute(const QString& iName) const
         if (ok) {
             // What is the key corresponding to this name ?
             QStringList keys = d->attributes.keys();
-            if (pos >= 0 && pos < keys.count()) output = d->attributes[keys.at(pos)];
+            if (pos >= 0 && pos < keys.count()) {
+                output = d->attributes[keys.at(pos)];
+            }
         }
     }
 
@@ -278,37 +291,46 @@ QString SKGObjectBase::getAttribute(const QString& iName) const
 
 bool SKGObjectBase::exist() const
 {
-    SKGTRACEIN(20, "SKGObjectBase::exist");
+    SKGTRACEINFUNC(20);
 
     SKGStringListList result;
     QString wc = getWhereclauseId();
-    if (wc.isEmpty() && d->id) wc = "id=" % SKGServices::intToString(d->id);
-    if (wc.isEmpty()) return false;
+    if (wc.isEmpty() && d->id) {
+        wc = "id=" % SKGServices::intToString(d->id);
+    }
+    if (wc.isEmpty()) {
+        return false;
+    }
 
     QString sql = "SELECT count(1) FROM " % d->table % " WHERE " % wc;
-    if (getDocument()) getDocument()->executeSelectSqliteOrder(sql, result);
+    if (getDocument()) {
+        getDocument()->executeSelectSqliteOrder(sql, result);
+    }
     return (result.size() >= 2 && result.at(1).at(0) != "0");
 }
 
 SKGError SKGObjectBase::load()
 {
     SKGError err;
-    SKGTRACEINRC(20, "SKGObjectBase::load", err);
+    SKGTRACEINFUNCRC(20, err);
 
     if (Q_LIKELY(getDocument() && !getTable().isEmpty())) {
         // Prepare where clause
         QString wc = getWhereclauseId();
-        if (wc.isEmpty()) wc = "id=" % SKGServices::intToString(d->id);
+        if (wc.isEmpty()) {
+            wc = "id=" % SKGServices::intToString(d->id);
+        }
 
         // Execute sql order
         SKGStringListList result;
         err = getDocument()->executeSelectSqliteOrder("SELECT * FROM " % d->table % " WHERE " % wc, result);
         IFOK(err) {
             int size = result.size();
-            if (Q_UNLIKELY(size == 1))  err = SKGError(ERR_INVALIDARG, i18nc("Error message: Could not load something because it is not in the database", "Load of '%1' with '%2' failed because it was not found in the database", d->table, wc));
-            else if (Q_UNLIKELY(size != 2))  err = SKGError(ERR_INVALIDARG, i18np("Load of '%2' with '%3' failed because of bad size of result (found one object)",
-                                                       "Load of '%2' with '%3' failed because of bad size of result (found %1 objects)",
-                                                       size - 1, d->table, wc));
+            if (Q_UNLIKELY(size == 1)) {
+                err = SKGError(ERR_INVALIDARG, i18nc("Error message: Could not load something because it is not in the database", "Load of '%1' with '%2' failed because it was not found in the database", d->table, wc));
+            } else if (Q_UNLIKELY(size != 2))  err = SKGError(ERR_INVALIDARG, i18np("Load of '%2' with '%3' failed because of bad size of result (found one object)",
+                        "Load of '%2' with '%3' failed because of bad size of result (found %1 objects)",
+                        size - 1, d->table, wc));
             else {
                 SKGStringListListIterator itrow = result.begin();
                 QStringList columns = *(itrow);
@@ -325,17 +347,20 @@ SKGError SKGObjectBase::load()
 QString SKGObjectBase::getWhereclauseId() const
 {
     int id = getID();
-    if (id != 0) return "id=" % SKGServices::intToString(id);
+    if (id != 0) {
+        return "id=" % SKGServices::intToString(id);
+    }
     return "";
 }
 
 SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
 {
     SKGError err;
-    SKGTRACEINRC(20, "SKGObjectBase::save", err);
+    SKGTRACEINFUNCRC(20, err);
 
-    if (Q_UNLIKELY(!d->document)) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
-    else {
+    if (Q_UNLIKELY(!d->document)) {
+        err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
+    } else {
         // Save linking objects
         int nb = d->objects.count();
         for (int i = 0; !err && i < nb; ++i) {
@@ -409,9 +434,10 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
 SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
 {
     SKGError err;
-    SKGTRACEINRC(20, "SKGObjectBase::remove", err);
-    if (Q_UNLIKELY(!d->document)) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
-    else {
+    SKGTRACEINFUNCRC(20, err);
+    if (Q_UNLIKELY(!d->document)) {
+        err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
+    } else {
         // Check if we are in a transaction
         err = d->document->checkExistingTransaction();
 
@@ -426,16 +452,21 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
             err = d->document->executeSelectSqliteOrder("SELECT t_delete_message FROM " % viewForDelete % " WHERE id=" % SKGServices::intToString(d->id), temporaryResult);
             IFOK(err) {
                 QString msg;
-                if (temporaryResult.count() > 1) msg = temporaryResult.at(1).at(0);
+                if (temporaryResult.count() > 1) {
+                    msg = temporaryResult.at(1).at(0);
+                }
                 // Should the string below be translated ??? It contains no word
-                if (!msg.isEmpty()) err = SKGError(ERR_FORCEABLE, i18nc("Error message for an object", "'%1': %2", getDisplayName(), msg));
+                if (!msg.isEmpty()) {
+                    err = SKGError(ERR_FORCEABLE, i18nc("Error message for an object", "'%1': %2", getDisplayName(), msg));
+                }
             }
         }
 
         QString displayname = getDisplayName();  // Must be done before the delete order
         IFOKDO(err, d->document->executeSqliteOrder("DELETE FROM " % getRealTable() % " WHERE id=" % SKGServices::intToString(d->id)))
-        if (iSendMessage && !err && !displayname.isEmpty())
+        if (iSendMessage && !err && !displayname.isEmpty()) {
             err = d->document->sendMessage(i18nc("An information to the user that something was deleted", "'%1' has been deleted", displayname), SKGDocument::Hidden);
+        }
     }
 
     return err;
@@ -446,8 +477,9 @@ SKGError SKGObjectBase::dump()
     // dump
     SKGTRACE << "=== START DUMP [" << getUniqueID() << "]===" << endl;
     SKGQStringQStringMapIterator it;
-    for (it = d->attributes.begin() ; it != d->attributes.end(); ++it)
+    for (it = d->attributes.begin() ; it != d->attributes.end(); ++it) {
         SKGTRACE << it.key() << "=[" << it.value() << ']' << endl;
+    }
     SKGTRACE << "=== END DUMP [" << getUniqueID() << "]===" << endl;
     return SKGError();
 }
