@@ -35,14 +35,24 @@ class SKGBASEMODELER_EXPORT SKGReport : public QObject
 {
     Q_OBJECT
     /**
-     * The current month
+     * The period
      */
-    Q_PROPERTY(QString month READ getMonth)
+    Q_PROPERTY(QString period READ getPeriod)
 
     /**
-     * The previous month
+     * The month (for compatibility in templates)
      */
-    Q_PROPERTY(QString previous_month READ getPreviousMonth)
+    Q_PROPERTY(QString month READ getPeriod)
+
+    /**
+     * The previous period
+     */
+    Q_PROPERTY(QString previous_period READ getPreviousPeriod)
+
+    /**
+     * The previous month (for compatibility in templates)
+     */
+    Q_PROPERTY(QString previous_month READ getPreviousPeriod)
 
 public:
     /**
@@ -56,22 +66,22 @@ public:
     virtual ~SKGReport();
 
     /**
-     * Set the current month
-     * @param iMonth the month
+     * Set the current period
+     * @param iPeriod the period
      */
-    virtual void setMonth(const QString& iMonth);
+    virtual void setPeriod(const QString& iPeriod);
 
     /**
-     * Get the current month
-     * @return the current month
+     * Get the current period
+     * @return the current period
      */
-    virtual QString getMonth();
+    virtual QString getPeriod();
 
     /**
-     * Get the previous month
-     * @return the previous month
+     * Get the previous period
+     * @return the previous period
      */
-    virtual QString getPreviousMonth();
+    virtual QString getPreviousPeriod();
 
     /**
      * Get report
