@@ -1309,11 +1309,9 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
             err = SKGError(SQLLITEERROR + sqlError.number(), iSqlOrder);
             err.addError(SQLLITEERROR + sqlError.number(), sqlError.text());
         } else {
+            double elapse1 = 0;
             if (SKGServices::SKGSqlTraces != -1) {
-                double elapse1 = SKGServices::getMicroTime() - elapse;
-                if (elapse1 >= SKGServices::SKGSqlTraces) {
-                    SKGTRACE << "executeSqliteOrder :" << iSqlOrder << " TIME=" << elapse1 << " ms" << endl;
-                }
+                elapse1 = SKGServices::getMicroTime() - elapse;
             }
 
             // Addition of column names
@@ -1347,9 +1345,9 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
                 oResult.push_back(line2);
             }
             if (SKGServices::SKGSqlTraces != -1) {
-                double elapse1 = SKGServices::getMicroTime() - elapse;
+                double elapse2 = SKGServices::getMicroTime() - elapse;
                 if (elapse1 >= SKGServices::SKGSqlTraces) {
-                    SKGTRACE << "executeSqliteOrder (with fetch) :" << iSqlOrder << " TIME=" << elapse1 << " ms" << endl;
+                    SKGTRACE << "executeSqliteOrder:" << iSqlOrder << " TIME=" << elapse1 << " ms,  (with fetch):" << elapse2 << " ms" << endl;
                 }
             }
         }
