@@ -135,8 +135,12 @@ SKGTraces::~SKGTraces()
         ++(m_it.value().NbCall);
         m_it.value().Time += m_elapse;
         m_it.value().TimePropre += m_elapse;
-        if (m_elapse > m_it.value().TimeMax) m_it.value().TimeMax = m_elapse;
-        if (m_elapse < m_it.value().TimeMin) m_it.value().TimeMin = m_elapse;
+        if (m_elapse > m_it.value().TimeMax) {
+            m_it.value().TimeMax = m_elapse;
+        }
+        if (m_elapse < m_it.value().TimeMin) {
+            m_it.value().TimeMin = m_elapse;
+        }
 
         if (!SKGTraces::m_SKGPerfoPathMethode.empty() && SKGTraces::m_SKGPerfoPathMethode.top() == m_mame) {
             // Remove current methode from stack
@@ -175,7 +179,7 @@ QStringList SKGTraces::getProfilingStatistics()
 {
     QStringList output;
     if (SKGPerfo) {
-        output.push_back("method , nb call , millisecondes , average , min , max , own time , average own time");
+        output.push_back("method ; nb call ; millisecondes ; average ; min ; max ; own time ; average own time");
 
         SKGPerfoMap SKGPerfoMethodeCopy = m_SKGPerfoMethode;
         while (!SKGPerfoMethodeCopy.empty()) {
@@ -193,13 +197,13 @@ QStringList SKGTraces::getProfilingStatistics()
             // dump max
             if (maxtime != -1) {
                 output.push_back(max.key()
-                                 % " , " % SKGServices::intToString(max.value().NbCall)
-                                 % " , " % SKGServices::doubleToString(max.value().Time)
-                                 % " , " % SKGServices::doubleToString((max.value().Time) / (static_cast<double>(max.value().NbCall)))
-                                 % " , " % SKGServices::doubleToString(max.value().TimeMin)
-                                 % " , " % SKGServices::doubleToString(max.value().TimeMax)
-                                 % " , " % SKGServices::doubleToString(max.value().TimePropre)
-                                 % " , " % SKGServices::doubleToString((max.value().TimePropre) / (static_cast<double>(max.value().NbCall))));
+                                 % " ; " % SKGServices::intToString(max.value().NbCall)
+                                 % " ; " % SKGServices::doubleToString(max.value().Time)
+                                 % " ; " % SKGServices::doubleToString((max.value().Time) / (static_cast<double>(max.value().NbCall)))
+                                 % " ; " % SKGServices::doubleToString(max.value().TimeMin)
+                                 % " ; " % SKGServices::doubleToString(max.value().TimeMax)
+                                 % " ; " % SKGServices::doubleToString(max.value().TimePropre)
+                                 % " ; " % SKGServices::doubleToString((max.value().TimePropre) / (static_cast<double>(max.value().NbCall))));
 
                 // Remove it
                 SKGPerfoMethodeCopy.erase(max);
