@@ -91,8 +91,9 @@ int main(int argc, char** argv)
     // Build list of arguments
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
     SKGError err;
-    if (!args->isSet("in")) err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Missing -in option"));
-    else if (!args->isSet("out")) {
+    if (!args->isSet("in")) {
+        err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Missing -in option"));
+    } else if (!args->isSet("out")) {
         err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Missing -out option"));
     }
 
@@ -104,7 +105,9 @@ int main(int argc, char** argv)
         // Import
         QString file = args->getOption("in");
         QFileInfo fi(file);
-        if (fi.exists()) file = fi.absoluteFilePath();
+        if (fi.exists()) {
+            file = fi.absoluteFilePath();
+        }
         SKGImportExportManager imp(&document, KUrl::fromLocalFile(file));
         QMap<QString, QString>  parameters = imp.getImportParameters();
         parameters["import_by_load"] = 'Y';
@@ -136,7 +139,9 @@ int main(int argc, char** argv)
         // Export
         QString file = args->getOption("out");
         QFileInfo fi(file);
-        if (fi.exists()) file = fi.absoluteFilePath();
+        if (fi.exists()) {
+            file = fi.absoluteFilePath();
+        }
         SKGImportExportManager exp(&document, KUrl::fromLocalFile(args->getOption("out")));
         SKGTRACESEPARATOR;
         SKGTRACE << i18nc("Title of a console trace section", " Exported file:") << exp.getFileName().prettyUrl()  << endl;
